@@ -28,10 +28,14 @@ styling_within_preprocessor=1;0;false;false
 [keywords]
 # all items must be in one line
 primary=volatile default export goto sizeof typename asm enum bool union NULL FALSE TRUE typedef struct char int float double void unsigned signed long short extern static register auto const if else switch for while do break continue return class new delete inline case
+secondary=
 # these are some doxygen keywords (incomplete)
 docComment=attention author brief bug class code date def enum example exception file fn namespace note param remarks return see since struct throw todo typedef var version warning union
 
 [settings]
+# default extension used when saving files
+#extension=c
+
 # the following characters are these which a "word" can contains, see documentation
 #wordchars=_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789
 
@@ -43,20 +47,22 @@ comment_close=
 #comment_close=*/
 
 # set to false if a comment character/string should start at column 0 of a line, true uses any
-# indention of the line, e.g. setting to true causes the following on pressing CTRL+d
+# indentation of the line, e.g. setting to true causes the following on pressing CTRL+d
 	#command_example();
 # setting to false would generate this
 #	command_example();
 # This setting works only for single line comments
 comment_use_indent=true
 
+# context action command (please see Geany's main documentation for details)
+context_action_cmd=
+
 [build_settings]
 # %f will be replaced by the complete filename
 # %e will be replaced by the filename without extension
 # (use only one of it at one time)
 compiler=gcc -Wall -c "%f"
-# the -o option is automatically added by Geany
-linker=gcc -Wall "%f"
+linker=gcc -Wall -o "%e" "%f"
 run_cmd="./%e"
 
 
