@@ -20,7 +20,7 @@
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *      MA 02110-1301, USA.
  *
- * $Id: classbuilder.c 2195 2008-01-28 17:27:39Z ntrel $
+ * $Id: classbuilder.c 2430 2008-03-31 13:09:56Z ntrel $
  */
 
 /* Class Builder - creates source files containing a new class interface and definition. */
@@ -37,10 +37,10 @@ PluginFields	*plugin_fields;
 GeanyData		*geany_data;
 
 
-VERSION_CHECK(7)
+PLUGIN_VERSION_CHECK(7)
 
 PLUGIN_INFO(_("Class Builder"), _("Creates source files for new class types."), VERSION,
-	_("The Geany developer team"))
+	"Alexander Rodin")
 
 
 enum
@@ -99,10 +99,10 @@ class {class_name}{base_decl}\n\
 		{destructor_decl}\
 	\n\
 	private:\n\
-		// add your private declarations\n\
+		/* add your private declarations */\n\
 };\n\
 \n\
-#endif // {header_guard}\n\
+#endif /* {header_guard} */ \n\
 ";
 
 static const gchar templates_cpp_class_source[] = "{fileheader}\n\n\
@@ -481,7 +481,7 @@ void show_dialog_create_class(gint type)
 		cc_dlg_on_create_class(cc_dlg);
 
 	gtk_widget_destroy(cc_dlg->dialog);
-//	g_object_unref(G_OBJECT(cc_dlg->dialog));
+/*	g_object_unref(G_OBJECT(cc_dlg->dialog));	*/
 }
 
 
@@ -725,7 +725,7 @@ static void cc_dlg_on_create_class(CreateClassDialog *cc_dlg)
 		}
 	}
 
-	// only create the files if the filename is not empty
+	/* only create the files if the filename is not empty */
 	if (! p_utils->str_equal(class_info->source, ""))
 	{
 		text = get_template_class_source(class_info);
@@ -784,10 +784,10 @@ void init(GeanyData *data)
 	menu_create_class1_menu = gtk_menu_new ();
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_create_class1), menu_create_class1_menu);
 
-	menu_create_cpp_class = gtk_menu_item_new_with_mnemonic (_("C++ Class"));
+	menu_create_cpp_class = gtk_menu_item_new_with_mnemonic (_("_C++ Class"));
 	gtk_container_add (GTK_CONTAINER (menu_create_class1_menu), menu_create_cpp_class);
 
-	menu_create_gtk_class = gtk_menu_item_new_with_mnemonic (_("GTK+ Class"));
+	menu_create_gtk_class = gtk_menu_item_new_with_mnemonic (_("_GTK+ Class"));
 	gtk_container_add (GTK_CONTAINER (menu_create_class1_menu), menu_create_gtk_class);
 
 	g_signal_connect ((gpointer) menu_create_cpp_class, "activate",
@@ -803,7 +803,7 @@ void init(GeanyData *data)
 }
 
 
-void cleanup()
+void cleanup(void)
 {
 	gtk_widget_destroy(plugin_fields->menu_item);
 }
