@@ -19,7 +19,7 @@
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *      MA 02110-1301, USA.
  *
- * $Id: filebrowser.c 2195 2008-01-28 17:27:39Z ntrel $
+ * $Id: filebrowser.c 2444 2008-04-03 16:06:41Z ntrel $
  */
 
 /* Sidebar file browser plugin. */
@@ -43,13 +43,24 @@ PluginFields	*plugin_fields;
 GeanyData		*geany_data;
 
 
-VERSION_CHECK(26)
+PLUGIN_VERSION_CHECK(26)
 
 PLUGIN_INFO(_("File Browser"), _("Adds a file browser tab to the sidebar."), VERSION,
 	_("The Geany developer team"))
 
 
-// number of characters to skip the root of an absolute path("c:" or "d:" on Windows)
+/* Keybinding(s) */
+enum
+{
+	KB_FOCUS_FILE_LIST,
+	KB_FOCUS_PATH_ENTRY,
+	KB_COUNT
+};
+
+PLUGIN_KEY_GROUP(file_browser, KB_COUNT)
+
+
+/* number of characters to skip the root of an absolute path("c:" or "d:" on Windows) */
 #ifdef G_OS_WIN32
 # define ROOT_OFFSET 2
 #else
@@ -60,7 +71,7 @@ enum
 {
 	FILEVIEW_COLUMN_ICON = 0,
 	FILEVIEW_COLUMN_NAME,
-	FILEVIEW_N_COLUMNS,
+	FILEVIEW_N_COLUMNS
 };
 
 static gboolean show_hidden_files = FALSE;
@@ -73,8 +84,8 @@ static GtkTreeIter			*last_dir_iter = NULL;
 static GtkEntryCompletion	*entry_completion = NULL;
 
 static GtkWidget	*path_entry;
-static gchar		*current_dir = NULL;	// in locale-encoding
-static gchar		*open_cmd;				// in locale-encoding
+static gchar		*current_dir = NULL;	/* in locale-encoding */
+static gchar		*open_cmd;				/* in locale-encoding */
 static gchar		*config_file;
 
 static struct
@@ -85,7 +96,7 @@ static struct
 } popup_items;
 
 
-// Returns: whether name should be hidden.
+/* Returns: whether name should be hidden. */
 static gboolean check_hidden(const gchar *base_name)
 {
 	gsize len;
@@ -117,7 +128,7 @@ static gboolean check_hidden(const gchar *base_name)
 }
 
 
-// name is in locale encoding
+/* name is in locale encoding */
 static void add_item(const gchar *name)
 {
 	GtkTreeIter iter;
@@ -162,8 +173,8 @@ static gboolean is_top_level_directory(const gchar *dir)
 }
 
 
-// adds ".." to the start of the file list
-static void add_top_level_entry()
+/* adds ".." to the start of the file list */
+static void add_top_level_entry(void)
 {
 	GtkTreeIter iter;
 
@@ -178,24 +189,24 @@ static void add_top_level_entry()
 }
 
 
-static void clear()
+static void clear(void)
 {
 	gtk_list_store_clear(file_store);
 
-	// reset the directory item pointer
+	/* reset the directory item pointer */
 	if (last_dir_iter != NULL)
 		gtk_tree_iter_free(last_dir_iter);
 	last_dir_iter = NULL;
 }
 
 
-// recreate the tree model from current_dir.
-static void refresh()
+/* recreate the tree model from current_dir. */
+static void refresh(void)
 {
 	gchar *utf8_dir;
 	GSList *list;
 
-	// don't clear when the new path doesn't exist
+	/* don't clear when the new path doesn't exist */
 	if (! g_file_test(current_dir, G_FILE_TEST_EXISTS))
 		return;
 
@@ -217,14 +228,14 @@ static void refresh()
 }
 
 
-static void on_go_home()
+static void on_go_home(void)
 {
 	setptr(current_dir, g_strdup(g_get_home_dir()));
 	refresh();
 }
 
 
-static gchar *get_default_dir()
+static gchar *get_default_dir(void)
 {
 	const gchar *dir = NULL;
 
@@ -237,7 +248,7 @@ static gchar *get_default_dir()
 }
 
 
-static void on_current_path()
+static void on_current_path(void)
 {
 	gchar *fname;
 	gchar *dir;
@@ -260,9 +271,9 @@ static void on_current_path()
 }
 
 
-static void on_go_up()
+static void on_go_up(void)
 {
-	// remove the highest directory part (which becomes the basename of current_dir)
+	/* remove the highest directory part (which becomes the basename of current_dir) */
 	setptr(current_dir, g_path_get_dirname(current_dir));
 	refresh();
 }
@@ -412,7 +423,7 @@ static void open_selected_files(GList *list)
 		files = g_slist_append(files, fname);
 	}
 	p_document->open_files(files, FALSE, NULL, NULL);
-	g_slist_foreach(files, (GFunc) g_free, NULL);	// free filenames
+	g_slist_foreach(files, (GFunc) g_free, NULL);	/* free filenames */
 	g_slist_free(files);
 }
 
@@ -442,7 +453,7 @@ static void on_open_clicked(GtkMenuItem *menuitem, gpointer user_data)
 	{
 		if (check_single_selection(treesel))
 		{
-			GtkTreePath *treepath = list->data;	// first selected item
+			GtkTreePath *treepath = list->data;	/* first selected item */
 
 			open_folder(treepath);
 		}
@@ -472,7 +483,7 @@ static void on_find_in_files(GtkMenuItem *menuitem, gpointer user_data)
 
 	if (is_dir)
 	{
-		GtkTreePath *treepath = list->data;	// first selected item
+		GtkTreePath *treepath = list->data;	/* first selected item */
 
 		dir = get_tree_path_filename(treepath);
 	}
@@ -495,7 +506,13 @@ static void on_hidden_files_clicked(GtkCheckMenuItem *item)
 }
 
 
-static GtkWidget *create_popup_menu()
+static void on_hide_sidebar(void)
+{
+	p_keybindings->send_command(GEANY_KEY_GROUP_VIEW, GEANY_KEYS_VIEW_SIDEBAR);
+}
+
+
+static GtkWidget *create_popup_menu(void)
 {
 	GtkWidget *item, *menu, *image;
 
@@ -545,9 +562,7 @@ static GtkWidget *create_popup_menu()
 		gtk_image_new_from_stock("gtk-close", GTK_ICON_SIZE_MENU));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
-	g_signal_connect_swapped((gpointer) item, "activate",
-		G_CALLBACK(p_keybindings->send_command),
-		GINT_TO_POINTER(GEANY_KEYS_MENU_SIDEBAR));
+	g_signal_connect((gpointer) item, "activate", G_CALLBACK(on_hide_sidebar), NULL);
 
 	return menu;
 }
@@ -573,7 +588,7 @@ static void update_popup_menu(GtkWidget *popup_menu)
 }
 
 
-// delay updating popup menu until the selection has been set
+/* delay updating popup menu until the selection has been set */
 static gboolean on_button_release(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
 {
 	if (event->button == 3)
@@ -602,7 +617,7 @@ static gboolean on_key_press(GtkWidget *widget, GdkEventKey *event, gpointer dat
 
 	if ((event->keyval == GDK_Up ||
 		event->keyval == GDK_KP_Up) &&
-		(event->state & GDK_MOD1_MASK))	// FIXME: Alt-Up doesn't seem to work!
+		(event->state & GDK_MOD1_MASK))	/* FIXME: Alt-Up doesn't seem to work! */
 		on_go_up();
 	return FALSE;
 }
@@ -629,7 +644,7 @@ static void on_path_entry_activate(GtkEntry *entry, gpointer user_data)
 }
 
 
-static void prepare_file_view()
+static void prepare_file_view(void)
 {
 	GtkCellRenderer *text_renderer, *icon_renderer;
 	GtkTreeViewColumn *column;
@@ -657,7 +672,7 @@ static void prepare_file_view()
 	gtk_widget_modify_font(file_view, pfd);
 	pango_font_description_free(pfd);
 
-	// selection handling
+	/* selection handling */
 	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(file_view));
 	gtk_tree_selection_set_mode(select, GTK_SELECTION_MULTIPLE);
 
@@ -671,7 +686,7 @@ static void prepare_file_view()
 }
 
 
-static GtkWidget *make_toolbar()
+static GtkWidget *make_toolbar(void)
 {
 	GtkWidget *wid, *toolbar;
 	GtkTooltips *tooltips = GTK_TOOLTIPS(p_support->lookup_widget(
@@ -721,8 +736,8 @@ static gboolean completion_match_func(GtkEntryCompletion *completion, const gcha
 	if (str != NULL && icon != NULL && p_utils->str_equal(icon, GTK_STOCK_DIRECTORY) &&
 		! g_str_has_suffix(key, G_DIR_SEPARATOR_S))
 	{
-		// key is something like "/tmp/te" and str is a filename like "test",
-		// so strip the path from key to make them comparable
+		/* key is something like "/tmp/te" and str is a filename like "test",
+		 * so strip the path from key to make them comparable */
 		gchar *base_name = g_path_get_basename(key);
 		gchar *str_lowered = g_utf8_strdown(str, -1);
 		result = g_str_has_prefix(str_lowered, base_name);
@@ -746,7 +761,7 @@ static gboolean completion_match_selected(GtkEntryCompletion *widget, GtkTreeMod
 		gchar *text = g_strconcat(current_dir, G_DIR_SEPARATOR_S, str, NULL);
 		gtk_entry_set_text(GTK_ENTRY(path_entry), text);
 		gtk_editable_set_position(GTK_EDITABLE(path_entry), -1);
-		// force change of directory when completion is done
+		/* force change of directory when completion is done */
 		on_path_entry_activate(GTK_ENTRY(path_entry), NULL);
 		g_free(text);
 	}
@@ -756,7 +771,7 @@ static gboolean completion_match_selected(GtkEntryCompletion *widget, GtkTreeMod
 }
 
 
-static void completion_create()
+static void completion_create(void)
 {
 	entry_completion = gtk_entry_completion_new();
 
@@ -781,13 +796,49 @@ static void completion_create()
 	else \
 		(var) = (tmp);
 
-void init(GeanyData *data)
+static void load_settings(void)
 {
-	GtkWidget *scrollwin, *toolbar;
 	GKeyFile *config = g_key_file_new();
 	GError *error = NULL;
 	gboolean tmp;
 
+	config_file = g_strconcat(app->configdir, G_DIR_SEPARATOR_S, "plugins", G_DIR_SEPARATOR_S,
+		"filebrowser", G_DIR_SEPARATOR_S, "filebrowser.conf", NULL);
+	g_key_file_load_from_file(config, config_file, G_KEY_FILE_NONE, NULL);
+	open_cmd = g_key_file_get_string(config, "filebrowser", "open_command", &error);
+	if (error != NULL)
+	{
+		open_cmd = g_strdup("nautilus \"%d\"");
+		g_error_free(error);
+		error = NULL;
+	}
+	tmp = g_key_file_get_boolean(config, "filebrowser", "show_hidden_files", &error);
+	CHECK_READ_SETTING(show_hidden_files, error, tmp);
+	tmp = g_key_file_get_boolean(config, "filebrowser", "hide_object_files", &error);
+	CHECK_READ_SETTING(hide_object_files, error, tmp);
+
+	g_key_file_free(config);
+}
+
+
+static void kb_activate(guint key_id)
+{
+	switch (key_id)
+	{
+		case KB_FOCUS_FILE_LIST:
+			gtk_widget_grab_focus(file_view);
+			break;
+		case KB_FOCUS_PATH_ENTRY:
+			gtk_widget_grab_focus(path_entry);
+			break;
+	}
+}
+
+
+void init(GeanyData *data)
+{
+	GtkWidget *scrollwin, *toolbar;
+
 	file_view_vbox = gtk_vbox_new(FALSE, 0);
 	toolbar = make_toolbar();
 	gtk_box_pack_start(GTK_BOX(file_view_vbox), toolbar, FALSE, FALSE, 0);
@@ -811,22 +862,13 @@ void init(GeanyData *data)
 	gtk_notebook_append_page(GTK_NOTEBOOK(app->treeview_notebook), file_view_vbox,
 		gtk_label_new(_("Files")));
 
-	config_file = g_strconcat(app->configdir, G_DIR_SEPARATOR_S, "plugins", G_DIR_SEPARATOR_S,
-		"filebrowser", G_DIR_SEPARATOR_S, "filebrowser.conf", NULL);
-	g_key_file_load_from_file(config, config_file, G_KEY_FILE_NONE, NULL);
-	open_cmd = g_key_file_get_string(config, "filebrowser", "open_command", &error);
-	if (error != NULL)
-	{
-		open_cmd = g_strdup("nautilus \"%d\"");
-		g_error_free(error);
-		error = NULL;
-	}
-	tmp = g_key_file_get_boolean(config, "filebrowser", "show_hidden_files", &error);
-	CHECK_READ_SETTING(show_hidden_files, error, tmp);
-	tmp = g_key_file_get_boolean(config, "filebrowser", "hide_object_files", &error);
-	CHECK_READ_SETTING(hide_object_files, error, tmp);
+	load_settings();
 
-	g_key_file_free(config);
+	/* setup keybindings */
+	p_keybindings->set_item(plugin_key_group, KB_FOCUS_FILE_LIST, kb_activate,
+		0, 0, "focus_file_list", _("Focus File List"), NULL);
+	p_keybindings->set_item(plugin_key_group, KB_FOCUS_PATH_ENTRY, kb_activate,
+		0, 0, "focus_path_entry", _("Focus Path Entry"), NULL);
 }
 
 
@@ -842,7 +884,7 @@ void configure(GtkWidget *parent)
 	gtk_widget_set_name(dialog, "GeanyDialog");
 	gtk_box_set_spacing(GTK_BOX(vbox), 6);
 
-	label = gtk_label_new("External open command:");
+	label = gtk_label_new(_("External open command:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 	gtk_container_add(GTK_CONTAINER(vbox), label);
 
@@ -874,7 +916,7 @@ void configure(GtkWidget *parent)
 
 	gtk_widget_show_all(vbox);
 
-	// run the dialog and check for the response code
+	/* run the dialog and check for the response code */
 	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
 	{
 		GKeyFile *config = g_key_file_new();
@@ -899,13 +941,13 @@ void configure(GtkWidget *parent)
 		}
 		else
 		{
-			// write config to file
+			/* write config to file */
 			data = g_key_file_to_data(config, NULL, NULL);
 			p_utils->write_file(config_file, data);
 			g_free(data);
 		}
 
-		// apply the changes
+		/* apply the changes */
 		refresh();
 
 		g_free(config_dir);
@@ -915,7 +957,7 @@ void configure(GtkWidget *parent)
 }
 
 
-void cleanup()
+void cleanup(void)
 {
 	g_free(config_file);
 	g_free(open_cmd);
