@@ -19,7 +19,7 @@
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *      MA 02110-1301, USA.
  *
- * $Id: htmlchars.c 2195 2008-01-28 17:27:39Z ntrel $
+ * $Id: htmlchars.c 2411 2008-03-26 17:10:18Z ntrel $
  */
 
 /* HTML Characters plugin (Inserts HTML character entities like '&amp;') */
@@ -28,6 +28,7 @@
 #include "support.h"
 #include "plugindata.h"
 #include "document.h"
+#include "keybindings.h"
 #include "pluginmacros.h"
 
 
@@ -35,12 +36,22 @@ PluginFields	*plugin_fields;
 GeanyData		*geany_data;
 
 
-VERSION_CHECK(7)
+PLUGIN_VERSION_CHECK(48)
 
 PLUGIN_INFO(_("HTML Characters"), _("Inserts HTML character entities like '&amp;'."), VERSION,
 	_("The Geany developer team"))
 
 
+/* Keybinding(s) */
+enum
+{
+	KB_INSERT_HTML_CHARS,
+	KB_COUNT
+};
+
+PLUGIN_KEY_GROUP(html_chars, KB_COUNT)
+
+
 enum
 {
 	COLUMN_CHARACTER,
@@ -61,7 +72,7 @@ static void sc_fill_store(GtkTreeStore *store);
 static gboolean sc_insert(GtkTreeModel *model, GtkTreeIter *iter);
 
 
-static void tools_show_dialog_insert_special_chars()
+static void tools_show_dialog_insert_special_chars(void)
 {
 	if (sc_dialog == NULL)
 	{
@@ -79,7 +90,7 @@ static void tools_show_dialog_insert_special_chars()
 		gtk_widget_set_name(sc_dialog, "GeanyDialog");
 
 		height = GEANY_WINDOW_MINIMAL_HEIGHT;
-		gtk_window_set_default_size(GTK_WINDOW(sc_dialog), height * 0.8, height);
+		gtk_window_set_default_size(GTK_WINDOW(sc_dialog), height * 8 / 10, height);
 		gtk_dialog_set_default_response(GTK_DIALOG(sc_dialog), GTK_RESPONSE_CANCEL);
 
 		label = gtk_label_new(_("Choose a special character from the list below and double click on it or use the button to insert it at the current cursor position."));
@@ -124,15 +135,15 @@ static void tools_show_dialog_insert_special_chars()
 
 		sc_fill_store(sc_store);
 
-		//gtk_tree_view_expand_all(special_characters_tree);
+		/*gtk_tree_view_expand_all(special_characters_tree);*/
 		gtk_tree_view_set_search_column(sc_tree, COLUMN_HTML_NAME);
 	}
 	gtk_widget_show_all(sc_dialog);
 }
 
 
-// fill the tree model with data
-/// TODO move this in a file and make it extendable for more data types
+/* fill the tree model with data
+ ** TODO move this in a file and make it extendable for more data types */
 static void sc_fill_store(GtkTreeStore *store)
 {
 	GtkTreeIter iter;
@@ -405,14 +416,14 @@ static void sc_fill_store(GtkTreeStore *store)
 	for (i = 0; i < G_N_ELEMENTS(chars); i++)
 	{
 		if (chars[i][1] == NULL)
-		{	// add a category
+		{	/* add a category */
 			gtk_tree_store_append(store, &iter, NULL);
 			gtk_tree_store_set(store, &iter, COLUMN_CHARACTER, chars[i][0], -1);
 			if (parent_iter != NULL) gtk_tree_iter_free(parent_iter);
 			parent_iter = gtk_tree_iter_copy(&iter);
 		}
 		else
-		{	// add child to parent_iter
+		{	/* add child to parent_iter */
 			gtk_tree_store_append(store, &iter, parent_iter);
 			gtk_tree_store_set(store, &iter, COLUMN_CHARACTER, chars[i][0],
 											 COLUMN_HTML_NAME, chars[i][1], -1);
@@ -458,7 +469,7 @@ static void sc_on_tools_show_dialog_insert_special_chars_response(GtkDialog *dia
 
 		if (gtk_tree_selection_get_selected(selection, &model, &iter))
 		{
-			// only hide dialog if selection was not a category
+			/* only hide dialog if selection was not a category */
 			if (sc_insert(model, &iter))
 				gtk_widget_hide(GTK_WIDGET(dialog));
 		}
@@ -476,11 +487,11 @@ static void sc_on_tree_row_activated(GtkTreeView *treeview, GtkTreePath *path,
 
 	if (gtk_tree_model_get_iter(model, &iter, path))
 	{
-		// only hide dialog if selection was not a category
+		/* only hide dialog if selection was not a category */
 		if (sc_insert(model, &iter))
 			gtk_widget_hide(sc_dialog);
 		else
-		{	// double click on a category to toggle the expand or collapse it
+		{	/* double click on a category to toggle the expand or collapse it */
 			if (gtk_tree_view_row_expanded(sc_tree, path))
 				gtk_tree_view_collapse_row(sc_tree, path);
 			else
@@ -494,7 +505,7 @@ static void sc_on_tree_row_activated(GtkTreeView *treeview, GtkTreePath *path,
 static void
 item_activate(GtkMenuItem *menuitem, gpointer gdata)
 {
-	// refuse opening the dialog if we don't have an active tab
+	/* refuse opening the dialog if we don't have an active tab */
 	gint idx = p_document->get_cur_idx();
 
 	if (idx == -1 || ! doc_list[idx].is_valid) return;
@@ -503,25 +514,37 @@ item_activate(GtkMenuItem *menuitem, gpointer gdata)
 }
 
 
+static void kb_activate(G_GNUC_UNUSED guint key_id)
+{
+	item_activate(NULL, NULL);
+}
+
+
 /* Called by Geany to initialize the plugin */
 void init(GeanyData *data)
 {
 	GtkWidget *demo_item;
+	const gchar *menu_text = _("_Insert Special HTML Characters");
+	gchar *kb_label = _("Insert Special HTML Characters");
 
-	// Add an item to the Tools menu
-	demo_item = gtk_menu_item_new_with_mnemonic(_("_Insert Special HTML Characters"));
+	/* Add an item to the Tools menu */
+	demo_item = gtk_menu_item_new_with_mnemonic(menu_text);
 	gtk_widget_show(demo_item);
 	gtk_container_add(GTK_CONTAINER(geany_data->tools_menu), demo_item);
 	g_signal_connect(G_OBJECT(demo_item), "activate", G_CALLBACK(item_activate), NULL);
 
-	// disable menu_item when there are no documents open
+	/* disable menu_item when there are no documents open */
 	plugin_fields->menu_item = demo_item;
 	plugin_fields->flags = PLUGIN_IS_DOCUMENT_SENSITIVE;
+
+	/* setup keybindings */
+	p_keybindings->set_item(plugin_key_group, KB_INSERT_HTML_CHARS, kb_activate,
+		0, 0, "insert_html_chars", kb_label, demo_item);
 }
 
 
 /* Destroy widgets */
-void cleanup()
+void cleanup(void)
 {
 	gtk_widget_destroy(plugin_fields->menu_item);
 
