@@ -19,6 +19,10 @@
 #include "Scintilla.h"
 #include "SciLexer.h"
 
+#ifdef SCI_NAMESPACE
+using namespace Scintilla;
+#endif
+
 const LexerModule *LexerModule::base = 0;
 int LexerModule::nextLanguage = SCLEX_AUTOMATIC+1;
 
@@ -138,37 +142,37 @@ int Scintilla_LinkLexers() {
 //++Autogenerated -- run src/LexGen.py to regenerate
 //**\(\tLINK_LEXER(\*);\n\)
 	LINK_LEXER(lmAsm);
-	LINK_LEXER(lmBash);
-	LINK_LEXER(lmOMS);
-	LINK_LEXER(lmCaml);
-	LINK_LEXER(lmFortran);
-	LINK_LEXER(lmPython);
-	LINK_LEXER(lmBatch);
-	LINK_LEXER(lmDiff);
-	LINK_LEXER(lmProps);
-	LINK_LEXER(lmMake);
-	LINK_LEXER(lmErrorList);
-	LINK_LEXER(lmLatex);
-	LINK_LEXER(lmNull);
-	LINK_LEXER(lmPascal);
-	LINK_LEXER(lmConf);
-	LINK_LEXER(lmNncrontab);
-	LINK_LEXER(lmHTML);
-	LINK_LEXER(lmXML);
 	LINK_LEXER(lmASP);
-	LINK_LEXER(lmPHP);
-	LINK_LEXER(lmPHPSCRIPT);
-	LINK_LEXER(lmCss);
+	LINK_LEXER(lmBash);
+	LINK_LEXER(lmFreeBasic);
+	LINK_LEXER(lmBatch);
+	LINK_LEXER(lmCaml);
 	LINK_LEXER(lmCPP);
 	LINK_LEXER(lmCPPNoCase);
+	LINK_LEXER(lmCss);
+	LINK_LEXER(lmD);
+	LINK_LEXER(lmDiff);
+	LINK_LEXER(lmErrorList);
+	LINK_LEXER(lmFortran);
+	LINK_LEXER(lmHaskell);
+	LINK_LEXER(lmHTML);
+	LINK_LEXER(lmLatex);
+	LINK_LEXER(lmLua);
+	LINK_LEXER(lmMake);
+	LINK_LEXER(lmNncrontab);
+	LINK_LEXER(lmNull);
+	LINK_LEXER(lmOMS);
+	LINK_LEXER(lmPascal);
 	LINK_LEXER(lmPerl);
+	LINK_LEXER(lmPHP);
+	LINK_LEXER(lmPHPSCRIPT);
+	LINK_LEXER(lmProps);
+	LINK_LEXER(lmPython);
 	LINK_LEXER(lmRuby);
 	LINK_LEXER(lmSQL);
 	LINK_LEXER(lmTCL);
 	LINK_LEXER(lmVHDL);
-	LINK_LEXER(lmD);
-	LINK_LEXER(lmLua);
-	LINK_LEXER(lmHaskell);
+	LINK_LEXER(lmXML);
 
 //--Autogenerated -- end of automatically generated section
 
