@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: about.c 2183 2008-01-22 15:19:36Z eht16 $
+ * $Id: about.c 2498 2008-04-18 11:37:37Z frlan $
  */
 
 /*
@@ -54,11 +54,12 @@ const gchar *translators[][2] = {
 	{ "fr", "Jean-Philippe Moal &lt;skateinmars@skateinmars.net&gt;" },
 	{ "hu", "Gabor Kmetyko &lt;kg_kilo@freemail.hu&gt;" },
 	{ "it", "Max Baldinelli &lt;m.baldinelli@agora.it&gt;,\nDario Santomarco &lt;dariello@yahoo.it&gt;" },
-	{ "ja", "Tarot Osuji &lt;tarot@sdf.lonestar.org&gt;"},
+	{ "ja", "Tarot Osuji &lt;tarot@sdf.lonestar.org&gt;\nChikahiro Masami &lt;cmasa.z321@gmail.com&gt;" },
 	{ "nl", "Kurt De Bree &lt;kdebree@telenet.be&gt;" },
 	{ "pl_PL", "Jarosław Foksa &lt;jfoksa@gmail.com&gt;" },
 	{ "pt_BR", "Alexandra Moreire &lt;alexandream@gmail.com&gt;\nAdrovane Marques Kade &lt;adrovane@gmail.com&gt;" },
-	{ "ru_RU", "brahmann_ &lt;brahmann@mthr.net.ru&gt;" },
+	{ "ro", "Alex Eftimie &lt;alex@rosedu.org&gt;" },
+	{ "ru_RU", "brahmann_ &lt;brahmann@pisem.net&gt;,\nNikita E. Shalaev &lt;nshalaev@eu.spb.ru&gt;" },
 	{ "sv", "Tony Mattsson &lt;superxorn@gmail.com&gt;" },
 	{ "uk", "Boris Dibrov &lt;dibrov.bor@gmail.com&gt;" },
 	{ "vi_VN", "Clytie Siddall &lt;clytie@riverland.net.au&gt;" },
@@ -116,7 +117,7 @@ static GtkWidget *create_dialog(void)
 
 	dialog = gtk_dialog_new();
 
-	// configure dialog
+	/* configure dialog */
 	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(app->window));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 	gtk_window_set_title(GTK_WINDOW(dialog), _("About Geany"));
@@ -126,7 +127,7 @@ static GtkWidget *create_dialog(void)
 	gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
 	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(gb_on_key_pressed), NULL);
 
-	// create header
+	/* create header */
 	header_eventbox = gtk_event_box_new();
 	gtk_widget_show(header_eventbox);
 	header_hbox = gtk_hbox_new(FALSE, 12);
@@ -137,7 +138,7 @@ static GtkWidget *create_dialog(void)
 	gtk_box_pack_start(GTK_BOX(header_hbox), header_image, FALSE,FALSE,0);
 	header_label = gtk_label_new(NULL);
 	gtk_label_set_use_markup(GTK_LABEL(header_label), TRUE);
-	// print the subversion revision generated by ./configure if it is available
+	/* print the subversion revision generated by ./configure if it is available */
 	g_snprintf(buffer, sizeof(buffer), HEADER,
 		(utils_str_equal(REVISION, "-1")) ? "" : "svn >= " REVISION);
 	gtk_label_set_markup(GTK_LABEL(header_label), buffer);
@@ -149,19 +150,19 @@ static GtkWidget *create_dialog(void)
 	g_signal_connect_after(G_OBJECT(header_label), "style_set", G_CALLBACK(header_label_style_set), NULL);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), header_eventbox, FALSE, FALSE, 0);
 
-	// set image
+	/* set image */
 	icon = ui_new_pixbuf_from_inline(GEANY_IMAGE_LOGO, FALSE);
 	gtk_image_set_from_pixbuf(GTK_IMAGE(header_image), icon);
 	gtk_window_set_icon(GTK_WINDOW(dialog), icon);
-	g_object_unref(icon);	// free our reference
+	g_object_unref(icon);	/* free our reference */
 
-	// create notebook
+	/* create notebook */
 	notebook = gtk_notebook_new();
 	gtk_widget_show(notebook);
 	gtk_container_set_border_width(GTK_CONTAINER(notebook), 2);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), notebook, TRUE, TRUE, 0);
 
-	// create "Info" tab
+	/* create "Info" tab */
 	info_box = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(info_box), 6);
 	gtk_widget_show(info_box);
@@ -176,7 +177,7 @@ static GtkWidget *create_dialog(void)
 	gtk_widget_show(label_info);
 	gtk_box_pack_start(GTK_BOX(info_box), label_info, FALSE, FALSE, 0);
 
-	// Codename label
+	/* Codename label */
 	codename_label = gtk_label_new(NULL);
 	gtk_label_set_justify(GTK_LABEL(codename_label), GTK_JUSTIFY_CENTER);
 	gtk_label_set_selectable(GTK_LABEL(codename_label), TRUE);
@@ -186,7 +187,7 @@ static GtkWidget *create_dialog(void)
 	gtk_widget_show(codename_label);
 	gtk_box_pack_start(GTK_BOX(info_box), codename_label, FALSE, FALSE, 0);
 
-	// build date label
+	/* build date label */
 	builddate_label = gtk_label_new(NULL);
 	gtk_label_set_justify(GTK_LABEL(builddate_label), GTK_JUSTIFY_CENTER);
 	gtk_label_set_selectable(GTK_LABEL(builddate_label), TRUE);
@@ -211,7 +212,7 @@ static GtkWidget *create_dialog(void)
 	gtk_widget_show(box);
 	gtk_box_pack_start(GTK_BOX(info_box), box, FALSE, FALSE, 10);
 
-	// copyright label
+	/* copyright label */
 	cop_label = gtk_label_new(NULL);
 	gtk_label_set_justify(GTK_LABEL(cop_label), GTK_JUSTIFY_CENTER);
 	gtk_label_set_selectable(GTK_LABEL(cop_label), FALSE);
@@ -220,14 +221,14 @@ static GtkWidget *create_dialog(void)
 	gtk_misc_set_padding(GTK_MISC(cop_label), 2, 10);
 	gtk_widget_show(cop_label);
 	gtk_box_pack_start(GTK_BOX(info_box), cop_label, FALSE, FALSE, 0);
-	//gtk_container_add(GTK_CONTAINER(info_box), cop_label);
+	/*gtk_container_add(GTK_CONTAINER(info_box), cop_label); */
 
 	label = gtk_label_new(_("Info"));
 	gtk_widget_show(label);
 	gtk_widget_show_all(info_box);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), info_box, label);
 
-	// create "Credits" tab
+	/* create "Credits" tab */
 	credits_scrollwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_container_set_border_width(GTK_CONTAINER(credits_scrollwin), 10);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(credits_scrollwin),
@@ -315,7 +316,7 @@ static GtkWidget *create_dialog(void)
 	gtk_widget_show(label);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), credits_scrollwin, label);
 
-	// create "License" tab
+	/* create "License" tab */
 	license_scrollwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_container_set_border_width(GTK_CONTAINER(license_scrollwin), 6);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(license_scrollwin),
