@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: callbacks.c 2190 2008-01-25 13:14:38Z ntrel $
+ * $Id: callbacks.c 2490 2008-04-16 12:00:27Z ntrel $
  */
 
 /*
@@ -75,25 +75,22 @@
 #endif
 
 
-// represents the state while closing all tabs(used to prevent notebook switch page signals)
-static gboolean closing_all = FALSE;
-
-// flag to indicate the explicit change of a toggle button of the toolbar menu and so the
-// toggled callback should ignore the change since it is not triggered by the user
+/* flag to indicate the explicit change of a toggle button of the toolbar menu and so the
+ * toggled callback should ignore the change since it is not triggered by the user */
 static gboolean ignore_toolbar_toggle = FALSE;
 
-// flag to indicate that an insert callback was triggered from the file menu,
-// so we need to store the current cursor position in editor_info.click_pos.
+/* flag to indicate that an insert callback was triggered from the file menu,
+ * so we need to store the current cursor position in editor_info.click_pos. */
 static gboolean insert_callback_from_menu = FALSE;
 
-// represents the state at switching a notebook page(in the left treeviews widget), to not emit
-// the selection-changed signal from tv.tree_openfiles
-//static gboolean switch_tv_notebook_page = FALSE;
+/* represents the state at switching a notebook page(in the left treeviews widget), to not emit
+ * the selection-changed signal from tv.tree_openfiles */
+/*static gboolean switch_tv_notebook_page = FALSE; */
 
 CallbacksData callbacks_data = {-1};
 
 
-static gboolean check_no_unsaved()
+static gboolean check_no_unsaved(void)
 {
 	guint i;
 
@@ -104,11 +101,12 @@ static gboolean check_no_unsaved()
 			return FALSE;
 		}
 	}
-	return TRUE;	// no unsaved edits
+	return TRUE;	/* no unsaved edits */
 }
 
 
-static gboolean account_for_unsaved()
+/* @return TRUE if all files were saved or had their changes discarded. */
+static gboolean account_for_unsaved(void)
 {
 	gint p;
 
@@ -126,8 +124,8 @@ static gboolean account_for_unsaved()
 }
 
 
-// set editor_info.click_pos to the current cursor position if insert_callback_from_menu is TRUE
-// to prevent invalid cursor positions which can cause segfaults
+/* set editor_info.click_pos to the current cursor position if insert_callback_from_menu is TRUE
+ * to prevent invalid cursor positions which can cause segfaults */
 static void verify_click_pos(gint idx)
 {
 	if (insert_callback_from_menu)
@@ -138,31 +136,44 @@ static void verify_click_pos(gint idx)
 }
 
 
-// should only be called from on_exit_clicked
-static void quit_app()
+static void force_close_all()
 {
-	guint i;
+	guint i, len = doc_array->len;
 
-	configuration_save();
+	main_status.closing_all = TRUE;
 
-	// ignore changes for all tabs (already asked user in on_exit_clicked)
-	for (i = 0; i < doc_array->len; i++)
+	/* all documents should be accounted for, so ignore any changes */
+	for (i = 0; i < len; i++)
 	{
 		if (doc_list[i].is_valid && doc_list[i].changed)
 		{
 			doc_list[i].changed = FALSE;
 		}
 	}
-	if (app->project != NULL)
-		project_close(FALSE);	// save project session files
+	while (gtk_notebook_get_n_pages(GTK_NOTEBOOK(app->notebook)) > 0)
+	{
+		document_remove(0);
+	}
 
-	on_close_all1_activate(NULL, NULL);
+	main_status.closing_all = FALSE;
+}
+
+
+/* should only be called from on_exit_clicked */
+static void quit_app(void)
+{
+	configuration_save();
+
+	if (app->project != NULL)
+		project_close(FALSE);	/* save project session files */
+
+	force_close_all();
 
 	main_quit();
 }
 
 
-// wrapper function to abort exit process if cancel button is pressed
+/* wrapper function to abort exit process if cancel button is pressed */
 gboolean
 on_exit_clicked                        (GtkWidget *widget, gpointer gdata)
 {
@@ -234,7 +245,7 @@ on_save_all1_activate                  (GtkMenuItem     *menuitem,
 	gint i, idx, max = gtk_notebook_get_n_pages(GTK_NOTEBOOK(app->notebook));
 	gint cur_idx = document_get_cur_idx();
 
-	document_delay_colourise();	// avoid recolourising all C files after each save
+	document_delay_colourise();	/* avoid recolourising all C files after each save */
 
 	for (i = 0; i < max; i++)
 	{
@@ -242,7 +253,7 @@ on_save_all1_activate                  (GtkMenuItem     *menuitem,
 		if (! doc_list[idx].changed) continue;
 		if (doc_list[idx].file_name == NULL)
 		{
-			// display unnamed document
+			/* display unnamed document */
 			gtk_notebook_set_current_page(GTK_NOTEBOOK(app->notebook),
 				document_get_notebook_page(idx));
 			dialogs_show_save_as();
@@ -256,26 +267,23 @@ on_save_all1_activate                  (GtkMenuItem     *menuitem,
 }
 
 
-gboolean
+static gboolean close_all(void)
+{
+	if (! account_for_unsaved())
+		return FALSE;
+
+	force_close_all();
+
+	tm_workspace_update(TM_WORK_OBJECT(app->tm_workspace), TRUE, TRUE, FALSE);
+	return TRUE;
+}
+
+
+void
 on_close_all1_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	gboolean ret = TRUE;
-	gint i, max = gtk_notebook_get_n_pages(GTK_NOTEBOOK(app->notebook));
-
-	closing_all = TRUE;
-	for(i = 0; i < max; i++)
-	{
-		if (! document_remove(0))
-		{
-			ret = FALSE;
-			break;
-		}
-	}
-	closing_all = FALSE;
-	tm_workspace_update(TM_WORK_OBJECT(app->tm_workspace), TRUE, TRUE, FALSE);
-	// if cancel is clicked, cancel the complete exit process
-	return ret;
+	close_all();
 }
 
 
@@ -303,15 +311,15 @@ on_file1_activate                      (GtkMenuItem     *menuitem,
 	gtk_widget_set_sensitive(ui_widgets.recent_files_menuitem,
 						g_queue_get_length(ui_prefs.recent_queue) > 0);
 #if GTK_CHECK_VERSION(2, 10, 0)
-	// hide Page setup when GTK printing is not used
-	// (on GTK < 2.10 the menu item is hidden completely)
+	/* hide Page setup when GTK printing is not used
+	 * (on GTK < 2.10 the menu item is hidden completely) */
 	ui_widget_show_hide(ui_widgets.print_page_setup,
 		printing_prefs.use_gtk_printing || gtk_check_version(2, 10, 0) != NULL);
 #endif
 }
 
 
-// edit actions, c&p & co, from menu bar and from popup menu
+/* edit actions, c&p & co, from menu bar and from popup menu */
 void
 on_edit1_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -398,9 +406,11 @@ on_paste1_activate                     (GtkMenuItem     *menuitem,
 	else
 	if (IS_SCINTILLA(focusw) && idx >= 0)
 	{
-#ifdef G_OS_WIN32
-		// insert the text manually for now, because the auto conversion of EOL characters by
-		// by Scintilla seems to make problems
+#if 0
+//#ifdef G_OS_WIN32
+		/* insert the text manually for now, because the auto conversion of EOL characters by
+		 * by Scintilla seems to make problems */
+		/** TODO this is probably obsolete now since we fixed PLAT_GTK_WIN32 in Scintilla */
 		if (gtk_clipboard_wait_is_text_available(gtk_clipboard_get(GDK_NONE)))
 		{
 			gchar *content = gtk_clipboard_wait_for_text(gtk_clipboard_get(GDK_NONE));
@@ -455,7 +465,7 @@ on_preferences1_activate               (GtkMenuItem     *menuitem,
 }
 
 
-// about menu item
+/* about menu item */
 void
 on_info1_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -464,7 +474,7 @@ on_info1_activate                      (GtkMenuItem     *menuitem,
 }
 
 
-// open file
+/* open file */
 void
 on_open1_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -473,7 +483,7 @@ on_open1_activate                      (GtkMenuItem     *menuitem,
 }
 
 
-// quit toolbar button
+/* quit toolbar button */
 void
 on_toolbutton19_clicked                (GtkToolButton   *toolbutton,
                                         gpointer         user_data)
@@ -482,7 +492,7 @@ on_toolbutton19_clicked                (GtkToolButton   *toolbutton,
 }
 
 
-// reload file
+/* reload file */
 void
 on_toolbutton23_clicked                (GtkToolButton   *toolbutton,
                                         gpointer         user_data)
@@ -491,7 +501,7 @@ on_toolbutton23_clicked                (GtkToolButton   *toolbutton,
 }
 
 
-// also used for reloading when user_data is -1
+/* also used for reloading when user_data is -1 */
 void
 on_reload_as_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -563,7 +573,7 @@ on_change_font1_activate               (GtkMenuItem     *menuitem,
 }
 
 
-// new file
+/* new file */
 void
 on_toolbutton8_clicked                 (GtkToolButton   *toolbutton,
                                         gpointer         user_data)
@@ -571,7 +581,7 @@ on_toolbutton8_clicked                 (GtkToolButton   *toolbutton,
 	document_new_file(NULL, NULL, NULL);
 }
 
-// open file
+/* open file */
 void
 on_toolbutton9_clicked                 (GtkToolButton   *toolbutton,
                                         gpointer         user_data)
@@ -580,7 +590,7 @@ on_toolbutton9_clicked                 (GtkToolButton   *toolbutton,
 }
 
 
-// save file
+/* save file */
 void
 on_toolbutton10_clicked                (GtkToolButton   *toolbutton,
                                         gpointer         user_data)
@@ -596,7 +606,7 @@ static void set_search_bar_background(gboolean success)
 	static gboolean old_value = TRUE;
 	GtkWidget *widget = lookup_widget(app->window, "entry1");
 
-	// only update if really needed
+	/* only update if really needed */
 	if (search_data.search_bar && old_value != success)
 	{
 		gtk_widget_modify_base(widget, GTK_STATE_NORMAL, success ? NULL : &red);
@@ -607,7 +617,7 @@ static void set_search_bar_background(gboolean success)
 }
 
 
-// store text, clear search flags so we can use Search->Find Next/Previous
+/* store text, clear search flags so we can use Search->Find Next/Previous */
 static void setup_find_next(GtkEditable *editable)
 {
 	g_free(search_data.text);
@@ -618,7 +628,7 @@ static void setup_find_next(GtkEditable *editable)
 }
 
 
-// search text
+/* search text */
 void
 on_entry1_activate                     (GtkEntry        *entry,
                                         gpointer         user_data)
@@ -632,7 +642,7 @@ on_entry1_activate                     (GtkEntry        *entry,
 }
 
 
-// search text
+/* search text */
 void
 on_entry1_changed                      (GtkEditable     *editable,
                                         gpointer         user_data)
@@ -646,21 +656,7 @@ on_entry1_changed                      (GtkEditable     *editable,
 }
 
 
-gboolean
-on_entry1_key_press_event              (GtkWidget       *widget,
-                                        GdkEventKey     *event,
-                                        gpointer         user_data)
-{
-	if (event->keyval == GDK_Escape)
-	{
-		keybindings_cmd(GEANY_KEYS_SWITCH_EDITOR);
-		return TRUE;
-	}
-	return FALSE;
-}
-
-
-// search text
+/* search text */
 void
 on_toolbutton18_clicked                (GtkToolButton   *toolbutton,
                                         gpointer         user_data)
@@ -697,7 +693,7 @@ on_toolbar_small_icons1_activate       (GtkMenuItem     *menuitem,
 }
 
 
-// hides toolbar from toolbar popup menu
+/* hides toolbar from toolbar popup menu */
 void
 on_hide_toolbar1_activate              (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -707,7 +703,7 @@ on_hide_toolbar1_activate              (GtkMenuItem     *menuitem,
 }
 
 
-// zoom in from menu bar and popup menu
+/* zoom in from menu bar and popup menu */
 void
 on_zoom_in1_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -723,7 +719,7 @@ on_zoom_in1_activate                   (GtkMenuItem     *menuitem,
 	}
 }
 
-// zoom out from menu bar and popup menu
+/* zoom out from menu bar and popup menu */
 void
 on_zoom_out1_activate                   (GtkMenuItem     *menuitem,
                                          gpointer         user_data)
@@ -751,7 +747,7 @@ on_normal_size1_activate               (GtkMenuItem     *menuitem,
 }
 
 
-// close tab
+/* close tab */
 void
 on_toolbutton15_clicked                (GtkToolButton   *toolbutton,
                                         gpointer         user_data)
@@ -771,7 +767,7 @@ on_notebook1_switch_page               (GtkNotebook     *notebook,
 }
 
 
-// changes window-title on switching tabs and lots of other things
+/* changes window-title on switching tabs and lots of other things */
 void
 on_notebook1_switch_page_after         (GtkNotebook     *notebook,
                                         GtkNotebookPage *page,
@@ -780,20 +776,21 @@ on_notebook1_switch_page_after         (GtkNotebook     *notebook,
 {
 	gint idx;
 
-	if (closing_all) return;
+	if (main_status.opening_session_files || main_status.closing_all)
+		return;
 
-	// guint == -1 seems useless, but it isn't!
+	/* guint == -1 seems useless, but it isn't! */
 	if (page_num == (guint) -1 && page != NULL)
 		idx = document_find_by_sci(SCINTILLA(page));
 	else
 		idx = document_get_n_idx(page_num);
 
-	if (idx >= 0 && main_status.opening_session_files == FALSE)
+	if (idx >= 0)
 	{
 		treeviews_select_openfiles_item(idx);
-		document_set_text_changed(idx);	// also sets window title and status bar
+		document_set_text_changed(idx);	/* also sets window title and status bar */
 		ui_update_popup_reundo_items(idx);
-		ui_document_show_hide(idx); // update the document menu
+		ui_document_show_hide(idx); /* update the document menu */
 		build_menu_update(idx);
 		treeviews_update_tag_list(idx, FALSE);
 
@@ -817,7 +814,7 @@ on_tv_notebook_switch_page             (GtkNotebook     *notebook,
                                         guint            page_num,
                                         gpointer         user_data)
 {
-	// suppress selection changed signal when switching to the open files list
+	/* suppress selection changed signal when switching to the open files list */
 	app->ignore_callback = TRUE;
 }
 
@@ -897,8 +894,8 @@ toolbar_popup_menu                     (GtkWidget *widget,
 		switch (prefs.toolbar_icon_size)
 		{
 			case GTK_ICON_SIZE_LARGE_TOOLBAR:
-					widget = lookup_widget(ui_widgets.toolbar_menu, "large_icons1"); break;
-			default: widget = lookup_widget(ui_widgets.toolbar_menu, "small_icons1"); break;
+					w = lookup_widget(ui_widgets.toolbar_menu, "large_icons1"); break;
+			default: w = lookup_widget(ui_widgets.toolbar_menu, "small_icons1"); break;
 		}
 		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(w), TRUE);
 
@@ -924,30 +921,49 @@ void on_toggle_case1_activate(GtkMenuItem *menuitem, gpointer user_data)
 
 	if (! sci_can_copy(sci))
 	{
-		keybindings_cmd(GEANY_KEYS_EDIT_SELECTWORD);
+		keybindings_send_command(GEANY_KEY_GROUP_SELECT, GEANY_KEYS_SELECT_WORD);
 		keep_sel = FALSE;
 	}
 
 	if (sci_can_copy(sci))
 	{
-		gchar *result;
+		gchar *result = NULL;
+		gint cmd = SCI_LOWERCASE;
 		gint text_len = sci_get_selected_text_length(sci);
+		gboolean rectsel = scintilla_send_message(sci, SCI_SELECTIONISRECTANGLE, 0, 0);
 
 		text = g_malloc(text_len + 1);
 		sci_get_selected_text(sci, text);
 
 		if (utils_str_has_upper(text))
-			result = g_utf8_strdown(text, -1);
+        {
+			if (rectsel)
+				cmd = SCI_LOWERCASE;
+			else
+				result = g_utf8_strdown(text, -1);
+
+		}
 		else
-			result = g_utf8_strup(text, -1);
+		{
+			if (rectsel)
+				cmd = SCI_UPPERCASE;
+			else
+				result = g_utf8_strup(text, -1);
 
-		sci_replace_sel(sci, result);
+		}
+
+		if (result != NULL)
+		{
+			sci_replace_sel(sci, result);
+			g_free(result);
+			if (keep_sel)
+				sci_set_selection_start(sci, sci_get_current_position(sci) - text_len + 1);
+		}
+		else
+			sci_cmd(sci, cmd);
 
-		g_free(result);
 		g_free(text);
 
-		if (keep_sel)
-			sci_set_selection_start(sci, sci_get_current_position(sci) - text_len + 1);
 	}
 }
 
@@ -1054,7 +1070,7 @@ on_find_usage1_activate                (GtkMenuItem     *menuitem,
 	if (! DOC_IDX_VALID(idx)) return;
 
 	if (sci_can_copy(doc_list[idx].sci))
-	{	// take selected text if there is a selection
+	{	/* take selected text if there is a selection */
 		search_text = g_malloc(sci_get_selected_text_length(doc_list[idx].sci) + 1);
 		sci_get_selected_text(doc_list[idx].sci, search_text);
 		flags = SCFIND_MATCHCASE;
@@ -1113,7 +1129,7 @@ void
 on_compile_button_clicked              (GtkToolButton   *toolbutton,
                                         gpointer         user_data)
 {
-	keybindings_cmd(GEANY_KEYS_BUILD_COMPILE);
+	keybindings_send_command(GEANY_KEY_GROUP_BUILD, GEANY_KEYS_BUILD_COMPILE);
 }
 
 
@@ -1125,39 +1141,43 @@ on_find1_activate                      (GtkMenuItem     *menuitem,
 }
 
 
-void
-on_find_next1_activate                 (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+static void find_again(gboolean change_direction)
 {
 	gint idx = document_get_cur_idx();
 
+	g_return_if_fail(DOC_IDX_VALID(idx));
+
 	if (search_data.text)
 	{
+		gboolean forward = ! search_data.backwards;
 		gint result = document_find_text(idx, search_data.text, search_data.flags,
-			search_data.backwards, TRUE, NULL);
+			change_direction ? forward : !forward, FALSE, NULL);
+
+		if (result > -1)
+			editor_display_current_line(idx, 0.3F);
 
 		set_search_bar_background((result > -1) ? TRUE : FALSE);
 	}
 }
 
 
+void
+on_find_next1_activate                 (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+	find_again(FALSE);
+}
+
+
 void
 on_find_previous1_activate             (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	gint idx = document_get_cur_idx();
-
-	if (search_data.text == NULL) return;
-
 	if (search_data.flags & SCFIND_REGEXP)
-		utils_beep(); // Can't reverse search order for a regex (find next ignores search backwards)
+		/* Can't reverse search order for a regex (find next ignores search backwards) */
+		utils_beep();
 	else
-	{
-		gint result = document_find_text(idx, search_data.text, search_data.flags,
-			!search_data.backwards, TRUE, NULL);
-
-		set_search_bar_background((result > -1) ? TRUE : FALSE);
-	}
+		find_again(TRUE);
 }
 
 
@@ -1249,15 +1269,6 @@ on_entry_goto_line_activate            (GtkEntry        *entry,
 }
 
 
-gboolean
-on_entry_goto_line_key_press_event     (GtkWidget       *widget,
-                                        GdkEventKey     *event,
-                                        gpointer         user_data)
-{
-	return on_entry1_key_press_event(widget, event, user_data);
-}
-
-
 void
 on_toolbutton_goto_clicked             (GtkToolButton   *toolbutton,
                                         gpointer         user_data)
@@ -1277,16 +1288,16 @@ on_help1_activate                      (GtkMenuItem     *menuitem,
 #ifdef G_OS_WIN32
 	skip = 8;
 	uri = g_strconcat("file:///", app->docdir, "/Manual.html", NULL);
-	g_strdelimit(uri, "\\", '/'); // replace '\\' by '/'
+	g_strdelimit(uri, "\\", '/'); /* replace '\\' by '/' */
 #else
 	skip = 7;
 	uri = g_strconcat("file://", app->docdir, "index.html", NULL);
 #endif
 
 	if (! g_file_test(uri + skip, G_FILE_TEST_IS_REGULAR))
-	{	// fall back to online documentation if it is not found on the hard disk
+	{	/* fall back to online documentation if it is not found on the hard disk */
 		g_free(uri);
-		uri = g_strconcat(GEANY_HOMEPAGE, "manual/index.html", NULL);
+		uri = g_strconcat(GEANY_HOMEPAGE, "manual/", VERSION, "/index.html", NULL);
 	}
 
 	utils_start_browser(uri);
@@ -1325,8 +1336,8 @@ on_comments_function_activate          (GtkMenuItem     *menuitem,
 		return;
 	}
 
-	// utils_get_current_function returns -1 on failure, so sci_get_position_from_line
-	// returns the current position, so it should be safe
+	/* utils_get_current_function returns -1 on failure, so sci_get_position_from_line
+	 * returns the current position, so it should be safe */
 	line = utils_get_current_function(idx, &cur_tag);
 	pos = sci_get_position_from_line(doc_list[idx].sci, line - 1);
 
@@ -1349,7 +1360,7 @@ on_comments_multiline_activate         (GtkMenuItem     *menuitem,
 		return;
 	}
 
-	verify_click_pos(idx); // make sure that the click_pos is valid
+	verify_click_pos(idx); /* make sure that the click_pos is valid */
 
 	editor_insert_multiline_comment(idx);
 }
@@ -1364,7 +1375,7 @@ on_comments_gpl_activate               (GtkMenuItem     *menuitem,
 
 	text = templates_get_template_licence(FILETYPE_ID(doc_list[idx].file_type), GEANY_TEMPLATE_GPL);
 
-	verify_click_pos(idx); // make sure that the click_pos is valid
+	verify_click_pos(idx); /* make sure that the click_pos is valid */
 
 	sci_insert_text(doc_list[idx].sci, editor_info.click_pos, text);
 	g_free(text);
@@ -1381,7 +1392,7 @@ on_comments_bsd_activate               (GtkMenuItem     *menuitem,
 
 	text = templates_get_template_licence(FILETYPE_ID(doc_list[idx].file_type), GEANY_TEMPLATE_BSD);
 
-	verify_click_pos(idx); // make sure that the click_pos is valid
+	verify_click_pos(idx); /* make sure that the click_pos is valid */
 
 	sci_insert_text(doc_list[idx].sci, editor_info.click_pos, text);
 	g_free(text);
@@ -1398,8 +1409,8 @@ on_comments_changelog_activate         (GtkMenuItem     *menuitem,
 
 	text = templates_get_template_changelog();
 	sci_insert_text(doc_list[idx].sci, 0, text);
-	// sets the cursor to the right position to type the changelog text,
-	// the template has 21 chars + length of name and email
+	/* sets the cursor to the right position to type the changelog text,
+	 * the template has 21 chars + length of name and email */
 	sci_goto_pos(doc_list[idx].sci, 21 + strlen(prefs.template_developer) + strlen(prefs.template_mail), TRUE);
 
 	g_free(text);
@@ -1440,8 +1451,8 @@ on_insert_date_activate                (GtkMenuItem     *menuitem,
 {
 	gint idx = document_get_cur_idx();
 	gchar *format;
-	gchar time_str[300]; // the entered format string can be maximal 256 chars long, so we have
-						 // 44 additional characters for strtime's conversion
+	gchar time_str[300]; /* the entered format string can be maximal 256 chars long, so we have
+						  * 44 additional characters for strtime's conversion */
 	time_t t;
 	struct tm *tm;
 
@@ -1463,7 +1474,7 @@ on_insert_date_activate                (GtkMenuItem     *menuitem,
 		format = ui_prefs.custom_date_format;
 	else
 	{
-		// set default value
+		/* set default value */
 		if (utils_str_equal("", ui_prefs.custom_date_format))
 		{
 			g_free(ui_prefs.custom_date_format);
@@ -1476,12 +1487,12 @@ on_insert_date_activate                (GtkMenuItem     *menuitem,
 		return;
 	}
 
-	// get the current time
+	/* get the current time */
 	t = time(NULL);
 	tm = localtime(&t);
 	if (strftime(time_str, sizeof time_str, format, tm) != 0)
 	{
-		verify_click_pos(idx); // make sure that the click_pos is valid
+		verify_click_pos(idx); /* make sure that the click_pos is valid */
 
 		sci_insert_text(doc_list[idx].sci, editor_info.click_pos, time_str);
 		sci_goto_pos(doc_list[idx].sci, editor_info.click_pos + strlen(time_str), FALSE);
@@ -1505,7 +1516,7 @@ on_insert_include_activate             (GtkMenuItem     *menuitem,
 
 	if (! DOC_IDX_VALID(idx) || user_data == NULL) return;
 
-	verify_click_pos(idx); // make sure that the click_pos is valid
+	verify_click_pos(idx); /* make sure that the click_pos is valid */
 
 	if (utils_str_equal(user_data, "blank"))
 	{
@@ -1557,7 +1568,7 @@ void
 on_run_button_clicked                  (GtkToolButton   *toolbutton,
                                         gpointer         user_data)
 {
-	keybindings_cmd(GEANY_KEYS_BUILD_RUN);
+	keybindings_send_command(GEANY_KEY_GROUP_BUILD, GEANY_KEYS_BUILD_RUN);
 }
 
 
@@ -1565,7 +1576,7 @@ void
 on_go_to_line1_activate                (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	// this is search menu cb; call popup menu goto cb
+	/* this is search menu cb; call popup menu goto cb */
 	on_go_to_line_activate(menuitem, user_data);
 }
 
@@ -1636,8 +1647,8 @@ on_menu_show_sidebar1_toggled          (GtkCheckMenuItem *checkmenuitem,
 
 	if (ui_prefs.sidebar_visible)
 	{
-		// to remember the active page because GTK (e.g. 2.8.18) doesn't do it and shows always
-		// the last page (for unknown reason, with GTK 2.6.4 it works)
+		/* to remember the active page because GTK (e.g. 2.8.18) doesn't do it and shows always
+		 * the last page (for unknown reason, with GTK 2.6.4 it works) */
 		active_page = gtk_notebook_get_current_page(GTK_NOTEBOOK(app->treeview_notebook));
 	}
 
@@ -1713,7 +1724,7 @@ void
 on_menu_duplicate_line1_activate       (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	keybindings_cmd(GEANY_KEYS_EDIT_DUPLICATELINE);
+	keybindings_send_command(GEANY_KEY_GROUP_EDITOR, GEANY_KEYS_EDITOR_DUPLICATELINE);
 }
 
 
@@ -1735,7 +1746,7 @@ on_menu_increase_indent1_activate      (GtkMenuItem     *menuitem,
 		old_pos = sci_get_current_position(doc_list[idx].sci);
 		line = sci_get_line_from_position(doc_list[idx].sci, old_pos);
 		ind_pos = sci_get_line_indent_position(doc_list[idx].sci, line);
-		// when using tabs increase cur pos by 1, when using space increase it by tab_width
+		/* when using tabs increase cur pos by 1, when using space increase it by tab_width */
 		step = (doc_list[idx].use_tabs) ? 1 : editor_prefs.tab_width;
 		new_pos = (old_pos > ind_pos) ? old_pos + step : old_pos;
 
@@ -1896,7 +1907,7 @@ on_menu_open_selected_file1_activate   (GtkMenuItem     *menuitem,
 
 	if (! DOC_IDX_VALID(idx)) return;
 
-	sel = editor_get_default_selection(idx, GEANY_WORDCHARS"./");
+	sel = editor_get_default_selection(idx, TRUE, GEANY_WORDCHARS"./");
 
 	if (sel != NULL)
 	{
@@ -1905,7 +1916,7 @@ on_menu_open_selected_file1_activate   (GtkMenuItem     *menuitem,
 		if (g_path_is_absolute(sel))
 			filename = g_strdup(sel);
 		else
-		{	// relative filename, add the path of the current file
+		{	/* relative filename, add the path of the current file */
 			gchar *path;
 
 			path = g_path_get_dirname(doc_list[idx].file_name);
@@ -1914,7 +1925,7 @@ on_menu_open_selected_file1_activate   (GtkMenuItem     *menuitem,
 			if (! g_file_test(filename, G_FILE_TEST_EXISTS) &&
 				app->project != NULL && NZV(app->project->base_path))
 			{
-				// try the project's base path
+				/* try the project's base path */
 				setptr(path, project_get_base_path());
 				setptr(filename, g_build_path(G_DIR_SEPARATOR_S, path, sel, NULL));
 			}
@@ -1940,8 +1951,8 @@ on_remove_markers1_activate            (GtkMenuItem     *menuitem,
 	if (! DOC_IDX_VALID(idx))
 		return;
 
-	sci_marker_delete_all(doc_list[idx].sci, 0);	// delete the yellow tag marker
-	sci_marker_delete_all(doc_list[idx].sci, 1);	// delete user markers
+	sci_marker_delete_all(doc_list[idx].sci, 0);	/* delete the yellow tag marker */
+	sci_marker_delete_all(doc_list[idx].sci, 1);	/* delete user markers */
 }
 
 
@@ -1965,7 +1976,7 @@ on_context_action1_activate            (GtkMenuItem     *menuitem,
 	if (! DOC_IDX_VALID(idx)) return;
 
 	if (sci_can_copy(doc_list[idx].sci))
-	{	// take selected text if there is a selection
+	{	/* take selected text if there is a selection */
 		word = g_malloc(sci_get_selected_text_length(doc_list[idx].sci) + 1);
 		sci_get_selected_text(doc_list[idx].sci, word);
 	}
@@ -1974,7 +1985,7 @@ on_context_action1_activate            (GtkMenuItem     *menuitem,
 		word = g_strdup(editor_info.current_word);
 	}
 
-	// use the filetype specific command if available, fallback to global command otherwise
+	/* use the filetype specific command if available, fallback to global command otherwise */
 	if (doc_list[idx].file_type != NULL &&
 		doc_list[idx].file_type->context_action_cmd != NULL &&
 		*doc_list[idx].file_type->context_action_cmd != '\0')
@@ -1986,7 +1997,7 @@ on_context_action1_activate            (GtkMenuItem     *menuitem,
 		command = g_strdup(prefs.context_action_cmd);
 	}
 
-	// substitute the wildcard %s and run the command if it is non empty
+	/* substitute the wildcard %s and run the command if it is non empty */
 	if (command != NULL && *command != '\0')
 	{
 		command = utils_str_replace(command, "%s", word);
@@ -2008,10 +2019,12 @@ on_menu_toggle_all_additional_widgets1_activate
                                         gpointer         user_data)
 {
 	static gint hide_all = -1;
-	GtkCheckMenuItem *msgw = GTK_CHECK_MENU_ITEM(lookup_widget(app->window, "menu_show_messages_window1"));
-	GtkCheckMenuItem *toolbari = GTK_CHECK_MENU_ITEM(lookup_widget(app->window, "menu_show_toolbar1"));
+	GtkCheckMenuItem *msgw = GTK_CHECK_MENU_ITEM(
+		lookup_widget(app->window, "menu_show_messages_window1"));
+	GtkCheckMenuItem *toolbari = GTK_CHECK_MENU_ITEM(
+		lookup_widget(app->window, "menu_show_toolbar1"));
 
-	// get the initial state (necessary if Geany was closed with hide_all = TRUE)
+	/* get the initial state (necessary if Geany was closed with hide_all = TRUE) */
 	if (hide_all == -1)
 	{
 		if (! gtk_check_menu_item_get_active(msgw) &&
@@ -2024,7 +2037,7 @@ on_menu_toggle_all_additional_widgets1_activate
 			hide_all = FALSE;
 	}
 
-	hide_all = ! hide_all; // toggle
+	hide_all = ! hide_all; /* toggle */
 
 	if (hide_all)
 	{
@@ -2132,3 +2145,17 @@ on_tools1_activate                     (GtkMenuItem     *menuitem,
 #endif
 }
 
+
+gboolean
+on_escape_key_press_event              (GtkWidget       *widget,
+                                        GdkEventKey     *event,
+                                        gpointer         user_data)
+{
+	/* make pressing escape in the sidebar and toolbar focus the editor */
+	if (event->keyval == GDK_Escape && event->state == 0)
+	{
+		keybindings_send_command(GEANY_KEY_GROUP_FOCUS, GEANY_KEYS_FOCUS_EDITOR);
+		return TRUE;
+	}
+	return FALSE;
+}
