@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: callbacks.h 2150 2008-01-06 18:11:57Z eht16 $
+ * $Id: callbacks.h 2488 2008-04-16 11:34:34Z ntrel $
  */
 
 typedef struct
@@ -102,7 +102,7 @@ void
 on_close1_activate                     (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-gboolean
+void
 on_close_all1_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
@@ -562,17 +562,6 @@ on_motion_event                        (GtkWidget       *widget,
                                         GdkEventMotion  *event,
                                         gpointer         user_data);
 
-
-gboolean
-on_entry1_key_press_event              (GtkWidget       *widget,
-                                        GdkEventKey     *event,
-                                        gpointer         user_data);
-
-gboolean
-on_entry_goto_line_key_press_event     (GtkWidget       *widget,
-                                        GdkEventKey     *event,
-                                        gpointer         user_data);
-
 void
 on_tv_notebook_switch_page_after       (GtkNotebook     *notebook,
                                         GtkNotebookPage *page,
@@ -599,3 +588,8 @@ on_page_setup1_activate                (GtkMenuItem     *menuitem,
 void
 on_tools1_activate                     (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
+
+gboolean
+on_escape_key_press_event              (GtkWidget       *widget,
+                                        GdkEventKey     *event,
+                                        gpointer         user_data);
