@@ -1,8 +1,8 @@
 /*
  *      dialogs.c - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2005-2007 Enrico Tröger <enrico.troeger@uvena.de>
- *      Copyright 2006-2007 Nick Treleaven <nick.treleaven@btinternet.com>
+ *      Copyright 2005-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2006-2008 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: dialogs.c 1818 2007-08-24 11:19:26Z ntrel $
+ * $Id: dialogs.c 2436 2008-04-02 13:26:38Z eht16 $
  */
 
 /*
@@ -57,8 +57,14 @@
 #include "build.h"
 
 
+enum
+{
+	GEANY_RESPONSE_RENAME,
+	GEANY_RESPONSE_VIEW
+};
+
 #if ! GEANY_USE_WIN32_DIALOG
-static GtkWidget *add_file_open_extra_widget();
+static GtkWidget *add_file_open_extra_widget(void);
 #endif
 
 
@@ -70,7 +76,7 @@ on_file_open_dialog_response           (GtkDialog *dialog,
 {
 	gtk_widget_hide(ui_widgets.open_filesel);
 
-	if (response == GTK_RESPONSE_ACCEPT || response == GTK_RESPONSE_APPLY)
+	if (response == GTK_RESPONSE_ACCEPT || response == GEANY_RESPONSE_VIEW)
 	{
 		GSList *filelist;
 		gint filetype_idx = gtk_combo_box_get_active(GTK_COMBO_BOX(
@@ -79,7 +85,7 @@ on_file_open_dialog_response           (GtkDialog *dialog,
 						lookup_widget(GTK_WIDGET(dialog), "encoding_combo")));
 		filetype *ft = NULL;
 		gchar *charset = NULL;
-		gboolean ro = (response == GTK_RESPONSE_APPLY);	// View clicked
+		gboolean ro = (response == GEANY_RESPONSE_VIEW);	/* View clicked */
 
 		if (filetype_idx >= 0 && filetype_idx < GEANY_FILETYPES_ALL) ft = filetypes[filetype_idx];
 		if (encoding_idx >= 0 && encoding_idx < GEANY_ENCODINGS_MAX)
@@ -89,7 +95,7 @@ on_file_open_dialog_response           (GtkDialog *dialog,
 		if (filelist != NULL)
 		{
 			document_open_files(filelist, ro, ft, charset);
-			g_slist_foreach(filelist, (GFunc) g_free, NULL);	// free filenames
+			g_slist_foreach(filelist, (GFunc) g_free, NULL);	/* free filenames */
 		}
 		g_slist_free(filelist);
 	}
@@ -98,7 +104,7 @@ on_file_open_dialog_response           (GtkDialog *dialog,
 
 
 #if ! GEANY_USE_WIN32_DIALOG
-// callback for the text entry for typing in filename
+/* callback for the text entry for typing in filename */
 static void
 on_file_open_entry_activate            (GtkEntry        *entry,
                                         gpointer         user_data)
@@ -130,7 +136,7 @@ on_file_open_selection_changed         (GtkFileChooser  *filechooser,
 
 	if (filename)
 	{
-		// try to get the UTF-8 equivalent for the filename, fallback to filename if error
+		/* try to get the UTF-8 equivalent for the filename, fallback to filename if error */
 		gchar *utf8_filename = utils_get_utf8_from_locale(filename);
 
 		gtk_entry_set_text(GTK_ENTRY(lookup_widget(
@@ -157,115 +163,113 @@ on_file_open_check_hidden_toggled      (GtkToggleButton *togglebutton,
 #endif
 
 
+#if ! GEANY_USE_WIN32_DIALOG
+static void create_open_file_dialog(void)
+{
+	GtkWidget *filetype_combo, *encoding_combo;
+	GtkWidget *viewbtn;
+	GtkTooltips *tooltips = GTK_TOOLTIPS(lookup_widget(app->window, "tooltips"));
+	gint i;
+	gchar *encoding_string;
+
+	ui_widgets.open_filesel = gtk_file_chooser_dialog_new(_("Open File"), GTK_WINDOW(app->window),
+			GTK_FILE_CHOOSER_ACTION_OPEN, NULL, NULL);
+	gtk_widget_set_name(ui_widgets.open_filesel, "GeanyDialog");
+
+	viewbtn = gtk_dialog_add_button(GTK_DIALOG(ui_widgets.open_filesel), _("_View"),
+				GEANY_RESPONSE_VIEW);
+	gtk_tooltips_set_tip(tooltips, viewbtn,
+		_("Opens the file in read-only mode. If you choose more than one file to open, all files will be opened read-only."), NULL);
+
+	gtk_dialog_add_buttons(GTK_DIALOG(ui_widgets.open_filesel),
+		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
+	gtk_dialog_set_default_response(GTK_DIALOG(ui_widgets.open_filesel), GTK_RESPONSE_ACCEPT);
+
+	gtk_widget_set_size_request(ui_widgets.open_filesel, -1, 460);
+	gtk_window_set_modal(GTK_WINDOW(ui_widgets.open_filesel), TRUE);
+	gtk_window_set_destroy_with_parent(GTK_WINDOW(ui_widgets.open_filesel), TRUE);
+	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(ui_widgets.open_filesel), FALSE);
+	gtk_window_set_type_hint(GTK_WINDOW(ui_widgets.open_filesel), GDK_WINDOW_TYPE_HINT_DIALOG);
+	gtk_window_set_transient_for(GTK_WINDOW(ui_widgets.open_filesel), GTK_WINDOW(app->window));
+	gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(ui_widgets.open_filesel), TRUE);
+
+	/* add checkboxes and filename entry */
+	gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(ui_widgets.open_filesel),
+		add_file_open_extra_widget());
+	filetype_combo = lookup_widget(ui_widgets.open_filesel, "filetype_combo");
+
+	/* add FileFilters(start with "All Files") */
+	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(ui_widgets.open_filesel),
+				filetypes_create_file_filter(filetypes[GEANY_FILETYPES_ALL]));
+	/* now create meta filter "All Source" */
+	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(ui_widgets.open_filesel),
+				filetypes_create_file_filter_all_source());
+	for (i = 0; i < GEANY_MAX_FILE_TYPES - 1; i++)
+	{
+		gtk_combo_box_append_text(GTK_COMBO_BOX(filetype_combo), filetypes[i]->title);
+		gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(ui_widgets.open_filesel),
+				filetypes_create_file_filter(filetypes[i]));
+	}
+	gtk_combo_box_append_text(GTK_COMBO_BOX(filetype_combo), _("Detect by file extension"));
+	gtk_combo_box_set_active(GTK_COMBO_BOX(filetype_combo), GEANY_MAX_FILE_TYPES - 1);
+
+	/* fill encoding combo box */
+	encoding_combo = lookup_widget(ui_widgets.open_filesel, "encoding_combo");
+	for (i = 0; i < GEANY_ENCODINGS_MAX; i++)
+	{
+		encoding_string = encodings_to_string(&encodings[i]);
+		gtk_combo_box_append_text(GTK_COMBO_BOX(encoding_combo), encoding_string);
+		g_free(encoding_string);
+	}
+	gtk_combo_box_append_text(GTK_COMBO_BOX(encoding_combo), _("Detect from file"));
+	gtk_combo_box_set_active(GTK_COMBO_BOX(encoding_combo), GEANY_ENCODINGS_MAX);
+
+	g_signal_connect((gpointer) ui_widgets.open_filesel, "selection-changed",
+				G_CALLBACK(on_file_open_selection_changed), NULL);
+	g_signal_connect ((gpointer) ui_widgets.open_filesel, "delete_event",
+				G_CALLBACK(gtk_widget_hide_on_delete), NULL);
+	g_signal_connect((gpointer) ui_widgets.open_filesel, "response",
+				G_CALLBACK(on_file_open_dialog_response), NULL);
+}
+#endif
+
+
 /* This shows the file selection dialog to open a file. */
-void dialogs_show_open_file ()
+void dialogs_show_open_file()
 {
-#if GEANY_USE_WIN32_DIALOG
-	win32_show_file_dialog(TRUE);
-#else /* X11, not win32: use GTK_FILE_CHOOSER */
 	gchar *initdir;
 
-	/* We use the same file selection widget each time, so first
-		of all we create it if it hasn't already been created. */
+	/* set dialog directory to the current file's directory, if present */
+	initdir = utils_get_current_file_dir_utf8();
+
+	/* use project or default startup directory (if set) if no files are open */
+	/** TODO should it only be used when initally open the dialog and not on every show? */
+	if (! initdir)
+		initdir = g_strdup(utils_get_default_dir_utf8());
+
+	setptr(initdir, utils_get_locale_from_utf8(initdir));
+
+#if GEANY_USE_WIN32_DIALOG
+	win32_show_file_dialog(TRUE, initdir);
+#else /* X11, not win32: use GTK_FILE_CHOOSER */
+
+	/* We use the same file selection widget each time, so first of all we create it
+	 * if it hasn't already been created. */
 	if (ui_widgets.open_filesel == NULL)
-	{
-		GtkWidget *filetype_combo, *encoding_combo;
-		GtkWidget *viewbtn;
-		GtkTooltips *tooltips = GTK_TOOLTIPS(lookup_widget(app->window, "tooltips"));
-		gint i;
-		gchar *encoding_string;
+		create_open_file_dialog();
 
-		ui_widgets.open_filesel = gtk_file_chooser_dialog_new(_("Open File"), GTK_WINDOW(app->window),
-				GTK_FILE_CHOOSER_ACTION_OPEN, NULL, NULL);
-		gtk_widget_set_name(ui_widgets.open_filesel, "GeanyDialog");
-
-		viewbtn = gtk_button_new_with_mnemonic(_("_View"));
-		gtk_tooltips_set_tip(tooltips, viewbtn,
-			_("Opens the file in read-only mode. If you choose more than one file to open, all files will be opened read-only."), NULL);
-		gtk_widget_show(viewbtn);
-		gtk_dialog_add_action_widget(GTK_DIALOG(ui_widgets.open_filesel),
-			viewbtn, GTK_RESPONSE_APPLY);
-
-		gtk_dialog_add_buttons(GTK_DIALOG(ui_widgets.open_filesel),
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
-		gtk_dialog_set_default_response(GTK_DIALOG(ui_widgets.open_filesel),
-			GTK_RESPONSE_ACCEPT);
-
-		gtk_widget_set_size_request(ui_widgets.open_filesel, -1, 460);
-		gtk_window_set_modal(GTK_WINDOW(ui_widgets.open_filesel), TRUE);
-		gtk_window_set_destroy_with_parent(GTK_WINDOW(ui_widgets.open_filesel), TRUE);
-		gtk_window_set_skip_taskbar_hint(GTK_WINDOW(ui_widgets.open_filesel), TRUE);
-		gtk_window_set_type_hint(GTK_WINDOW(ui_widgets.open_filesel), GDK_WINDOW_TYPE_HINT_DIALOG);
-		gtk_window_set_transient_for(GTK_WINDOW(ui_widgets.open_filesel), GTK_WINDOW(app->window));
-		gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(ui_widgets.open_filesel), TRUE);
-
-		// add checkboxes and filename entry
-		gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(ui_widgets.open_filesel),
-			add_file_open_extra_widget());
-		filetype_combo = lookup_widget(ui_widgets.open_filesel, "filetype_combo");
-
-		// add FileFilters(start with "All Files")
-		gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(ui_widgets.open_filesel),
-					filetypes_create_file_filter(filetypes[GEANY_FILETYPES_ALL]));
-		// now create meta filter "All Source"
-		gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(ui_widgets.open_filesel),
-					filetypes_create_file_filter_all_source());
-		for (i = 0; i < GEANY_MAX_FILE_TYPES - 1; i++)
-		{
-			gtk_combo_box_append_text(GTK_COMBO_BOX(filetype_combo), filetypes[i]->title);
-			gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(ui_widgets.open_filesel),
-					filetypes_create_file_filter(filetypes[i]));
-		}
-		gtk_combo_box_append_text(GTK_COMBO_BOX(filetype_combo), _("Detect by file extension"));
-		gtk_combo_box_set_active(GTK_COMBO_BOX(filetype_combo), GEANY_MAX_FILE_TYPES - 1);
-
-		// fill encoding combo box
-		encoding_combo = lookup_widget(ui_widgets.open_filesel, "encoding_combo");
-		for (i = 0; i < GEANY_ENCODINGS_MAX; i++)
-		{
-			encoding_string = encodings_to_string(&encodings[i]);
-			gtk_combo_box_append_text(GTK_COMBO_BOX(encoding_combo), encoding_string);
-			g_free(encoding_string);
-		}
-		gtk_combo_box_append_text(GTK_COMBO_BOX(encoding_combo), _("Detect from file"));
-		gtk_combo_box_set_active(GTK_COMBO_BOX(encoding_combo), GEANY_ENCODINGS_MAX);
-
-		g_signal_connect((gpointer) ui_widgets.open_filesel, "selection-changed",
-					G_CALLBACK(on_file_open_selection_changed), NULL);
-		g_signal_connect ((gpointer) ui_widgets.open_filesel, "delete_event",
-					G_CALLBACK(gtk_widget_hide_on_delete), NULL);
-		g_signal_connect((gpointer) ui_widgets.open_filesel, "response",
-					G_CALLBACK(on_file_open_dialog_response), NULL);
-	}
-
-	// set dialog directory to the current file's directory, if present
-	initdir = utils_get_current_file_dir();
 	if (initdir != NULL)
 	{
-		gchar *locale_filename;
-
-		locale_filename = utils_get_locale_from_utf8(initdir);
-
-		if (g_path_is_absolute(locale_filename))
+		if (g_path_is_absolute(initdir))
 			gtk_file_chooser_set_current_folder(
-				GTK_FILE_CHOOSER(ui_widgets.open_filesel), locale_filename);
-
-		g_free(initdir);
-		g_free(locale_filename);
-	}
-	// use default startup directory(if set) if no files are open
-	/// TODO should it only be used when initally open the dialog and not on every show?
-	else if (prefs.default_open_path != NULL && *prefs.default_open_path != '\0')
-	{
-		if (g_path_is_absolute(prefs.default_open_path))
-			gtk_file_chooser_set_current_folder(
-				GTK_FILE_CHOOSER(ui_widgets.open_filesel), prefs.default_open_path);
+				GTK_FILE_CHOOSER(ui_widgets.open_filesel), initdir);
 	}
 
 	gtk_file_chooser_unselect_all(GTK_FILE_CHOOSER(ui_widgets.open_filesel));
 	gtk_widget_show(ui_widgets.open_filesel);
 #endif
+	g_free(initdir);
 }
 
 
@@ -281,7 +285,7 @@ static GtkWidget *add_file_open_extra_widget()
 
 	table = gtk_table_new(2, 4, FALSE);
 
-	// line 1 with checkbox and encoding combo
+	/* line 1 with checkbox and encoding combo */
 	check_hidden = gtk_check_button_new_with_mnemonic(_("Show _hidden files"));
 	gtk_button_set_focus_on_click(GTK_BUTTON(check_hidden), FALSE);
 	gtk_widget_show(check_hidden);
@@ -289,7 +293,7 @@ static GtkWidget *add_file_open_extra_widget()
 					(GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
 					(GtkAttachOptions) (0), 0, 5);
 
-	// spacing
+	/* spacing */
 	gtk_table_attach(GTK_TABLE(table), gtk_label_new(""), 1, 2, 0, 1,
 					(GtkAttachOptions) (GTK_FILL),
 					(GtkAttachOptions) (0), 5, 5);
@@ -299,7 +303,7 @@ static GtkWidget *add_file_open_extra_widget()
 	gtk_table_attach(GTK_TABLE(table), encoding_label, 2, 3, 0, 1,
 					(GtkAttachOptions) (GTK_FILL),
 					(GtkAttachOptions) (0), 4, 5);
-	// the ebox is for the tooltip, because gtk_combo_box can't show tooltips
+	/* the ebox is for the tooltip, because gtk_combo_box can't show tooltips */
 	encoding_ebox = gtk_event_box_new();
 	encoding_combo = gtk_combo_box_new_text();
 	gtk_combo_box_set_wrap_width(GTK_COMBO_BOX(encoding_combo), 3);
@@ -310,16 +314,16 @@ static GtkWidget *add_file_open_extra_widget()
 					(GtkAttachOptions) (GTK_FILL),
 					(GtkAttachOptions) (0), 0, 5);
 
-	// line 2 with filename entry and filetype combo
+	/* line 2 with filename entry and filetype combo */
 	file_entry = gtk_entry_new();
 	gtk_widget_show(file_entry);
-	//gtk_editable_set_editable(GTK_EDITABLE(file_entry), FALSE);
+	/*gtk_editable_set_editable(GTK_EDITABLE(file_entry), FALSE);*/
 	gtk_entry_set_activates_default(GTK_ENTRY(file_entry), TRUE);
 	gtk_table_attach(GTK_TABLE(table), file_entry, 0, 1, 1, 2,
 					(GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
 					(GtkAttachOptions) (0), 0, 5);
 
-	// spacing
+	/* spacing */
 	gtk_table_attach(GTK_TABLE(table), gtk_label_new(""), 1, 2, 1, 2,
 					(GtkAttachOptions) (GTK_FILL),
 					(GtkAttachOptions) (0), 5, 5);
@@ -329,7 +333,7 @@ static GtkWidget *add_file_open_extra_widget()
 	gtk_table_attach(GTK_TABLE(table), filetype_label, 2, 3, 1, 2,
 					(GtkAttachOptions) (GTK_FILL),
 					(GtkAttachOptions) (0), 4, 5);
-	// the ebox is for the tooltip, because gtk_combo_box can't show tooltips
+	/* the ebox is for the tooltip, because gtk_combo_box can't show tooltips */
 	filetype_ebox = gtk_event_box_new();
 	filetype_combo = gtk_combo_box_new_text();
 	gtk_combo_box_set_wrap_width(GTK_COMBO_BOX(filetype_combo), 2);
@@ -372,6 +376,45 @@ static void on_save_as_new_tab_toggled(GtkToggleButton *togglebutton, gpointer u
 
 
 #if ! GEANY_USE_WIN32_DIALOG
+static void handle_save_as(const gchar *utf8_filename, gboolean open_new_tab,
+		gboolean rename_file)
+{
+	gint idx = document_get_cur_idx();
+
+	g_return_if_fail(NZV(utf8_filename));
+
+	if (open_new_tab)
+	{	/* "open" the saved file in a new tab and switch to it */
+		idx = document_clone(idx, utf8_filename);
+	}
+	else
+	{
+		if (doc_list[idx].file_name != NULL)
+		{
+			if (rename_file)
+			{
+				gchar *old_filename = utils_get_locale_from_utf8(doc_list[idx].file_name);
+				gchar *new_filename = utils_get_locale_from_utf8(utf8_filename);
+
+				g_rename(old_filename, new_filename);
+				g_free(old_filename);
+				g_free(new_filename);
+			}
+			/* create a new tm_source_file object otherwise tagmanager won't work correctly */
+			tm_workspace_remove_object(doc_list[idx].tm_file, TRUE, TRUE);
+			doc_list[idx].tm_file = NULL;
+			g_free(doc_list[idx].file_name);
+		}
+		doc_list[idx].file_name = g_strdup(utf8_filename);
+	}
+
+	document_save_file_as(idx);
+
+	if (! open_new_tab)
+		build_menu_update(idx);
+}
+
+
 static void
 on_file_save_dialog_response           (GtkDialog *dialog,
                                         gint response,
@@ -381,68 +424,38 @@ on_file_save_dialog_response           (GtkDialog *dialog,
 
 	switch (response)
 	{
-		case GTK_RESPONSE_APPLY:
+		case GEANY_RESPONSE_RENAME:
 			rename_file = TRUE;
-			// fall through
-
+			/* fall through */
 		case GTK_RESPONSE_ACCEPT:
 		{
-			gint idx = document_get_cur_idx();
 			gchar *new_filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(ui_widgets.save_filesel));
-			gchar *utf8_filename;
 			gboolean open_new_tab = gtk_toggle_button_get_active(
 					GTK_TOGGLE_BUTTON(lookup_widget(ui_widgets.save_filesel, "check_open_new_tab")));
+			gchar *utf8_filename;
 
-#ifdef G_OS_WIN32
-			utf8_filename = g_strdup(new_filename);
-#else
+			if (! NZV(new_filename))	/* rename doesn't check for empty filename */
+			{
+				utils_beep();
+				g_free(new_filename);
+				return;
+			}
 			utf8_filename = utils_get_utf8_from_locale(new_filename);
-#endif
-			// check if file exists and ask whether to overwrite or not
+			/* check if file exists and ask whether to overwrite or not */
 			if (g_file_test(new_filename, G_FILE_TEST_EXISTS))
 			{
 				if (dialogs_show_question(
 					_("The file '%s' already exists. Do you want to overwrite it?"),
 					utf8_filename) == FALSE)
-					return;
-			}
-
-			if (open_new_tab)
-			{	// "open" the saved file in a new tab
-				idx = document_clone(idx, utf8_filename);
-				g_free(utf8_filename);
-			}
-			else
-			{
-				if (doc_list[idx].file_name != NULL)
 				{
-					if (rename_file)
-					{	// delete the previous file name
-#ifdef G_OS_WIN32
-						g_unlink(doc_list[idx].file_name);
-#else
-						gchar *old_filename = utils_get_locale_from_utf8(doc_list[idx].file_name);
-
-						g_unlink(old_filename);
-						g_free(old_filename);
-#endif
-					}
-					// create a new tm_source_file object otherwise tagmanager won't work correctly
-					tm_workspace_remove_object(doc_list[idx].tm_file, TRUE);
-					doc_list[idx].tm_file = NULL;
-					g_free(doc_list[idx].file_name);
+					g_free(utf8_filename);
+					g_free(new_filename);
+					return;
 				}
-				doc_list[idx].file_name = utf8_filename;
 			}
-			utils_replace_filename(idx);
-			document_save_file(idx, TRUE);
-
-			if (! open_new_tab)
-				build_menu_update(idx);
-
-			// finally add current file to recent files menu
-			ui_add_recent_file(doc_list[idx].file_name);
+			handle_save_as(utf8_filename, open_new_tab, rename_file);
 
+			g_free(utf8_filename);
 			g_free(new_filename);
 		}
 	}
@@ -451,79 +464,87 @@ on_file_save_dialog_response           (GtkDialog *dialog,
 #endif
 
 
-/* Show the Save As dialog for the current notebook page.
- * Returns: TRUE if the file was saved. */
-gboolean dialogs_show_save_as()
+#if ! GEANY_USE_WIN32_DIALOG
+static void create_save_file_dialog(void)
+{
+	GtkWidget *vbox, *check_open_new_tab, *rename_btn;
+	GtkTooltips *tooltips = GTK_TOOLTIPS(lookup_widget(app->window, "tooltips"));
+
+	ui_widgets.save_filesel = gtk_file_chooser_dialog_new(_("Save File"), GTK_WINDOW(app->window),
+				GTK_FILE_CHOOSER_ACTION_SAVE, NULL, NULL);
+	gtk_window_set_modal(GTK_WINDOW(ui_widgets.save_filesel), TRUE);
+	gtk_window_set_destroy_with_parent(GTK_WINDOW(ui_widgets.save_filesel), TRUE);
+	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(ui_widgets.save_filesel), FALSE);
+	gtk_window_set_type_hint(GTK_WINDOW(ui_widgets.save_filesel), GDK_WINDOW_TYPE_HINT_DIALOG);
+	gtk_widget_set_name(ui_widgets.save_filesel, "GeanyDialog");
+
+	rename_btn = gtk_dialog_add_button(GTK_DIALOG(ui_widgets.save_filesel), _("R_ename"),
+					GEANY_RESPONSE_RENAME);
+	gtk_tooltips_set_tip(tooltips, rename_btn,
+		_("Save the file and rename it."), NULL);
+
+	gtk_dialog_add_buttons(GTK_DIALOG(ui_widgets.save_filesel),
+		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL);
+	gtk_dialog_set_default_response(GTK_DIALOG(ui_widgets.save_filesel), GTK_RESPONSE_ACCEPT);
+
+	vbox = gtk_vbox_new(FALSE, 0);
+	check_open_new_tab = gtk_check_button_new_with_mnemonic(_("_Open file in a new tab"));
+	gtk_tooltips_set_tip(tooltips, check_open_new_tab,
+		_("Keep the current unsaved document open"
+		" and open the newly saved file in a new tab."), NULL);
+	gtk_box_pack_start(GTK_BOX(vbox), check_open_new_tab, FALSE, FALSE, 0);
+	gtk_widget_show_all(vbox);
+	gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(ui_widgets.save_filesel), vbox);
+
+	g_signal_connect(check_open_new_tab, "toggled",
+				G_CALLBACK(on_save_as_new_tab_toggled), rename_btn);
+
+	g_object_set_data_full(G_OBJECT(ui_widgets.save_filesel), "check_open_new_tab",
+				gtk_widget_ref(check_open_new_tab), (GDestroyNotify) gtk_widget_unref);
+
+	g_signal_connect((gpointer) ui_widgets.save_filesel, "delete_event",
+		G_CALLBACK(gtk_widget_hide_on_delete), NULL);
+	g_signal_connect((gpointer) ui_widgets.save_filesel, "response",
+		G_CALLBACK(on_file_save_dialog_response), NULL);
+
+	gtk_window_set_transient_for(GTK_WINDOW(ui_widgets.save_filesel), GTK_WINDOW(app->window));
+}
+#endif
+
+
+#if ! GEANY_USE_WIN32_DIALOG
+static gboolean gtk_show_save_as(const gchar *initdir)
 {
-#if GEANY_USE_WIN32_DIALOG
-	return win32_show_file_dialog(FALSE);
-#else
 	gint idx = document_get_cur_idx(), resp;
+	gboolean folder_set = FALSE;
 
 	if (ui_widgets.save_filesel == NULL)
-	{
-		GtkWidget *vbox, *check_open_new_tab, *rename_btn;
-		GtkTooltips *tooltips = GTK_TOOLTIPS(lookup_widget(app->window, "tooltips"));
+		create_save_file_dialog();
 
-		ui_widgets.save_filesel = gtk_file_chooser_dialog_new(_("Save File"), GTK_WINDOW(app->window),
-					GTK_FILE_CHOOSER_ACTION_SAVE, NULL, NULL);
-		gtk_window_set_modal(GTK_WINDOW(ui_widgets.save_filesel), TRUE);
-		gtk_window_set_destroy_with_parent(GTK_WINDOW(ui_widgets.save_filesel), TRUE);
-		gtk_window_set_skip_taskbar_hint(GTK_WINDOW(ui_widgets.save_filesel), TRUE);
-		gtk_window_set_type_hint(GTK_WINDOW(ui_widgets.save_filesel), GDK_WINDOW_TYPE_HINT_DIALOG);
-		gtk_widget_set_name(ui_widgets.save_filesel, "GeanyDialog");
+	gtk_file_chooser_unselect_all(GTK_FILE_CHOOSER(ui_widgets.save_filesel));
 
-		rename_btn = gtk_button_new_with_mnemonic(_("R_ename"));
-		gtk_tooltips_set_tip(tooltips, rename_btn,
-			_("Save the file and rename it."), NULL);
-		gtk_widget_show(rename_btn);
-		gtk_dialog_add_action_widget(GTK_DIALOG(ui_widgets.save_filesel),
-			rename_btn, GTK_RESPONSE_APPLY);
-
-		gtk_dialog_add_buttons(GTK_DIALOG(ui_widgets.save_filesel),
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL);
-		gtk_dialog_set_default_response(GTK_DIALOG(ui_widgets.save_filesel), GTK_RESPONSE_ACCEPT);
-
-		vbox = gtk_vbox_new(FALSE, 0);
-		check_open_new_tab = gtk_check_button_new_with_mnemonic(_("_Open file in a new tab"));
-		gtk_tooltips_set_tip(tooltips, check_open_new_tab,
-			_("Keep the current unsaved document open"
-			" and open the newly saved file in a new tab."), NULL);
-		gtk_box_pack_start(GTK_BOX(vbox), check_open_new_tab, FALSE, FALSE, 0);
-		gtk_widget_show_all(vbox);
-		gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(ui_widgets.save_filesel), vbox);
-
-		g_signal_connect(check_open_new_tab, "toggled",
-					G_CALLBACK(on_save_as_new_tab_toggled), rename_btn);
-
-		g_object_set_data_full(G_OBJECT(ui_widgets.save_filesel), "check_open_new_tab",
-					gtk_widget_ref(check_open_new_tab), (GDestroyNotify) gtk_widget_unref);
-
-		g_signal_connect((gpointer) ui_widgets.save_filesel, "delete_event",
-			G_CALLBACK(gtk_widget_hide_on_delete), NULL);
-		g_signal_connect((gpointer) ui_widgets.save_filesel, "response",
-			G_CALLBACK(on_file_save_dialog_response), NULL);
-
-		gtk_window_set_transient_for(GTK_WINDOW(ui_widgets.save_filesel), GTK_WINDOW(app->window));
-	}
-
-	// If the current document has a filename we use that as the default.
 	if (doc_list[idx].file_name != NULL)
 	{
-#ifdef G_OS_WIN32
-		gchar *locale_filename = doc_list[idx].file_name;
-#else
-		gchar *locale_filename = utils_get_locale_from_utf8(doc_list[idx].file_name);
-#endif
-		if (g_path_is_absolute(locale_filename))
-			gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(ui_widgets.save_filesel), locale_filename);
+		if (g_path_is_absolute(doc_list[idx].file_name))
+		{
+			gchar *locale_filename = utils_get_locale_from_utf8(doc_list[idx].file_name);
+			gchar *locale_basename = g_path_get_basename(locale_filename);
+			gchar *locale_dirname = g_path_get_dirname(locale_filename);
+
+			folder_set = TRUE;
+			gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(ui_widgets.save_filesel),
+				locale_dirname);
+			gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(ui_widgets.save_filesel),
+				locale_basename);
+
+			g_free(locale_filename);
+			g_free(locale_basename);
+			g_free(locale_dirname);
+		}
 		else
 			gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(ui_widgets.save_filesel),
 				doc_list[idx].file_name);
-#ifndef G_OS_WIN32
-		g_free(locale_filename);
-#endif
 	}
 	else
 	{
@@ -536,34 +557,61 @@ gboolean dialogs_show_save_as()
 		else
 			fname = g_strdup(GEANY_STRING_UNTITLED);
 
-		gtk_file_chooser_unselect_all(GTK_FILE_CHOOSER(ui_widgets.save_filesel));
 		gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(ui_widgets.save_filesel), fname);
 
-		// use default startup directory(if set) if no files are open
-		if (prefs.default_open_path != NULL && *prefs.default_open_path != '\0')
-		{
-			if (g_path_is_absolute(prefs.default_open_path))
-			{
-#ifdef G_OS_WIN32
-				gtk_file_chooser_set_current_folder(
-					GTK_FILE_CHOOSER(ui_widgets.save_filesel), prefs.default_open_path);
-#else
-				gchar *def_path = utils_get_locale_from_utf8(prefs.default_open_path);
-				gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(ui_widgets.save_filesel), def_path);
-				g_free(def_path);
-#endif
-			}
-		}
 		g_free(fname);
 	}
 
-	// Run the dialog synchronously, pausing this function call
+	/* if the folder wasn't set so far, we set it to the given directory */
+	if (! folder_set && initdir != NULL && g_path_is_absolute(initdir))
+		gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(ui_widgets.save_filesel), initdir);
+
+	/* Run the dialog synchronously, pausing this function call */
 	resp = gtk_dialog_run(GTK_DIALOG(ui_widgets.save_filesel));
 	return (resp == GTK_RESPONSE_ACCEPT);
+}
 #endif
+
+
+/**
+ *  Show the Save As dialog for the current notebook page.
+ *
+ *  @return @a TRUE if the file was saved, otherwise @a FALSE.
+ **/
+gboolean dialogs_show_save_as()
+{
+	gboolean result;
+	gchar *initdir = NULL;
+
+	initdir = utils_get_current_file_dir_utf8();
+
+	/* use project or default startup directory (if set) if no files are open */
+	/** TODO should it only be used when initally open the dialog and not on every show? */
+	if (! initdir)
+		initdir = g_strdup(utils_get_default_dir_utf8());
+
+	setptr(initdir, utils_get_locale_from_utf8(initdir));
+
+#if GEANY_USE_WIN32_DIALOG
+	result = win32_show_file_dialog(FALSE, initdir);
+#else
+	result = gtk_show_save_as(initdir);
+#endif
+	g_free(initdir);
+	return result;
 }
 
 
+/**
+ *  Show a message box of the type @c type with @c text.
+ *  On Unix-like systems a GTK message dialog box is shown, on Win32 systems a native Windows
+ *  message dialog box is shown.
+ *
+ *  @param type A GtkMessageType, can be one of: GTK_MESSAGE_INFO, GTK_MESSAGE_WARNING,
+ *              GTK_MESSAGE_QUESTION, GTK_MESSAGE_ERROR
+ *  @param text Printf()-style format string.
+ *  @param ... Arguments for the @c text format string.
+ **/
 void dialogs_show_msgbox(gint type, const gchar *text, ...)
 {
 #ifndef G_OS_WIN32
@@ -589,6 +637,25 @@ void dialogs_show_msgbox(gint type, const gchar *text, ...)
 }
 
 
+void dialogs_show_msgbox_with_secondary(gint type, const gchar *text, const gchar *secondary)
+{
+#ifdef G_OS_WIN32
+	/* put the two strings together because Windows message boxes don't support secondary texts */
+	gchar *string = g_strconcat(text, "\n", secondary, NULL);
+	win32_message_dialog(NULL, type, string);
+	g_free(string);
+#else
+	GtkWidget *dialog;
+	dialog = gtk_message_dialog_new(GTK_WINDOW(app->window), GTK_DIALOG_DESTROY_WITH_PARENT,
+                                  type, GTK_BUTTONS_OK, "%s", text);
+	gtk_widget_set_name(dialog, "GeanyDialog");
+	gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog), "%s", secondary);
+	gtk_dialog_run(GTK_DIALOG(dialog));
+	gtk_widget_destroy(dialog);
+#endif
+}
+
+
 gboolean dialogs_show_unsaved_file(gint idx)
 {
 #ifndef G_OS_WIN32
@@ -597,7 +664,7 @@ gboolean dialogs_show_unsaved_file(gint idx)
 	gchar *msg, *msg2, *short_fn = NULL;
 	gint ret;
 
-	// display the file tab to remind the user of the document
+	/* display the file tab to remind the user of the document */
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(app->notebook),
 		document_get_notebook_page(idx));
 
@@ -642,7 +709,7 @@ gboolean dialogs_show_unsaved_file(gint idx)
 				ret = dialogs_show_save_as();
 			}
 			else
-				// document_save_file() returns the status if the file could be saved
+				/* document_save_file() returns the status if the file could be saved */
 				ret = document_save_file(idx, FALSE);
 			break;
 		}
@@ -673,7 +740,7 @@ static void
 on_font_ok_button_clicked              (GtkButton       *button,
                                         gpointer         user_data)
 {
-	// We do the same thing as apply, but we close the dialog after.
+	/* We do the same thing as apply, but we close the dialog after. */
 	on_font_apply_button_clicked(button, NULL);
 	gtk_widget_hide(ui_widgets.open_fontsel);
 }
@@ -726,22 +793,72 @@ void dialogs_show_open_font()
 }
 
 
-void dialogs_show_input(const gchar *title, const gchar *label_text, const gchar *default_text,
-						GCallback cb_dialog, GCallback cb_entry)
+static void
+on_input_dialog_show(GtkDialog *dialog, GtkWidget *entry)
 {
-	GtkWidget *dialog, *label, *entry, *vbox;
+	gtk_widget_grab_focus(entry);
+}
 
-	dialog = gtk_dialog_new_with_buttons(title, GTK_WINDOW(app->window),
-						GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-						GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
-	vbox = ui_dialog_vbox_new(GTK_DIALOG(dialog));
-	gtk_widget_set_name(dialog, "GeanyDialog");
-	gtk_box_set_spacing(GTK_BOX(vbox), 6);
+
+static void
+on_input_entry_activate(GtkEntry *entry, GtkDialog *dialog)
+{
+	gtk_dialog_response(dialog, GTK_RESPONSE_ACCEPT);
+}
+
+
+static void
+on_input_dialog_response(GtkDialog *dialog,
+                         gint response,
+                         GtkWidget *entry)
+{
+	gboolean persistent = (gboolean) GPOINTER_TO_INT(g_object_get_data(G_OBJECT(dialog), "has_combo"));
+
+	if (response == GTK_RESPONSE_ACCEPT)
+	{
+		const gchar *str = gtk_entry_get_text(GTK_ENTRY(entry));
+		InputCallback input_cb =
+			(InputCallback) g_object_get_data(G_OBJECT(dialog), "input_cb");
+
+		if (persistent)
+		{
+			GtkWidget *combo = (GtkWidget *) g_object_get_data(G_OBJECT(dialog), "combo");
+			ui_combo_box_add_to_history(GTK_COMBO_BOX(combo), str);
+		}
+		input_cb(str);
+	}
+
+	if (persistent)
+		gtk_widget_hide(GTK_WIDGET(dialog));
+	else
+		gtk_widget_destroy(GTK_WIDGET(dialog));
+}
+
+
+static void add_input_widgets(GtkWidget *dialog, GtkWidget *vbox,
+		const gchar *label_text, const gchar *default_text, gboolean persistent)
+{
+	GtkWidget *label, *entry;
 
 	label = gtk_label_new(label_text);
 	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
-	entry = gtk_entry_new();
+	gtk_container_add(GTK_CONTAINER(vbox), label);
+
+	if (persistent)	/* remember previous entry text in a combo box */
+	{
+		GtkWidget *combo = gtk_combo_box_entry_new_text();
+
+		entry = GTK_BIN(combo)->child;
+		g_object_set_data(G_OBJECT(dialog), "combo", combo);
+		gtk_container_add(GTK_CONTAINER(vbox), combo);
+	}
+	else
+	{
+		entry = gtk_entry_new();
+		gtk_container_add(GTK_CONTAINER(vbox), entry);
+	}
+
 	if (default_text != NULL)
 	{
 		gtk_entry_set_text(GTK_ENTRY(entry), default_text);
@@ -749,13 +866,47 @@ void dialogs_show_input(const gchar *title, const gchar *label_text, const gchar
 	gtk_entry_set_max_length(GTK_ENTRY(entry), 255);
 	gtk_entry_set_width_chars(GTK_ENTRY(entry), 30);
 
-	if (cb_entry != NULL) g_signal_connect((gpointer) entry, "activate", cb_entry, dialog);
-	g_signal_connect((gpointer) dialog, "response", cb_dialog, entry);
-	g_signal_connect((gpointer) dialog, "delete_event", G_CALLBACK(gtk_widget_destroy), NULL);
+	g_signal_connect((gpointer) entry, "activate",
+		G_CALLBACK(on_input_entry_activate), dialog);
+	g_signal_connect((gpointer) dialog, "show",
+		G_CALLBACK(on_input_dialog_show), entry);
+	g_signal_connect((gpointer) dialog, "response",
+		G_CALLBACK(on_input_dialog_response), entry);
+}
+
+
+/* Create and display an input dialog.
+ * persistent: whether to remember previous entry text in a combo box;
+ * 	in this case the dialog returned is not destroyed on a response,
+ * 	and can be reshown.
+ * Returns: the dialog widget. */
+GtkWidget *
+dialogs_show_input(const gchar *title, const gchar *label_text, const gchar *default_text,
+						gboolean persistent, InputCallback input_cb)
+{
+	GtkWidget *dialog, *vbox;
+
+	dialog = gtk_dialog_new_with_buttons(title, GTK_WINDOW(app->window),
+		GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+	vbox = ui_dialog_vbox_new(GTK_DIALOG(dialog));
+	gtk_widget_set_name(dialog, "GeanyDialog");
+	gtk_box_set_spacing(GTK_BOX(vbox), 6);
+
+	g_object_set_data(G_OBJECT(dialog), "has_combo", GINT_TO_POINTER(persistent));
+	g_object_set_data(G_OBJECT(dialog), "input_cb", (gpointer) input_cb);
+
+	add_input_widgets(dialog, vbox, label_text, default_text, persistent);
+
+	if (persistent)
+		g_signal_connect((gpointer) dialog, "delete_event",
+			G_CALLBACK(gtk_widget_hide_on_delete), NULL);
+	else
+		g_signal_connect((gpointer) dialog, "delete_event",
+			G_CALLBACK(gtk_widget_destroy), NULL);
 
-	gtk_container_add(GTK_CONTAINER(vbox), label);
-	gtk_container_add(GTK_CONTAINER(vbox), entry);
 	gtk_widget_show_all(dialog);
+	return dialog;
 }
 
 
@@ -799,7 +950,7 @@ void dialogs_show_file_properties(gint idx)
 	gint mode = 0;
 #endif
 
-// define this ones, to avoid later trouble
+/* define this ones, to avoid later trouble */
 #ifndef S_IRUSR
 # define S_IRUSR 0
 # define S_IWUSR 0
@@ -823,16 +974,11 @@ void dialogs_show_file_properties(gint idx)
 
 
 #if defined(HAVE_SYS_STAT_H) && defined(TIME_WITH_SYS_TIME) && defined(HAVE_SYS_TYPES_H)
-#ifdef G_OS_WIN32
-	// don't try to convert the filename on Windows, it should be already in UTF8
-	locale_filename = g_strdup(doc_list[idx].file_name);
-#else
 	locale_filename = utils_get_locale_from_utf8(doc_list[idx].file_name);
-#endif
 	if (g_stat(locale_filename, &st) == 0)
 	{
-		// first copy the returned string and the trim it, to not modify the static glibc string
-		// g_strchomp() is used to remove trailing EOL chars, which are there for whatever reason
+		/* first copy the returned string and the trim it, to not modify the static glibc string
+		 * g_strchomp() is used to remove trailing EOL chars, which are there for whatever reason */
 		time_changed  = g_strchomp(g_strdup(ctime(&st.st_ctime)));
 		time_modified = g_strchomp(g_strdup(ctime(&st.st_mtime)));
 		time_accessed = g_strchomp(g_strdup(ctime(&st.st_atime)));
@@ -1000,10 +1146,10 @@ void dialogs_show_file_properties(gint idx)
 					(GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 
-	// add table
+	/* add table */
 	gtk_container_add(GTK_CONTAINER(vbox), table);
 
-	// create table with the permissions
+	/* create table with the permissions */
 	perm_table = gtk_table_new(5, 4, TRUE);
 	gtk_table_set_row_spacings(GTK_TABLE(perm_table), 5);
 	gtk_table_set_col_spacings(GTK_TABLE(perm_table), 5);
@@ -1015,7 +1161,7 @@ void dialogs_show_file_properties(gint idx)
 					(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 					(GtkAttachOptions) (0), 0, 0);
 
-	// Header
+	/* Header */
 	label = gtk_label_new(_("Read:"));
 	gtk_table_attach(GTK_TABLE(perm_table), label, 1, 2, 1, 2,
 					(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -1037,7 +1183,7 @@ void dialogs_show_file_properties(gint idx)
 	gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0);
 
-	// Owner
+	/* Owner */
 	label = gtk_label_new(_("Owner:"));
 	gtk_table_attach(GTK_TABLE(perm_table), label, 0, 1, 2, 3,
 					(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -1073,7 +1219,7 @@ void dialogs_show_file_properties(gint idx)
 	gtk_button_set_alignment(GTK_BUTTON(check), 0.5, 0);
 
 
-	// Group
+	/* Group */
 	label = gtk_label_new(_("Group:"));
 	gtk_table_attach(GTK_TABLE(perm_table), label, 0, 1, 3, 4,
 					(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -1109,7 +1255,7 @@ void dialogs_show_file_properties(gint idx)
 	gtk_button_set_alignment(GTK_BUTTON(check), 0.5, 0);
 
 
-	// Other
+	/* Other */
 	label = gtk_label_new(_("Other:"));
 	gtk_table_attach(GTK_TABLE(perm_table), label, 0, 1, 4, 5,
 					(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -1156,7 +1302,7 @@ void dialogs_show_file_properties(gint idx)
 
 
 static gboolean show_question(GtkWidget *parent, const gchar *yes_btn, const gchar *no_btn,
-	const gchar *question_text,	const gchar *extra_text)
+							  const gchar *question_text, const gchar *extra_text)
 {
 	gboolean ret = FALSE;
 #ifdef G_OS_WIN32
@@ -1175,12 +1321,12 @@ static gboolean show_question(GtkWidget *parent, const gchar *yes_btn, const gch
 		GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION,
 		GTK_BUTTONS_NONE, "%s", question_text);
 	gtk_widget_set_name(dialog, "GeanyDialog");
-	// question_text will be in bold if optional extra_text used
+	/* question_text will be in bold if optional extra_text used */
 	if (extra_text != NULL)
 		gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
 			"%s", extra_text);
 
-	// For a cancel button, use cancel response so user can press escape to cancel
+	/* For a cancel button, use cancel response so user can press escape to cancel */
 	gtk_dialog_add_button(GTK_DIALOG(dialog), no_btn,
 		utils_str_equal(no_btn, GTK_STOCK_CANCEL) ? GTK_RESPONSE_CANCEL : GTK_RESPONSE_NO);
 	gtk_dialog_add_button(GTK_DIALOG(dialog), yes_btn, GTK_RESPONSE_YES);
@@ -1193,6 +1339,16 @@ static gboolean show_question(GtkWidget *parent, const gchar *yes_btn, const gch
 }
 
 
+/**
+ *  Show a question message box with @c text and Yes/No buttons.
+ *  On Unix-like systems a GTK message dialog box is shown, on Win32 systems a native Windows
+ *  message dialog box is shown.
+ *
+ *  @param text Printf()-style format string.
+ *  @param ... Arguments for the @c text format string.
+ *
+ *  @return @a TRUE if the user answered with Yes, otherwise @a FALSE.
+ **/
 gboolean dialogs_show_question(const gchar *text, ...)
 {
 	gboolean ret = FALSE;
