@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: encodings.c 2177 2008-01-16 16:50:10Z eht16 $
+ *  $Id: encodings.c 2287 2008-02-27 13:17:29Z eht16 $
  */
 
 /*
@@ -44,15 +44,18 @@
 
 #ifdef HAVE_REGCOMP
 # include <regex.h>
-// <meta http-equiv="content-type" content="text/html; charset=UTF-8" />
+/* <meta http-equiv="content-type" content="text/html; charset=UTF-8" /> */
 # define PATTERN_HTMLMETA "<meta[ \t\n\r\f]http-equiv[ \t\n\r\f]*=[ \t\n\r\f]*\"content-type\"[ \t\n\r\f]+content[ \t\n\r\f]*=[ \t\n\r\f]*\"text/x?html;[ \t\n\r\f]*charset=([a-z0-9_-]+)\"[ \t\n\r\f]*/?>"
-// " geany_encoding=utf-8 "
+/* " geany_encoding=utf-8 " */
 # define PATTERN_GEANY "[\t ]geany_encoding=([a-z0-9-]+)[\t ]"
-// precompiled regexps
+/* precompiled regexps */
 static regex_t pregs[2];
 #endif
 
 
+GeanyEncoding encodings[GEANY_ENCODINGS_MAX];
+
+
 #define fill(Order, Group, Idx, Charset, Name) \
 		encodings[Idx].idx = Idx; \
 		encodings[Idx].order = Order; \
@@ -178,18 +181,17 @@ const GeanyEncoding *encodings_get_from_index(gint idx)
 }
 
 
-/*
- * gtk_status_icon_get_stock:
- * @idx: #GeanyEncodingIndex to retrieve the corresponding character set
+/**
+ *  Gets the character set name of the specified index e.g. for use with
+ *  @ref document_set_encoding().
  *
- * Gets the character set name of the specified index e.g. for use with
- * document_set_encoding.
+ *  @param idx @ref GeanyEncodingIndex to retrieve the corresponding character set.
  *
- * Return value: charset according to idx,
- *   or %NULL if the index is invalid.
  *
- * Since: 0.13
- */
+ *  @return The charset according to idx, or @c NULL if the index is invalid.
+ *
+ *  @since 0.13
+ **/
 const gchar* encodings_get_charset_from_index(gint idx)
 {
 	g_return_val_if_fail(idx >= 0 && idx < GEANY_ENCODINGS_MAX, NULL);
@@ -230,9 +232,9 @@ void encodings_select_radio_item(const gchar *charset)
 		if (utils_str_equal(charset, encodings[i].charset)) break;
 		i++;
 	}
-	if (i == GEANY_ENCODINGS_MAX) i = GEANY_ENCODING_UTF_8; // fallback to UTF-8
+	if (i == GEANY_ENCODINGS_MAX) i = GEANY_ENCODING_UTF_8; /* fallback to UTF-8 */
 
-	// app->ignore_callback has to be set by the caller
+	/* app->ignore_callback has to be set by the caller */
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(radio_items[i]), TRUE);
 }
 
@@ -268,7 +270,7 @@ static gchar *regex_match(regex_t *preg, const gchar *buffer, gsize size)
 		return NULL;
 
 	if (size > 512)
-		tmp_buf = g_strndup(buffer, 512); // scan only the first 512 characters in the buffer
+		tmp_buf = g_strndup(buffer, 512); /* scan only the first 512 characters in the buffer */
 
 	retval = regexec(preg, (tmp_buf != NULL) ? tmp_buf : buffer, 10, pmatch, 0);
 	if (retval == 0 && pmatch[0].rm_so != -1 && pmatch[1].rm_so != -1)
@@ -317,7 +319,7 @@ void encodings_init(void)
 	regex_compile(&pregs[1], PATTERN_GEANY);
 #endif
 
-	// create encodings submenu in document menu
+	/* create encodings submenu in document menu */
 	menu[0] = lookup_widget(app->window, "set_encoding1_menu");
 	menu[1] = lookup_widget(app->window, "menu_reload_as1_menu");
 	cb_func[0] = G_CALLBACK(on_encoding_change);
@@ -361,7 +363,7 @@ void encodings_init(void)
 		gtk_container_add(GTK_CONTAINER(menu[k]), item_utf8);
 		gtk_widget_show_all(item_utf8);
 
-		/// TODO can it be optimized? ATM 3782 runs at line "if (encodings[j].group ...)"
+		/** TODO can it be optimized? ATM 3782 runs at line "if (encodings[j].group ...)" */
 		for (i = 0; i < GEANY_ENCODING_GROUPS_MAX; i++)
 		{
 			order = 0;
@@ -376,7 +378,7 @@ void encodings_init(void)
 				default: submenu = menu[k]; group_size = 1;
 			}
 
-			while (order < group_size)	// the biggest group has 13 elements
+			while (order < group_size)	/* the biggest group has 13 elements */
 			{
 				for (j = 0; j < GEANY_ENCODINGS_MAX; j++)
 				{
@@ -406,19 +408,18 @@ void encodings_init(void)
 }
 
 
-/*
- * encodings_convert_to_utf8_from_charset:
- * @buffer: the input string to convert
- * @size: the length of the string, or -1 if the string is nul-terminated
- * @charset: the charset to be used for conversion
- * @fast: TRUE to only convert the input and skip extended checks on the converted string
+/**
+ *  Tries to convert @a buffer into UTF-8 encoding from the encoding specified with @a charset.
+ *  If @a fast is not set, additional checks to validate the converted string are performed.
  *
- * Tries to convert @buffer into UTF-8 encoding from the encoding specified with @charset.
- * If @fast is not set, additional checks to validate the converted string are performed.
+ *  @param buffer The input string to convert.
+ *  @param size The length of the string, or -1 if the string is nul-terminated.
+ *  @param charset The charset to be used for conversion.
+ *  @param fast @c TRUE to only convert the input and skip extended checks on the converted string.
  *
- * Return value: If the conversion was successful, a newly allocated nul-terminated string,
- *   which must be freed with g_free(). Otherwise %NULL.
- */
+ *  @return If the conversion was successful, a newly allocated nul-terminated string,
+ *    which must be freed with g_free(). Otherwise @c NULL.
+ **/
 gchar *encodings_convert_to_utf8_from_charset(const gchar *buffer, gsize size,
 											  const gchar *charset, gboolean fast)
 {
@@ -462,18 +463,17 @@ gchar *encodings_convert_to_utf8_from_charset(const gchar *buffer, gsize size,
 }
 
 
-/*
- * encodings_convert_to_utf8:
- * @buffer: the input string to convert
- * @size: the length of the string, or -1 if the string is nul-terminated.
- * @used_encoding: return location of the detected encoding of the input string, or %NULL
+/**
+ *  Tries to convert @a buffer into UTF-8 encoding and store the detected original encoding in
+ *  @a used_encoding.
  *
- * Tries to convert @buffer into UTF-8 encoding and store the detected original encoding in
- * @used_encoding.
+ *  @param buffer the input string to convert.
+ *  @param size the length of the string, or -1 if the string is nul-terminated.
+ *  @param used_encoding return location of the detected encoding of the input string, or @c NULL.
  *
- * Return value: If the conversion was successful, a newly allocated nul-terminated string,
- *   which must be freed with g_free(). Otherwise %NULL.
- */
+ *  @return If the conversion was successful, a newly allocated nul-terminated string,
+ *    which must be freed with g_free(). Otherwise @c NULL.
+ **/
 gchar *encodings_convert_to_utf8(const gchar *buffer, gsize size, gchar **used_encoding)
 {
 	gchar *locale_charset = NULL;
@@ -482,7 +482,7 @@ gchar *encodings_convert_to_utf8(const gchar *buffer, gsize size, gchar **used_e
 	gchar *utf8_content;
 	gboolean check_regex = FALSE;
 	gboolean check_locale = FALSE;
-	guint i;
+	gint i;
 
 	if ((gint)size == -1)
 	{
@@ -490,20 +490,20 @@ gchar *encodings_convert_to_utf8(const gchar *buffer, gsize size, gchar **used_e
 	}
 
 #ifdef HAVE_REGCOMP
-	// first try to read the encoding from the file content
-	for (i = 0; i < G_N_ELEMENTS(pregs) && ! check_regex; i++)
+	/* first try to read the encoding from the file content */
+	for (i = 0; i < (gint) G_N_ELEMENTS(pregs) && ! check_regex; i++)
 	{
 		if ((regex_charset = regex_match(&pregs[i], buffer, size)) != NULL)
 			check_regex = TRUE;
 	}
 #endif
 
-	// current locale is not UTF-8, we have to check this charset
+	/* current locale is not UTF-8, we have to check this charset */
 	check_locale = ! g_get_charset((const gchar**) &charset);
 
 	for (i = 0; i < GEANY_ENCODINGS_MAX; i++)
 	{
-		if (i == (guint) encodings[GEANY_ENCODING_NONE].idx || i == (guint) -1)
+		if (i == encodings[GEANY_ENCODING_NONE].idx || i == -1)
 			continue;
 
 		if (check_regex)
@@ -525,7 +525,7 @@ gchar *encodings_convert_to_utf8(const gchar *buffer, gsize size, gchar **used_e
 		if (charset == NULL)
 			continue;
 
-		geany_debug("Trying to convert %d bytes of data from %s into UTF-8.", size, charset);
+		geany_debug("Trying to convert %" G_GSIZE_FORMAT " bytes of data from %s into UTF-8.", size, charset);
 		utf8_content = encodings_convert_to_utf8_from_charset(buffer, size, charset, FALSE);
 
 		if (utf8_content != NULL)
@@ -573,12 +573,12 @@ GeanyEncodingIndex encodings_scan_unicode_bom(const gchar *string, gsize len, gu
 		if ((guchar)string[0] == 0x00 && (guchar)string[1] == 0x00 &&
 				 (guchar)string[2] == 0xfe && (guchar)string[3] == 0xff)
 		{
-			return GEANY_ENCODING_UTF_32BE; // Big endian
+			return GEANY_ENCODING_UTF_32BE; /* Big endian */
 		}
 		if ((guchar)string[0] == 0xff && (guchar)string[1] == 0xfe &&
 				 (guchar)string[2] == 0x00 && (guchar)string[3] == 0x00)
 		{
-			return GEANY_ENCODING_UTF_32LE; // Little endian
+			return GEANY_ENCODING_UTF_32LE; /* Little endian */
 		}
 		if ((string[0] == 0x2b && string[1] == 0x2f && string[2] == 0x76) &&
 				 (string[3] == 0x38 || string[3] == 0x39 || string[3] == 0x2b || string[3] == 0x2f))
@@ -593,11 +593,11 @@ GeanyEncodingIndex encodings_scan_unicode_bom(const gchar *string, gsize len, gu
 
 		if ((guchar)string[0]==0xfe && (guchar)string[1] == 0xff)
 		{
-			return GEANY_ENCODING_UTF_16BE; // Big endian
+			return GEANY_ENCODING_UTF_16BE; /* Big endian */
 		}
 		if ((guchar)string[0] == 0xff && (guchar)string[1] == 0xfe)
 		{
-			return GEANY_ENCODING_UTF_16LE; // Little endian
+			return GEANY_ENCODING_UTF_16LE; /* Little endian */
 		}
 	}
 	if (bom_len)
