@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: filetypes.c 2150 2008-01-06 18:11:57Z eht16 $
+ * $Id: filetypes.c 2472 2008-04-11 15:39:44Z eht16 $
  */
 
 /*
@@ -26,6 +26,7 @@
  */
 
 #include <string.h>
+#include <glib/gstdio.h>
 
 #include "geany.h"
 #include "filetypes.h"
@@ -45,40 +46,40 @@ filetype *filetypes[GEANY_MAX_FILE_TYPES];
  * The order must not be changed but can be appended to. */
 enum
 {
-	FILETYPE_UID_C = 0,		// 0
-	FILETYPE_UID_CPP,		// 1
-	FILETYPE_UID_JAVA,		// 2
-	FILETYPE_UID_PERL,		// 3
-	FILETYPE_UID_PHP,		// 4
-	FILETYPE_UID_XML,		// 5
-	FILETYPE_UID_DOCBOOK,	// 6
-	FILETYPE_UID_PYTHON,	// 7
-	FILETYPE_UID_LATEX,		// 8
-	FILETYPE_UID_PASCAL,	// 9
-	FILETYPE_UID_SH,		// 10
-	FILETYPE_UID_MAKE,		// 11
-	FILETYPE_UID_CSS,		// 12
-	FILETYPE_UID_CONF,		// 13
-	FILETYPE_UID_ASM,		// 14
-	FILETYPE_UID_SQL,		// 15
-	FILETYPE_UID_CAML,		// 16
-	FILETYPE_UID_OMS,		// 17
-	FILETYPE_UID_RUBY,		// 18
-	FILETYPE_UID_TCL,		// 19
-	FILETYPE_UID_ALL,		// 20
-	FILETYPE_UID_D,			// 21
-	FILETYPE_UID_FORTRAN,	// 22
-	FILETYPE_UID_DIFF,		// 23
-	FILETYPE_UID_FERITE,	// 24
-	FILETYPE_UID_HTML,		// 25
-	FILETYPE_UID_VHDL,		// 26
-	FILETYPE_UID_JS,		// 27
-	FILETYPE_UID_LUA,		// 28
-	FILETYPE_UID_HASKELL,	// 29
-	FILETYPE_UID_CS,		// 30
-	FILETYPE_UID_BASIC,		// 31
-	FILETYPE_UID_HAXE,		// 32
-	FILETYPE_UID_REST		// 33
+	FILETYPE_UID_C = 0,		/* 0 */
+	FILETYPE_UID_CPP,		/* 1 */
+	FILETYPE_UID_JAVA,		/* 2 */
+	FILETYPE_UID_PERL,		/* 3 */
+	FILETYPE_UID_PHP,		/* 4 */
+	FILETYPE_UID_XML,		/* 5 */
+	FILETYPE_UID_DOCBOOK,	/* 6 */
+	FILETYPE_UID_PYTHON,	/* 7 */
+	FILETYPE_UID_LATEX,		/* 8 */
+	FILETYPE_UID_PASCAL,	/* 9 */
+	FILETYPE_UID_SH,		/* 10 */
+	FILETYPE_UID_MAKE,		/* 11 */
+	FILETYPE_UID_CSS,		/* 12 */
+	FILETYPE_UID_CONF,		/* 13 */
+	FILETYPE_UID_ASM,		/* 14 */
+	FILETYPE_UID_SQL,		/* 15 */
+	FILETYPE_UID_CAML,		/* 16 */
+	FILETYPE_UID_OMS,		/* 17 */
+	FILETYPE_UID_RUBY,		/* 18 */
+	FILETYPE_UID_TCL,		/* 19 */
+	FILETYPE_UID_ALL,		/* 20 */
+	FILETYPE_UID_D,			/* 21 */
+	FILETYPE_UID_FORTRAN,	/* 22 */
+	FILETYPE_UID_DIFF,		/* 23 */
+	FILETYPE_UID_FERITE,	/* 24 */
+	FILETYPE_UID_HTML,		/* 25 */
+	FILETYPE_UID_VHDL,		/* 26 */
+	FILETYPE_UID_JS,		/* 27 */
+	FILETYPE_UID_LUA,		/* 28 */
+	FILETYPE_UID_HASKELL,	/* 29 */
+	FILETYPE_UID_CS,		/* 30 */
+	FILETYPE_UID_BASIC,		/* 31 */
+	FILETYPE_UID_HAXE,		/* 32 */
+	FILETYPE_UID_REST		/* 33 */
 };
 
 
@@ -99,7 +100,7 @@ void filetypes_init_types()
 		filetypes[ft_id]->actions = g_new0(struct build_actions, 1);
 	}
 
-#define C	// these macros are only to ease navigation
+#define C	/* these macros are only to ease navigation */
 	filetypes[GEANY_FILETYPES_C]->id = GEANY_FILETYPES_C;
 	filetypes[GEANY_FILETYPES_C]->uid = FILETYPE_UID_C;
 	filetypes[GEANY_FILETYPES_C]->lang = 0;
@@ -155,7 +156,7 @@ void filetypes_init_types()
 	filetypes[GEANY_FILETYPES_JAVA]->comment_open = g_strdup("/*");
 	filetypes[GEANY_FILETYPES_JAVA]->comment_close = g_strdup("*/");
 
-#define PAS // to avoid warnings when building under Windows, the symbol PASCAL is there defined
+#define PAS /* to avoid warnings when building under Windows, the symbol PASCAL is there defined */
 	filetypes[GEANY_FILETYPES_PASCAL]->id = GEANY_FILETYPES_PASCAL;
 	filetypes[GEANY_FILETYPES_PASCAL]->uid = FILETYPE_UID_PASCAL;
 	filetypes[GEANY_FILETYPES_PASCAL]->lang = 4;
@@ -345,7 +346,7 @@ void filetypes_init_types()
 	filetypes[GEANY_FILETYPES_XML]->title = g_strdup(_("XML document"));
 	filetypes[GEANY_FILETYPES_XML]->extension = g_strdup("xml");
 	filetypes[GEANY_FILETYPES_XML]->pattern = utils_strv_new(
-		"*.xml", "*.sgml", "*.xsl", "*.xslt", "*.xsd", NULL);
+		"*.xml", "*.sgml", "*.xsl", "*.xslt", "*.xsd", "*.xhtml", NULL);
 	filetypes[GEANY_FILETYPES_XML]->comment_open = g_strdup("<!--");
 	filetypes[GEANY_FILETYPES_XML]->comment_close = g_strdup("-->");
 
@@ -363,7 +364,7 @@ void filetypes_init_types()
 #define HTML
 	filetypes[GEANY_FILETYPES_HTML]->id = GEANY_FILETYPES_HTML;
 	filetypes[GEANY_FILETYPES_HTML]->uid = FILETYPE_UID_HTML;
-	filetypes[GEANY_FILETYPES_HTML]->lang = -2;
+	filetypes[GEANY_FILETYPES_HTML]->lang = 29;
 	filetypes[GEANY_FILETYPES_HTML]->name = g_strdup("HTML");
 	filetypes[GEANY_FILETYPES_HTML]->title = g_strdup_printf(_("%s source file"), "HTML");
 	filetypes[GEANY_FILETYPES_HTML]->extension = g_strdup("html");
@@ -510,36 +511,36 @@ void filetypes_init()
 	create_sub_menu(sub_menu_markup, sub_item_markup, _("_Markup Languages"));
 	create_sub_menu(sub_menu_misc, sub_item_misc, _("M_iscellaneous Languages"));
 
-	// Append all filetypes to the filetype menu
+	/* Append all filetypes to the filetype menu */
 	for (ft_id = 0; ft_id < GEANY_MAX_FILE_TYPES; ft_id++)
 	{
 		filetype *ft = filetypes[ft_id];
 		const gchar *title = ft->title;
 
-		// insert separators for different filetype groups
+		/* insert separators for different filetype groups */
 		switch (ft_id)
 		{
-			case GEANY_FILETYPES_GROUP_COMPILED:	// programming
+			case GEANY_FILETYPES_GROUP_COMPILED:	/* programming */
 			{
 				sub_menu = sub_menu_programming;
 				break;
 			}
-			case GEANY_FILETYPES_GROUP_SCRIPT:	// scripts
+			case GEANY_FILETYPES_GROUP_SCRIPT:	/* scripts */
 			{
 				sub_menu = sub_menu_scripts;
 				break;
 			}
-			case GEANY_FILETYPES_GROUP_MARKUP:	// markup
-			{	// (include also CSS, not really markup but fit quite well to HTML)
+			case GEANY_FILETYPES_GROUP_MARKUP:	/* markup */
+			{	/* (include also CSS, not really markup but fit quite well to HTML) */
 				sub_menu = sub_menu_markup;
 				break;
 			}
-			case GEANY_FILETYPES_GROUP_MISC:	// misc
+			case GEANY_FILETYPES_GROUP_MISC:	/* misc */
 			{
 				sub_menu = sub_menu_misc;
 				break;
 			}
-			case GEANY_FILETYPES_ALL:	// none
+			case GEANY_FILETYPES_ALL:	/* none */
 			{
 				sub_menu = filetype_menu;
 				title = _("None");
@@ -553,7 +554,7 @@ void filetypes_init()
 }
 
 
-// If uid is valid, return corresponding filetype, otherwise NULL.
+/* If uid is valid, return corresponding filetype, otherwise NULL. */
 filetype *filetypes_get_from_uid(gint uid)
 {
 	gint i;
@@ -569,9 +570,43 @@ filetype *filetypes_get_from_uid(gint uid)
 }
 
 
-static filetype *find_shebang(gint idx)
+/* Detect filetype only based on the filename extension.
+ * utf8_filename can include the full path. */
+filetype *filetypes_detect_from_extension(const gchar *utf8_filename)
+{
+	GPatternSpec *pattern;
+	gchar *base_filename;
+	gint i, j;
+
+	/* to match against the basename of the file(because of Makefile*) */
+	base_filename = g_path_get_basename(utf8_filename);
+#ifdef G_OS_WIN32
+	/* use lower case basename */
+	setptr(base_filename, g_utf8_strdown(base_filename, -1));
+#endif
+
+	for(i = 0; i < GEANY_MAX_FILE_TYPES; i++)
+	{
+		for (j = 0; filetypes[i]->pattern[j] != NULL; j++)
+		{
+			pattern = g_pattern_spec_new(filetypes[i]->pattern[j]);
+			if (g_pattern_match_string(pattern, base_filename))
+			{
+				g_free(base_filename);
+				g_pattern_spec_free(pattern);
+				return filetypes[i];
+			}
+			g_pattern_spec_free(pattern);
+		}
+	}
+
+	g_free(base_filename);
+	return filetypes[GEANY_FILETYPES_ALL];
+}
+
+
+static filetype *find_shebang(const gchar *utf8_filename, const gchar *line)
 {
-	gchar *line = sci_get_line(doc_list[idx].sci, 0);
 	filetype *ft = NULL;
 
 	if (strlen(line) > 2 && line[0] == '#' && line[1] == '!')
@@ -580,7 +615,7 @@ static filetype *find_shebang(gint idx)
 		gchar *basename_interpreter = tmp;
 
 		if (strncmp(tmp, "env ", 4) == 0 && strlen(tmp) > 4)
-		{	// skip "env" and read the following interpreter
+		{	/* skip "env" and read the following interpreter */
 			basename_interpreter +=4;
 		}
 
@@ -613,47 +648,61 @@ static filetype *find_shebang(gint idx)
 
 		g_free(tmp);
 	}
-	// detect XML files
-	if (strncmp(line, "<?xml", 5) == 0)
+	/* detect XML files */
+	if (utf8_filename && strncmp(line, "<?xml", 5) == 0)
 	{
-		// HTML and DocBook files might also start with <?xml, so detect them based on filename
-		// extension and use the detected filetype, else assume XML
-		ft = filetypes_detect_from_filename(doc_list[idx].file_name);
+		/* HTML and DocBook files might also start with <?xml, so detect them based on filename
+		 * extension and use the detected filetype, else assume XML */
+		ft = filetypes_detect_from_extension(utf8_filename);
 		if (FILETYPE_ID(ft) != GEANY_FILETYPES_HTML &&
 			FILETYPE_ID(ft) != GEANY_FILETYPES_DOCBOOK &&
-			FILETYPE_ID(ft) != GEANY_FILETYPES_PERL &&	// Perl, Python and PHP only to be safe
+			FILETYPE_ID(ft) != GEANY_FILETYPES_PERL &&	/* Perl, Python and PHP only to be safe */
 			FILETYPE_ID(ft) != GEANY_FILETYPES_PHP &&
 			FILETYPE_ID(ft) != GEANY_FILETYPES_PYTHON)
-
+		{
 			ft = filetypes[GEANY_FILETYPES_XML];
+		}
 	}
 	else if (strncmp(line, "<?php", 5) == 0)
 	{
 		ft = filetypes[GEANY_FILETYPES_PHP];
 	}
 
-	g_free(line);
 	return ft;
 }
 
 
-/* Detect the filetype for document idx, checking for a shebang, then filename extension. */
+/* Detect the filetype checking for a shebang, then filename extension. */
+static filetype *filetypes_detect_from_file_internal(const gchar *utf8_filename, const gchar *line)
+{
+	filetype *ft;
+
+	/* try to find a shebang and if found use it prior to the filename extension
+	 * also checks for <?xml */
+	ft = find_shebang(utf8_filename, line);
+	if (ft != NULL)
+		return ft;
+
+	if (utf8_filename == NULL)
+		return filetypes[GEANY_FILETYPES_ALL];
+
+	return filetypes_detect_from_extension(utf8_filename);
+}
+
+
+/* Detect the filetype for document idx. */
 filetype *filetypes_detect_from_file(gint idx)
 {
 	filetype *ft;
+	gchar *line;
 
 	if (! DOC_IDX_VALID(idx))
 		return filetypes[GEANY_FILETYPES_ALL];
 
-	// try to find a shebang and if found use it prior to the filename extension
-	// also checks for <?xml
-	ft = find_shebang(idx);
-	if (ft != NULL) return ft;
-
-	if (doc_list[idx].file_name == NULL)
-		return filetypes[GEANY_FILETYPES_ALL];
-
-	return filetypes_detect_from_filename(doc_list[idx].file_name);
+	line = sci_get_line(doc_list[idx].sci, 0);
+	ft = filetypes_detect_from_file_internal(doc_list[idx].file_name, line);
+	g_free(line);
+	return ft;
 }
 
 
@@ -661,40 +710,28 @@ filetype *filetypes_detect_from_file(gint idx)
  * utf8_filename can include the full path. */
 filetype *filetypes_detect_from_filename(const gchar *utf8_filename)
 {
-	GPatternSpec *pattern;
-	gchar *base_filename;
-	gint i, j;
+	gchar line[1024];
+	FILE *f;
+	gchar *locale_name = utils_get_locale_from_utf8(utf8_filename);
 
-	// to match against the basename of the file(because of Makefile*)
-	base_filename = g_path_get_basename(utf8_filename);
-#ifdef G_OS_WIN32
-	// use lower case basename
-	setptr(base_filename, g_utf8_strdown(base_filename, -1));
-#endif
-
-	for(i = 0; i < GEANY_MAX_FILE_TYPES; i++)
+	f = g_fopen(locale_name, "r");
+	g_free(locale_name);
+	if (f != NULL)
 	{
-		for (j = 0; filetypes[i]->pattern[j] != NULL; j++)
+		if (fgets(line, sizeof(line), f) != NULL)
 		{
-			pattern = g_pattern_spec_new(filetypes[i]->pattern[j]);
-			if (g_pattern_match_string(pattern, base_filename))
-			{
-				g_free(base_filename);
-				g_pattern_spec_free(pattern);
-				return filetypes[i];
-			}
-			g_pattern_spec_free(pattern);
+			fclose(f);
+			return filetypes_detect_from_file_internal(utf8_filename, line);
 		}
+		fclose(f);
 	}
-
-	g_free(base_filename);
-	return filetypes[GEANY_FILETYPES_ALL];
+	return filetypes_detect_from_extension(utf8_filename);
 }
 
 
 void filetypes_select_radio_item(const filetype *ft)
 {
-	// app->ignore_callback has to be set by the caller
+	/* app->ignore_callback has to be set by the caller */
 	if (ft == NULL)
 		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
 			radio_items[filetypes[GEANY_FILETYPES_ALL]->id]), TRUE);
@@ -763,7 +800,7 @@ static void load_settings(gint ft, GKeyFile *config, GKeyFile *configh)
 	GError *error = NULL;
 	gboolean tmp;
 
-	// default extension
+	/* default extension */
 	result = g_key_file_get_string(configh, "settings", "extension", NULL);
 	if (result == NULL) result = g_key_file_get_string(config, "settings", "extension", NULL);
 	if (result != NULL)
@@ -771,7 +808,7 @@ static void load_settings(gint ft, GKeyFile *config, GKeyFile *configh)
 		setptr(filetypes[ft]->extension, result);
 	}
 
-	// read comment notes
+	/* read comment notes */
 	result = g_key_file_get_string(configh, "settings", "comment_open", NULL);
 	if (result == NULL) result = g_key_file_get_string(config, "settings", "comment_open", NULL);
 	if (result != NULL)
@@ -799,7 +836,7 @@ static void load_settings(gint ft, GKeyFile *config, GKeyFile *configh)
 	}
 	else filetypes[ft]->comment_use_indent = tmp;
 
-	// read context action
+	/* read context action */
 	result = g_key_file_get_string(configh, "settings", "context_action_cmd", NULL);
 	if (result == NULL) result = g_key_file_get_string(config, "settings", "context_action_cmd", NULL);
 	if (result != NULL)
@@ -807,7 +844,7 @@ static void load_settings(gint ft, GKeyFile *config, GKeyFile *configh)
 		filetypes[ft]->context_action_cmd = result;
 	}
 
-	// read build settings
+	/* read build settings */
 	result = g_key_file_get_string(configh, "build_settings", "compiler", NULL);
 	if (result == NULL) result = g_key_file_get_string(config, "build_settings", "compiler", NULL);
 	if (result != NULL)
@@ -874,7 +911,7 @@ void filetypes_load_config(gint ft_id)
 	config = g_key_file_new();
 	config_home = g_key_file_new();
 	{
-		// highlighting uses GEANY_FILETYPES_ALL for common settings
+		/* highlighting uses GEANY_FILETYPES_ALL for common settings */
 		gchar *ext = (ft_id != GEANY_FILETYPES_ALL) ?
 			filetypes_get_conf_extension(ft_id) : g_strdup("common");
 		gchar *f0 = g_strconcat(app->datadir, G_DIR_SEPARATOR_S "filetypes.", ext, NULL);
@@ -901,7 +938,7 @@ gchar *filetypes_get_conf_extension(gint filetype_idx)
 {
 	gchar *result;
 
-	// Handle any special extensions different from lowercase filetype->name
+	/* Handle any special extensions different from lowercase filetype->name */
 	switch (filetype_idx)
 	{
 		case GEANY_FILETYPES_CPP: result = g_strdup("cpp"); break;
@@ -985,8 +1022,6 @@ GtkFileFilter *filetypes_create_file_filter(filetype *ft)
 	new_filter = gtk_file_filter_new();
 	gtk_file_filter_set_name(new_filter, ft->title);
 
-	// (GEANY_FILETYPES_MAX_PATTERNS - 1) because the last field in pattern is NULL
-	//for (i = 0; i < (GEANY_MAX_PATTERNS - 1) && ft->pattern[i]; i++)
 	for (i = 0; ft->pattern[i]; i++)
 	{
 		gtk_file_filter_add_pattern(new_filter, ft->pattern[i]);
@@ -996,7 +1031,7 @@ GtkFileFilter *filetypes_create_file_filter(filetype *ft)
 }
 
 
-// Indicates whether there is a tag parser for the filetype or not.
+/* Indicates whether there is a tag parser for the filetype or not. */
 gboolean filetype_has_tags(filetype *ft)
 {
 	g_return_val_if_fail(ft != NULL, FALSE);
