@@ -1,8 +1,8 @@
 /*
  *      geanyobject.c - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2007 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
- *      Copyright 2007 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
+ *      Copyright 2007-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2007-2008 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *      MA 02110-1301, USA.
  *
- * $Id: geanyobject.c 1816 2007-08-23 15:22:13Z ntrel $
+ * $Id: geanyobject.c 2287 2008-02-27 13:17:29Z eht16 $
  */
 
 /* GObject used for connecting and emitting signals when certain events happen,
@@ -41,8 +41,8 @@ typedef struct _GeanyObjectPrivate GeanyObjectPrivate;
 
 struct _GeanyObjectPrivate
 {
-	/* add your private declarations here */
-	gchar dummy; // to avoid warnings (g_type_class_add_private: assertion `private_size > 0' failed)
+	/* to avoid warnings (g_type_class_add_private: assertion `private_size > 0' failed) */
+	gchar dummy;
 };
 
 static void geany_object_class_init			(GeanyObjectClass *klass);
@@ -116,6 +116,33 @@ static void create_signals(GObjectClass *g_object_class)
 		gtk_marshal_NONE__INT,
 		G_TYPE_NONE, 1,
 		G_TYPE_INT);
+
+	geany_object_signals[GCB_PROJECT_OPEN] = g_signal_new (
+		"project-open",
+		G_OBJECT_CLASS_TYPE (g_object_class),
+		G_SIGNAL_RUN_FIRST,
+		G_STRUCT_OFFSET (GeanyObjectClass, project_open),
+		NULL, NULL,
+		gtk_marshal_NONE__INT,
+		G_TYPE_NONE, 1,
+		G_TYPE_POINTER);
+	geany_object_signals[GCB_PROJECT_SAVE] = g_signal_new (
+		"project-save",
+		G_OBJECT_CLASS_TYPE (g_object_class),
+		G_SIGNAL_RUN_FIRST,
+		G_STRUCT_OFFSET (GeanyObjectClass, project_save),
+		NULL, NULL,
+		gtk_marshal_NONE__INT,
+		G_TYPE_NONE, 1,
+		G_TYPE_POINTER);
+	geany_object_signals[GCB_PROJECT_CLOSE] = g_signal_new (
+		"project-close",
+		G_OBJECT_CLASS_TYPE (g_object_class),
+		G_SIGNAL_RUN_FIRST,
+		G_STRUCT_OFFSET (GeanyObjectClass, project_close),
+		NULL, NULL,
+		gtk_marshal_NONE__NONE,
+		G_TYPE_NONE, 0);
 }
 
 
@@ -146,7 +173,7 @@ GObject* geany_object_new(void)
 }
 
 
-void geany_object_finalize(GObject *object)
+static void geany_object_finalize(GObject *object)
 {
 	GeanyObject *self;
 
