@@ -19,7 +19,7 @@
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *      MA 02110-1301, USA.
  *
- * $Id: geanyobject.h 2150 2008-01-06 18:11:57Z eht16 $
+ * $Id: geanyobject.h 2267 2008-02-20 11:24:23Z eht16 $
  */
 
 
@@ -76,7 +76,7 @@ struct _GeanyObjectClass
 	void (*document_activate)(gint idx);
 	void (*project_open)(GKeyFile *keyfile);
 	void (*project_save)(GKeyFile *keyfile);
-	void (*project_close)();
+	void (*project_close)(void);
 };
 
 GType		geany_object_get_type	(void);
