@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: main.h 2150 2008-01-06 18:11:57Z eht16 $
+ * $Id: main.h 2437 2008-04-02 13:48:39Z eht16 $
  */
 
 
@@ -38,8 +38,10 @@ extern CommandLineOptions cl_options;
 
 typedef struct GeanyStatus
 {
-	gboolean	opening_session_files;	// state at startup while opening session files
-	gboolean	quitting;	// state when Geany is quitting completely
+	gboolean	opening_session_files;	/* state at startup while opening session files */
+	gboolean	closing_all; /* the state while closing all tabs
+							  * (used to prevent notebook switch page signals) */
+	gboolean	quitting;	/* state when Geany is quitting completely */
 	gboolean	main_window_realized;
 }
 GeanyStatus;
@@ -49,6 +51,6 @@ extern GeanyStatus main_status;
 
 gchar *get_argv_filename(const gchar *filename);
 
-void main_quit();
+void main_quit(void);
 
 #endif
