@@ -1,7 +1,9 @@
 /*
  *      navqueue.c - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2007 Dave Moore <wrex006@gmail.com>
+ *      Copyright 2007 Dave Moore <wrex006(at)gmail(dot)com>
+ *      Copyright 2007-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2007-2008 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -17,7 +19,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: navqueue.c 1904 2007-09-25 16:44:33Z ntrel $
+ * $Id: navqueue.c 2505 2008-04-19 08:14:00Z eht16 $
  */
 
 /*
@@ -33,13 +35,11 @@
 #include "support.h"
 
 
-// for the navigation history queue
+/* for the navigation history queue */
 typedef struct
 {
-	gchar *file;	// this is the tagmanager filename, not document::file_name
-	/// TODO maybe it is better to work on positions than on lines to be more accurate when
-	/// switching back or forward, sci_get_position_from_line() could be used for tm_tag lines
-	gint line;	// line is counted with 1 as the first line, not 0
+	gchar *file;	/* This is the document's filename, in UTF-8 */
+	gint pos;
 } filepos;
 
 static GQueue *navigation_queue;
@@ -69,7 +69,7 @@ void navqueue_free()
 }
 
 
-static void adjust_buttons()
+static void adjust_buttons(void)
 {
 	if (g_queue_get_length(navigation_queue) < 2)
 	{
@@ -83,10 +83,10 @@ static void adjust_buttons()
 		gtk_widget_set_sensitive(navigation_buttons[1], FALSE);
 		return;
 	}
-	// forward should be sensitive since where not at the start
+	/* forward should be sensitive since where not at the start */
 	gtk_widget_set_sensitive(navigation_buttons[1], TRUE);
 
-	// back should be sensitive if there's a place to go back to
+	/* back should be sensitive if there's a place to go back to */
 	(nav_queue_pos < g_queue_get_length(navigation_queue) - 1) ?
 		gtk_widget_set_sensitive(navigation_buttons[0], TRUE) :
 			gtk_widget_set_sensitive(navigation_buttons[0], FALSE);
@@ -94,32 +94,31 @@ static void adjust_buttons()
 
 
 static gboolean
-queue_pos_matches(guint queue_pos, const gchar *fname, gint line)
+queue_pos_matches(guint queue_pos, const gchar *fname, gint pos)
 {
 	if (queue_pos < g_queue_get_length(navigation_queue))
 	{
 		filepos *fpos = g_queue_peek_nth(navigation_queue, queue_pos);
 
-		return (utils_str_equal(fpos->file, fname) && fpos->line == line);
+		return (utils_str_equal(fpos->file, fname) && fpos->pos == pos);
 	}
 	return FALSE;
 }
 
 
-static void add_new_position(gchar *tm_filename, gint line)
+static void add_new_position(gchar *utf8_filename, gint pos)
 {
 	filepos *npos;
 	guint i;
 
-	if (queue_pos_matches(nav_queue_pos, tm_filename, line))
-		return;	// prevent duplicates
+	if (queue_pos_matches(nav_queue_pos, utf8_filename, pos))
+		return;	/* prevent duplicates */
 
 	npos = g_new0(filepos, 1);
-	npos->file = tm_filename;
-	npos->line = line;
+	npos->file = utf8_filename;
+	npos->pos = pos;
 
-	// if we've jumped to a new position from
-	// inside the queue rather than going forward
+	/* if we've jumped to a new position from inside the queue rather than going forward */
 	if (nav_queue_pos > 0)
 	{
 		for (i = 0; i < nav_queue_pos; i++)
@@ -133,27 +132,40 @@ static void add_new_position(gchar *tm_filename, gint line)
 }
 
 
-/* Adds the current document position to the queue before adding the new position.
- * line is counted with 1 as the first line, not 0. */
-gboolean navqueue_goto_line(gint new_idx, gint line)
+/**
+ *  Add old file position and new file position to the navqueue, then goes to the new position.
+ *
+ *  @param old_idx the %document index of the previous position, if set as invalid (-1) then no old
+ *         position is set
+ *  @param new_idx the %document index of the new position, must be valid.
+ *  @param line the line number of the new position. It is counted with 1 as the first line, not 0.
+ *
+ *  @return @a TRUE if the cursor has changed the position to @a line or @a FALSE otherwise.
+ **/
+gboolean navqueue_goto_line(gint old_idx, gint new_idx, gint line)
 {
-	gint old_idx = document_get_cur_idx();
+	gint pos;
 
-	g_return_val_if_fail(DOC_IDX_VALID(old_idx), FALSE);
 	g_return_val_if_fail(DOC_IDX_VALID(new_idx), FALSE);
-	g_return_val_if_fail(doc_list[new_idx].tm_file, FALSE);
 	g_return_val_if_fail(line >= 1, FALSE);
 
-	// first add old file as old position
-	if (doc_list[old_idx].tm_file)
-	{
-		gint cur_line = sci_get_current_line(doc_list[old_idx].sci);
+	pos = sci_get_position_from_line(doc_list[new_idx].sci, line - 1);
 
-		add_new_position(doc_list[old_idx].tm_file->file_name, cur_line + 1);
+	/* first add old file position */
+	if (DOC_IDX_VALID(old_idx) && doc_list[old_idx].file_name)
+	{
+		gint cur_pos = sci_get_current_position(doc_list[old_idx].sci);
+
+		add_new_position(doc_list[old_idx].file_name, cur_pos);
 	}
 
-	add_new_position(doc_list[new_idx].tm_file->file_name, line);
-	return utils_goto_line(new_idx, line);
+	/* now add new file position */
+	if (doc_list[new_idx].file_name)
+	{
+		add_new_position(doc_list[new_idx].file_name, pos);
+	}
+
+	return utils_goto_pos(new_idx, pos);
 }
 
 
@@ -161,20 +173,20 @@ void navqueue_go_back()
 {
 	filepos *fprev;
 
-	// return if theres no place to go back to
+	/* return if theres no place to go back to */
 	if (g_queue_is_empty(navigation_queue) ||
 		nav_queue_pos >= g_queue_get_length(navigation_queue) - 1)
 		return;
 
-	// jump back
+	/* jump back */
 	fprev = g_queue_peek_nth(navigation_queue, nav_queue_pos + 1);
-	if (utils_goto_file_line(fprev->file, TRUE, fprev->line))
+	if (utils_goto_file_pos(fprev->file, FALSE, fprev->pos))
 	{
 		nav_queue_pos++;
 	}
 	else
 	{
-		/// TODO: add option to re open the file
+		/** TODO: add option to re open the file */
 		g_free(g_queue_pop_nth(navigation_queue, nav_queue_pos + 1));
 	}
 	adjust_buttons();
@@ -189,18 +201,44 @@ void navqueue_go_forward()
 		nav_queue_pos >= g_queue_get_length(navigation_queue))
 		return;
 
-	// jump forward
+	/* jump forward */
 	fnext = g_queue_peek_nth(navigation_queue, nav_queue_pos - 1);
-	if (utils_goto_file_line(fnext->file, TRUE, fnext->line))
+	if (utils_goto_file_pos(fnext->file, FALSE, fnext->pos))
 	{
 		nav_queue_pos--;
 	}
 	else
 	{
-		/// TODO: add option to re open the file
+		/** TODO: add option to re open the file */
 		g_free(g_queue_pop_nth(navigation_queue, nav_queue_pos - 1));
 	}
 
 	adjust_buttons();
 }
 
+
+static gint find_by_filename(gconstpointer a, gconstpointer b)
+{
+	if (utils_str_equal(((const filepos*)a)->file, (const gchar*) b))
+		return 0;
+	else
+		return 1;
+}
+
+
+/* Remove all elements with the given filename */
+void navqueue_remove_file(const gchar *filename)
+{
+	GList *match;
+
+	if (filename == NULL)
+		return;
+
+	while ((match = g_queue_find_custom(navigation_queue, filename, find_by_filename)))
+	{
+		g_free(match->data);
+		g_queue_delete_link(navigation_queue, match);
+	}
+
+	adjust_buttons();
+}
