@@ -1,7 +1,9 @@
 /*
  *      navqueue.h - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2007 Dave Moore <wrex006@gmail.com>
+ *      Copyright 2007 Dave Moore <wrex006(at)gmail(dot)com>
+ *      Copyright 2007-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2007-2008 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -17,24 +19,31 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: navqueue.h 1900 2007-09-25 12:39:41Z ntrel $
+ * $Id: navqueue.h 2505 2008-04-19 08:14:00Z eht16 $
  */
 
+/**
+ *  @file navqueue.h
+ * Simple code navigation
+ **/
+
 
 #ifndef GEANY_NAVQUEUE_H
 #define GEANY_NAVQUEUE_H 1
 
 
-void navqueue_init();
+void navqueue_init(void);
 
-void navqueue_free();
+void navqueue_free(void);
+
+void navqueue_remove_file(const gchar *filename);
 
 
-gboolean navqueue_goto_line(gint new_idx, gint line);
+gboolean navqueue_goto_line(gint old_idx, gint new_idx, gint line);
 
-void navqueue_go_back();
+void navqueue_go_back(void);
 
-void navqueue_go_forward();
+void navqueue_go_forward(void);
 
 
 #endif
