@@ -18,18 +18,18 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: notebook.h 2150 2008-01-06 18:11:57Z eht16 $
+ * $Id: notebook.h 2287 2008-02-27 13:17:29Z eht16 $
  */
 
 #ifndef GEANY_NOTEBOOK_H
 #define GEANY_NOTEBOOK_H 1
 
-void notebook_init();
+void notebook_init(void);
 
 /* Returns page number of notebook page, or -1 on error */
 gint notebook_new_tab(gint doc_idx);
 
-// Always use this instead of gtk_notebook_remove_page().
+/* Always use this instead of gtk_notebook_remove_page(). */
 void notebook_remove_page(gint page_num);
 
 #endif
