@@ -19,92 +19,34 @@
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *      MA 02110-1301, USA.
  *
- * $Id: plugindata.h 2223 2008-02-04 13:40:14Z ntrel $
+ * $Id: plugindata.h 2496 2008-04-17 17:48:12Z eht16 $
  */
 
+/**
+ * @file plugindata.h
+ * This file defines the plugin API, the interface between Geany and its plugins.
+ * For detailed documentation of the plugin system please read the plugin
+ * API documentation.
+ **/
+
+
 #ifndef PLUGIN_H
 #define PLUGIN_H
 
-/**
- * Public symbols supported:
- *
- * version_check()
- * 	Use VERSION_CHECK() macro instead. Required by Geany.
- *
- * PluginInfo* info()
- * 	Use PLUGIN_INFO() macro to define it. Required by Geany.
- *
- * GeanyData* geany_data
- * 	Geany owned fields and functions.
- *
- * PluginFields* plugin_fields
- * 	Plugin owned fields, including flags.
- *
- * GeanyCallback geany_callbacks[]
- * 	An array for connecting GeanyObject events, which should be terminated with
- * 	{NULL, NULL, FALSE, NULL}. See signals below.
- *
- * void configure(GtkWidget *parent)
- * 	Called when the plugin should show a configure dialog to let the user set some basic
- *  plugin configuration. Optionally, can be omitted when not needed.
- *
- * void init(GeanyData *data)
- * 	Called after loading the plugin. data is the same as geany_data.
- *
- * void cleanup()
- * 	Called before unloading the plugin. Required for normal plugins - it should undo
- * 	everything done in init() - e.g. destroy menu items, free memory.
- */
-
-/**
- * Signals:
- *
- * "document-new"
- * 	Sent when a new document is created.
- *  Handler: void user_function(GObject *obj, gint idx, gpointer user_data);
- *
- * "document-open"
- * 	Sent when a file is opened.
- *  Handler: void user_function(GObject *obj, gint idx, gpointer user_data);
- *
- * "document-save"
- * 	Sent when a file is saved.
- *  Handler: void user_function(GObject *obj, gint idx, gpointer user_data);
- *
- * "document-activate"
- * 	Sent when switching notebook pages.
- *  Handler: void user_function(GObject *obj, gint idx, gpointer user_data);
- *
- * "project-open"
- * 	Sent after a project is opened but before session files are loaded.
- *  Handler: void user_function(GObject *obj, GKeyFile *config, gpointer user_data);
- *
- * "project-save"
- * 	Sent when a project is saved(happens when the project is created, the properties
- *  dialog is closed or Geany is exited). This signal is emitted shortly before Geany
- *  will write the contents of the GKeyFile to the disc.
- *  Handler: void user_function(GObject *obj, GKeyFile *config, gpointer user_data);
- *
- * "project-close"
- * 	Sent after a project is closed.
- *  Handler: void user_function(GObject *obj, gpointer user_data);
- */
-
-
 /* The API version should be incremented whenever any plugin data types below are
  * modified or appended to. */
-static const gint api_version = 42;
+static const gint api_version = 53;
 
 /* The ABI version should be incremented whenever existing fields in the plugin
  * data types below have to be changed or reordered. It should stay the same if fields
  * are only appended, as this doesn't affect existing fields. */
-static const gint abi_version = 20;
+static const gint abi_version = 24;
 
-/* This performs runtime checks that try to ensure:
- * 1. Geany ABI data types are compatible with this plugin.
- * 2. Geany sources provide the required API for this plugin. */
-/* TODO: if possible, the API version should be checked at compile time, not runtime. */
-#define VERSION_CHECK(api_required) \
+/** Check the plugin can be loaded by Geany.
+ * This performs runtime checks that try to ensure:
+ * - Geany ABI data types are compatible with this plugin.
+ * - Geany sources provide the required API for this plugin. */
+#define PLUGIN_VERSION_CHECK(api_required) \
 	gint version_check(gint abi_ver) \
 	{ \
 		if (abi_ver != abi_version) \
@@ -115,21 +57,28 @@ static const gint abi_version = 20;
 	}
 
 
+/** Plugin info structure to hold basic information about a plugin.
+ *  Should only be set with PLUGIN_INFO. */
 typedef struct PluginInfo
 {
-	gchar	*name;			// name of plugin
-	gchar	*description;	// description of plugin
-	gchar	*version;		// version of plugin
-	gchar	*author;		// author of plugin
-	gpointer reserved2;		// reserved for later use
+	/** The name of the plugin. */
+	gchar	*name;
+	/** The description of the plugin. */
+	gchar	*description;
+	/** The version of the plugin. */
+	gchar	*version;
+	/** The author of the plugin. */
+	gchar	*author;
+	/** Reserved for later use. */
+	gpointer reserved2;
 }
 PluginInfo;
 
 #include <string.h>
 
-/* Sets the plugin name and a brief description of what it is. */
+/** Set the plugin name and some other basic information about a plugin. */
 #define PLUGIN_INFO(p_name, p_description, p_version, p_author) \
-	PluginInfo *info() \
+	PluginInfo *info(void) \
 	{ \
 		static PluginInfo p_info; \
 		\
@@ -142,93 +91,124 @@ PluginInfo;
 	}
 
 
-/* For geany_callbacks array - see top of file. */
+/** Declare and initialise a keybinding group.
+ * @code KeyBindingGroup plugin_key_group[1]; @endcode
+ * You must then set the @c plugin_key_group::keys[] entries for the group in init().
+ * The @c plugin_key_group::label field is set by Geany after @c init()
+ * is called, to the name of the plugin.
+ * @param group_name A unique group name (without quotes) to be used in the
+ * configuration file, such as @c html_chars.
+ * @param key_count	The number of keybindings the group will hold. */
+#define PLUGIN_KEY_GROUP(group_name, key_count) \
+	static KeyBinding plugin_keys[key_count]; \
+	\
+	/* We have to declare plugin_key_group as a single element array.
+	 * Declaring as a pointer to a struct doesn't work with g_module_symbol(). */ \
+	KeyBindingGroup plugin_key_group[1] = \
+	{ \
+		{G_STRINGIFY(group_name), NULL, key_count, plugin_keys} \
+	};
+
+
+/** callback array entry */
 typedef struct GeanyCallback
 {
+	/** The name of signal, must be an existing signal. For a list of available signals,
+	 *  please see the @link signals Signal documentation @endlink. */
 	gchar		*signal_name;
+	/** A callback function which is called when the signal is emitted. */
 	GCallback	callback;
+	/** Set to TRUE to connect your handler with g_signal_connect_after(). */
 	gboolean	after;
+	/** The user data passed to the signal handler. */
 	gpointer	user_data;
 }
 GeanyCallback;
 
 
+
+/** Flags to be set by plugins in PluginFields struct. */
 typedef enum
 {
-	PLUGIN_IS_DOCUMENT_SENSITIVE	= 1 << 0	// if menu_item should be disabled when there are no documents
+	/** Whether a plugin's menu item should be disabled when there are no open documents */
+	PLUGIN_IS_DOCUMENT_SENSITIVE	= 1 << 0
 }
 PluginFlags;
 
-/* Fields set and owned by the plugin.
- * Note: Remember to increment api_version (and abi_version if necessary) when
- * making changes. */
+/** Fields set and owned by the plugin. */
+/* Note: Remember to increment api_version (and abi_version if necessary) when making changes. */
 typedef struct PluginFields
 {
+	/** Bitmask of PluginFlags. */
 	PluginFlags	flags;
-	GtkWidget	*menu_item;	// required if using PLUGIN_IS_DOCUMENT_SENSITIVE, ignored otherwise
+	/** Pointer to a plugin's menu item which will be automatically enabled/disabled when there
+	 *  are no open documents and PLUGIN_IS_DOCUMENT_SENSITIVE is set.
+	 *  This is required if using PLUGIN_IS_DOCUMENT_SENSITIVE, ignored otherwise */
+	GtkWidget	*menu_item;
 }
 PluginFields;
 
 
-/* These are fields and functions owned by Geany.
- * Fields and functions will be appended when needed by plugin authors.
- * Note: Remember to increment api_version (and abi_version if necessary) when
- * making changes. */
+/** This contains pointers to global variables and functions owned by Geany for plugins to use.
+ *  Variables and functions will be appended when needed by plugin authors. */
 typedef struct GeanyData
 {
-	GeanyApp	*app;	// Geany application data fields
-	GtkWidget	*tools_menu;	// Almost all plugins should add menu items to the Tools menu only
-	GArray		*doc_array;	// array of document pointers
+	GeanyApp	*app;					/**< Geany application data fields */
+	GtkWidget	*tools_menu;			/**< Most plugins should add menu items to the Tools menu only */
+	GArray		*doc_array;				/**< Dynamic array of document pointers */
 	struct filetype		**filetypes;
 	struct GeanyPrefs	*prefs;
-	struct EditorPrefs	*editor_prefs;
-	struct BuildInfo	*build_info;
+	struct EditorPrefs	*editor_prefs;	/**< Editor settings */
+	struct BuildInfo	*build_info;	/**< Current build information */
 
-	struct DocumentFuncs		*documents;
-	struct ScintillaFuncs		*sci;
-	struct TemplateFuncs		*templates;
-	struct UtilsFuncs			*utils;
-	struct UIUtilsFuncs			*ui;
-	struct SupportFuncs			*support;
-	struct DialogFuncs			*dialogs;
-	struct MsgWinFuncs			*msgwindow;
-	struct EncodingFuncs		*encoding;
-	struct KeybindingFuncs		*keybindings;
-	struct TagManagerFuncs		*tm;
-	struct SearchFuncs			*search;
-	struct HighlightingFuncs	*highlighting;
-	struct FiletypeFuncs		*filetype;
+	struct DocumentFuncs		*documents;		/**< See document.h */
+	struct ScintillaFuncs		*sci;			/**< See sciwrappers.h */
+	struct TemplateFuncs		*templates;		/**< See templates.h */
+	struct UtilsFuncs			*utils;			/**< See utils.h */
+	struct UIUtilsFuncs			*ui;			/**< See ui_utils.h */
+	struct SupportFuncs			*support;		/**< See support.h */
+	struct DialogFuncs			*dialogs;		/**< See dialogs.h */
+	struct MsgWinFuncs			*msgwindow;		/**< See msgwindow.h */
+	struct EncodingFuncs		*encoding;		/**< See encodings.h */
+	struct KeybindingFuncs		*keybindings;	/**< See keybindings.h */
+	struct TagManagerFuncs		*tm;			/**< See tagmanager/include */
+	struct SearchFuncs			*search;		/**< See search.h */
+	struct HighlightingFuncs	*highlighting;	/**< See highlighting.h */
+	struct FiletypeFuncs		*filetype;		/**< See filetypes.h */
+	struct NavQueueFuncs        *navqueue;      /**< See navqueue.h */
 }
 GeanyData;
 
-typedef GeanyData PluginData;	// for compatibility with API < 7
-
 
 /* For more info about these functions, see the main source code.
- * E.g. for GeanyData::document->new_file(), see document_new_file() in document.[hc]. */
+ * E.g. for GeanyData::documents->new_file(), see document_new_file() in document.c. */
 
 
+/* See document.h */
 typedef struct DocumentFuncs
 {
 	gint	(*new_file) (const gchar *filename, struct filetype *ft, const gchar *text);
-	gint	(*get_cur_idx) ();
+	gint	(*get_cur_idx) (void);
 	gint	(*get_n_idx) (guint i);
 	gint	(*find_by_filename) (const gchar *filename, gboolean is_tm_filename);
-	struct document* (*get_current) ();
-	gboolean (*save_file)(gint idx, gboolean force);
-	gint	(*open_file)(const gchar *locale_filename, gboolean readonly,
+	struct document* (*get_current) (void);
+	gboolean (*save_file) (gint idx, gboolean force);
+	gint	(*open_file) (const gchar *locale_filename, gboolean readonly,
 			struct filetype *ft, const gchar *forced_enc);
-	void	(*open_files)(const GSList *filenames, gboolean readonly, struct filetype *ft,
+	void	(*open_files) (const GSList *filenames, gboolean readonly, struct filetype *ft,
 			const gchar *forced_enc);
-	gboolean (*remove)(guint page_num);
-	gboolean (*reload_file)(gint idx, const gchar *forced_enc);
-	void	(*set_encoding)(gint idx, const gchar *new_encoding);
-	void	(*set_text_changed)(gint idx);
+	gboolean (*remove) (guint page_num);
+	gboolean (*reload_file) (gint idx, const gchar *forced_enc);
+	void	(*set_encoding) (gint idx, const gchar *new_encoding);
+	void	(*set_text_changed) (gint idx);
+	void	(*set_filetype) (gint idx, filetype *type);
 }
 DocumentFuncs;
 
+
 struct _ScintillaObject;
 
+/* See sciwrappers.h */
 typedef struct ScintillaFuncs
 {
 	long int (*send_message) (struct _ScintillaObject* sci, unsigned int iMessage,
@@ -269,12 +249,16 @@ typedef struct ScintillaFuncs
 }
 ScintillaFuncs;
 
+
+/* See templates.h */
 typedef struct TemplateFuncs
 {
 	gchar*		(*get_template_fileheader) (gint filetype_idx, const gchar *fname);
 }
 TemplateFuncs;
 
+
+/* See utils.h */
 typedef struct UtilsFuncs
 {
 	gboolean	(*str_equal) (const gchar *a, const gchar *b);
@@ -292,9 +276,17 @@ typedef struct UtilsFuncs
 				 const gint default_value);
 	gchar*		(*get_setting_string) (GKeyFile *config, const gchar *section, const gchar *key,
 				 const gchar *default_value);
+	gboolean	(*spawn_sync) (const gchar *dir, gchar **argv, gchar **env, GSpawnFlags flags,
+				 GSpawnChildSetupFunc child_setup, gpointer user_data, gchar **std_out,
+				 gchar **std_err, gint *exit_status, GError **error);
+	gboolean	(*spawn_async) (const gchar *dir, gchar **argv, gchar **env, GSpawnFlags flags,
+				 GSpawnChildSetupFunc child_setup, gpointer user_data, GPid *child_pid,
+				 GError **error);
 }
 UtilsFuncs;
 
+
+/* See ui_utils.h */
 typedef struct UIUtilsFuncs
 {
 	GtkWidget*	(*dialog_vbox_new) (GtkDialog *dialog);
@@ -309,14 +301,18 @@ typedef struct UIUtilsFuncs
 }
 UIUtilsFuncs;
 
+
+/* See dialogs.h */
 typedef struct DialogFuncs
 {
 	gboolean	(*show_question) (const gchar *text, ...);
 	void		(*show_msgbox) (gint type, const gchar *text, ...);
-	gboolean	(*show_save_as) ();
+	gboolean	(*show_save_as) (void);
 }
 DialogFuncs;
 
+
+/* See support.h */
 typedef struct SupportFuncs
 {
 	GtkWidget*	(*lookup_widget) (GtkWidget *widget, const gchar *widget_name);
@@ -324,6 +320,7 @@ typedef struct SupportFuncs
 SupportFuncs;
 
 
+/* See msgwindow.h */
 typedef struct MsgWinFuncs
 {
 	/* status_add() does not set the status bar - use ui->set_statusbar() instead. */
@@ -333,6 +330,7 @@ typedef struct MsgWinFuncs
 MsgWinFuncs;
 
 
+/* See encodings.h */
 typedef struct EncodingFuncs
 {
 	gchar*			(*convert_to_utf8) (const gchar *buffer, gsize size, gchar **used_encoding);
@@ -343,14 +341,21 @@ typedef struct EncodingFuncs
 EncodingFuncs;
 
 
+struct KeyBindingGroup;
+typedef void (*_KeyCallback) (guint key_id);
+
+/* See keybindings.h */
 typedef struct KeybindingFuncs
 {
-	/* See GeanyKeyCommand enum for cmd_id. */
-	void		(*send_command) (gint cmd_id);
+	void		(*send_command) (guint group_id, guint key_id);
+	void		(*set_item) (struct KeyBindingGroup *group, gsize key_id,
+					_KeyCallback callback, guint key, GdkModifierType mod,
+					gchar *name, gchar *label, GtkWidget *menu_item);
 }
 KeybindingFuncs;
 
 
+/* See highlighting.h */
 typedef struct HighlightingFuncs
 {
 	const struct HighlightingStyle* (*get_style) (gint ft_id, gint style_id);
@@ -358,19 +363,24 @@ typedef struct HighlightingFuncs
 HighlightingFuncs;
 
 
+/* See filetypes.h */
 typedef struct FiletypeFuncs
 {
 	filetype*	(*detect_from_filename) (const gchar *utf8_filename);
+	filetype*	(*get_from_uid) (gint uid);
 }
 FiletypeFuncs;
 
 
+/* See search.h */
 typedef struct SearchFuncs
 {
 	void		(*show_find_in_files_dialog) (const gchar *dir);
 }
 SearchFuncs;
 
+
+/* See tagmanager/include */
 typedef struct TagManagerFuncs
 {
 	gchar*			(*get_real_path) (const gchar *file_name);
@@ -383,4 +393,20 @@ typedef struct TagManagerFuncs
 }
 TagManagerFuncs;
 
+typedef struct NavQueueFuncs
+{
+	gboolean		(*goto_line) (gint old_idx, gint new_idx, gint line);
+}NavQueueFuncs;
+
+
+/* Deprecated aliases */
+#ifndef GEANY_DISABLE_DEPRECATED
+
+typedef GeanyData PluginData;	/* for compatibility with API < 7 */
+
+#define VERSION_CHECK(api_required) \
+	PLUGIN_VERSION_CHECK(api_required)
+
+#endif
+
 #endif
