@@ -19,7 +19,7 @@
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *      MA 02110-1301, USA.
  *
- * $Id: plugins.c 2223 2008-02-04 13:40:14Z ntrel $
+ * $Id: plugins.c 2496 2008-04-17 17:48:12Z eht16 $
  */
 
 /* Code to manage, load and unload plugins. */
@@ -53,9 +53,8 @@
 #include "encodings.h"
 #include "search.h"
 #include "highlighting.h"
-
-void keybindings_cmd(gint cmd_id);	// don't require keybindings.h enum in plugindata.h
-
+#include "keybindings.h"
+#include "navqueue.h"
 
 
 #ifdef G_OS_WIN32
@@ -68,25 +67,39 @@ void keybindings_cmd(gint cmd_id);	// don't require keybindings.h enum in plugin
 typedef struct Plugin
 {
 	GModule 	*module;
-	gchar		*filename;		// plugin filename (/path/libname.so)
+	gchar		*filename;				/* plugin filename (/path/libname.so) */
 	PluginFields	fields;
-	gulong		*signal_ids;		// signal IDs to disconnect when unloading
+	gulong		*signal_ids;			/* signal IDs to disconnect when unloading */
 	gsize		signal_ids_len;
+	KeyBindingGroup	*key_group;
 
-	PluginInfo*	(*info) ();	/* Returns plugin name, description */
+	PluginInfo*	(*info) (void);			/* Returns plugin name, description */
 	void	(*init) (GeanyData *data);	/* Called when the plugin is enabled */
 	void	(*configure) (GtkWidget *parent);	/* plugin configure dialog, optionally */
-	void	(*cleanup) ();		/* Called when the plugin is disabled or when Geany exits */
+	void	(*cleanup) (void);			/* Called when the plugin is disabled or when Geany exits */
 }
 Plugin;
 
 
-static GList *plugin_list = NULL; // list of all available, loadable plugins
-static GList *active_plugin_list = NULL; // list of only actually loaded plugins
+/* list of all available, loadable plugins, only valid as long as the plugin manager dialog is
+ * opened, afterwards it will be destroyed */
+static GList *plugin_list = NULL;
+static GList *active_plugin_list = NULL; /* list of only actually loaded plugins, always valid */
+static gchar **active_plugins_pref = NULL; 	/* list of plugin filenames to load at startup */
+static GList *failed_plugins_list = NULL;	/* plugins the user wants active but can't be used */
+
 static GtkWidget *separator = NULL;
+
 static void pm_show_dialog(GtkMenuItem *menuitem, gpointer user_data);
 
 
+enum
+{
+	PLUGIN_FREE_NON_ACTIVE,
+	PLUGIN_FREE_ALL
+};
+
+
 static DocumentFuncs doc_funcs = {
 	&document_new_file,
 	&document_get_cur_idx,
@@ -99,7 +112,8 @@ static DocumentFuncs doc_funcs = {
 	&document_remove,
 	&document_reload_file,
 	&document_set_encoding,
-	&document_set_text_changed
+	&document_set_text_changed,
+	&document_set_filetype
 };
 
 static ScintillaFuncs sci_funcs = {
@@ -153,7 +167,9 @@ static UtilsFuncs utils_funcs = {
 	&utils_mkdir,
 	&utils_get_setting_boolean,
 	&utils_get_setting_integer,
-	&utils_get_setting_string
+	&utils_get_setting_string,
+	&utils_spawn_sync,
+	&utils_spawn_async
 };
 
 static UIUtilsFuncs uiutils_funcs = {
@@ -187,7 +203,8 @@ static EncodingFuncs encoding_funcs = {
 };
 
 static KeybindingFuncs keybindings_funcs = {
-	&keybindings_cmd
+	&keybindings_send_command,
+	&keybindings_set_item
 };
 
 static TagManagerFuncs tagmanager_funcs = {
@@ -209,9 +226,13 @@ static HighlightingFuncs highlighting_funcs = {
 
 
 static FiletypeFuncs filetype_funcs = {
-	&filetypes_detect_from_filename
+	&filetypes_detect_from_filename,
+	&filetypes_get_from_uid
 };
 
+static NavQueueFuncs navqueue_funcs = {
+	&navqueue_goto_line
+};
 
 static GeanyData geany_data = {
 	NULL,
@@ -235,12 +256,13 @@ static GeanyData geany_data = {
 	&tagmanager_funcs,
 	&search_funcs,
 	&highlighting_funcs,
-	&filetype_funcs
+	&filetype_funcs,
+	&navqueue_funcs
 };
 
 
 static void
-geany_data_init()
+geany_data_init(void)
 {
 	geany_data.app = app;
 	geany_data.tools_menu = lookup_widget(app->window, "tools1_menu");
@@ -253,8 +275,7 @@ geany_data_init()
 
 
 /* Prevent the same plugin filename being loaded more than once.
- * Note: g_module_name always returns the .so name, even when Plugin::filename
- * is an .la file. */
+ * Note: g_module_name always returns the .so name, even when Plugin::filename is an .la file. */
 static gboolean
 plugin_loaded(GModule *module)
 {
@@ -275,11 +296,44 @@ plugin_loaded(GModule *module)
 		}
 		g_free(basename_loaded);
 	}
+	/* Look also through the list of active plugins. This prevents problems when we have the same
+	 * plugin in libdir/geany/ AND in configdir/plugins/ and the one in libdir/geany/ is loaded
+	 * as active plugin. The plugin manager list would only take the one in configdir/geany/ and
+	 * the plugin manager would list both plugins. Additionally, unloading the active plugin
+	 * would cause a crash. */
+	for (item = active_plugin_list; item != NULL; item = g_list_next(item))
+	{
+		basename_loaded = g_path_get_basename(g_module_name(((Plugin*)item->data)->module));
+
+		if (utils_str_equal(basename_module, basename_loaded))
+		{
+			g_free(basename_loaded);
+			g_free(basename_module);
+			return TRUE;
+		}
+		g_free(basename_loaded);
+	}
 	g_free(basename_module);
 	return FALSE;
 }
 
 
+static Plugin *find_active_plugin_by_name(const gchar *filename)
+{
+	GList *item;
+
+	g_return_val_if_fail(filename, FALSE);
+
+	for (item = active_plugin_list; item != NULL; item = g_list_next(item))
+	{
+		if (utils_str_equal(filename, ((Plugin*)item->data)->filename))
+			return item->data;
+	}
+
+	return NULL;
+}
+
+
 static gboolean
 plugin_check_version(GModule *module)
 {
@@ -293,6 +347,8 @@ plugin_check_version(GModule *module)
 		result = version_check(abi_version);
 		if (result < 0)
 		{
+			ui_set_statusbar(TRUE, _("The plugin \"%s\" is not binary compatible with this "
+				"release of Geany - please recompile it."), g_module_name(module));
 			geany_debug("Plugin \"%s\" is not binary compatible with this "
 				"release of Geany - recompile it.", g_module_name(module));
 			return FALSE;
@@ -337,23 +393,21 @@ static void add_callbacks(Plugin *plugin, GeanyCallback *callbacks)
 }
 
 
-static gboolean
-is_active_plugin(const gchar *name)
+static void
+add_kb_group(Plugin *plugin)
 {
-	gint i, len;
+	g_return_if_fail(NZV(plugin->key_group->name));
+	g_return_if_fail(! g_str_equal(plugin->key_group->name, keybindings_keyfile_group_name));
 
-	g_return_val_if_fail(name, FALSE);
-
-	// if app->active_plugins is NULL, guess it was not yet set and don't load any plugins
-	if (app->active_plugins == NULL || (len = g_strv_length(app->active_plugins)) == 0)
-		return FALSE;
-
-	for (i = 0; i < len; i++)
+	if (plugin->key_group->count == 0)
 	{
-		if (utils_str_equal(name, app->active_plugins[i]))
-			return TRUE;
+		plugin->key_group = NULL;	/* Ignore the group */
+		return;
 	}
-	return FALSE;
+
+	plugin->key_group->label = plugin->info()->name;
+
+	g_ptr_array_add(keybinding_groups, plugin->key_group);
 }
 
 
@@ -375,6 +429,11 @@ plugin_init(Plugin *plugin)
 	if (callbacks)
 		add_callbacks(plugin, callbacks);
 
+	g_module_symbol(plugin->module, "plugin_key_group",
+		(void *) &plugin->key_group);
+	if (plugin->key_group)
+		add_kb_group(plugin);
+
 	active_plugin_list = g_list_append(active_plugin_list, plugin);
 
 	geany_debug("Loaded:   %s (%s)", plugin->filename,
@@ -382,18 +441,34 @@ plugin_init(Plugin *plugin)
 }
 
 
+/* Load and init a plugin.
+ * init_plugin decides whether the plugin's init() function should be called or not. If it is
+ * called, the plugin will be started, if not the plugin will be read only (for the list of
+ * available plugins in the plugin manager).
+ * When add_to_list is set, the plugin will be added to the plugin manager's plugin_list. */
 static Plugin*
-plugin_new(const gchar *fname)
+plugin_new(const gchar *fname, gboolean init_plugin, gboolean add_to_list)
 {
 	Plugin *plugin;
 	GModule *module;
-	PluginInfo* (*info)();
+	PluginInfo* (*info)(void);
 	PluginFields **plugin_fields;
 	GeanyData **p_geany_data;
 
 	g_return_val_if_fail(fname, NULL);
 	g_return_val_if_fail(g_module_supported(), NULL);
 
+	/* find the plugin in the list of already loaded, active plugins and use it, otherwise
+	 * load the module */
+	plugin = find_active_plugin_by_name(fname);
+	if (plugin != NULL)
+	{
+		geany_debug("Plugin \"%s\" already loaded.", fname);
+		if (add_to_list)
+			plugin_list = g_list_append(plugin_list, plugin);
+		return plugin;
+	}
+
 	/* Don't use G_MODULE_BIND_LAZY otherwise we can get unresolved symbols at runtime,
 	 * causing a segfault. Without that flag the module will safely fail to load.
 	 * G_MODULE_BIND_LOCAL also helps find undefined symbols e.g. app when it would
@@ -455,11 +530,12 @@ plugin_new(const gchar *fname)
 				info()->name);
 	}
 
-	// only initialise the plugin if it should be loaded
-	if (is_active_plugin(fname))
-	{
+	if (init_plugin)
 		plugin_init(plugin);
-	}
+
+	if (add_to_list)
+		plugin_list = g_list_append(plugin_list, plugin);
+
 	return plugin;
 }
 
@@ -477,47 +553,80 @@ static void remove_callbacks(Plugin *plugin)
 }
 
 
+static gboolean is_active_plugin(Plugin *plugin)
+{
+	return (g_list_find(active_plugin_list, plugin) != NULL);
+}
+
+
 static void
 plugin_unload(Plugin *plugin)
+{
+
+	if (is_active_plugin(plugin) && plugin->cleanup)
+		plugin->cleanup();
+
+	remove_callbacks(plugin);
+
+	if (plugin->key_group)
+		g_ptr_array_remove_fast(keybinding_groups, plugin->key_group);
+
+	active_plugin_list = g_list_remove(active_plugin_list, plugin);
+	geany_debug("Unloaded: %s", plugin->filename);
+}
+
+
+static void
+plugin_free(Plugin *plugin, gpointer data)
 {
 	g_return_if_fail(plugin);
 	g_return_if_fail(plugin->module);
 
-	if (g_list_find(active_plugin_list, plugin))
-	{	// only do cleanup if the plugin was actually loaded
-		if (plugin->cleanup)
-			plugin->cleanup();
+	/* don't do anything when closing the plugin manager and it is an active plugin */
+	if (GPOINTER_TO_INT(data) == PLUGIN_FREE_NON_ACTIVE && is_active_plugin(plugin))
+		return;
 
-		remove_callbacks(plugin);
+	plugin_unload(plugin);
 
-		active_plugin_list = g_list_remove(active_plugin_list, plugin);
-		geany_debug("Unloaded: %s", plugin->filename);
+	if (plugin->module != NULL && ! g_module_close(plugin->module))
+		g_warning("%s: %s", plugin->filename, g_module_error());
+
+	plugin_list = g_list_remove(plugin_list, plugin);
+
+	g_free(plugin->filename);
+	g_free(plugin);
+	plugin = NULL;
+}
+
+
+/* load active plugins at startup */
+static void
+load_active_plugins()
+{
+	guint i, len;
+
+	len = g_strv_length(active_plugins_pref);
+	if (active_plugins_pref == NULL || len == 0)
+		return;
+
+	for (i = 0; i < len; i++)
+	{
+		const gchar *fname = active_plugins_pref[i];
+
+		if (NZV(fname))
+		{
+			if (plugin_new(fname, TRUE, FALSE) == NULL)
+				failed_plugins_list = g_list_append(failed_plugins_list, g_strdup(fname));
+		}
 	}
 }
 
 
 static void
-plugin_free(Plugin *plugin)
-{
-	g_return_if_fail(plugin);
-	g_return_if_fail(plugin->module);
-
-	plugin_unload(plugin);
-
-	if (! g_module_close(plugin->module))
-		g_warning("%s: %s", plugin->filename, g_module_error());
-
-	g_free(plugin->filename);
-	g_free(plugin);
-}
-
-
-static void
-load_plugins(const gchar *path)
+load_plugins_from_path(const gchar *path)
 {
 	GSList *list, *item;
 	gchar *fname, *tmp;
-	Plugin *plugin;
 
 	list = utils_get_file_list(path, NULL, NULL);
 
@@ -528,11 +637,7 @@ load_plugins(const gchar *path)
 			continue;
 
 		fname = g_strconcat(path, G_DIR_SEPARATOR_S, item->data, NULL);
-		plugin = plugin_new(fname);
-		if (plugin != NULL)
-		{
-			plugin_list = g_list_append(plugin_list, plugin);
-		}
+		plugin_new(fname, FALSE, TRUE);
 		g_free(fname);
 	}
 
@@ -554,20 +659,21 @@ static gchar *get_plugin_path()
 #endif
 
 
-static void load_plugin_paths()
+/* Load (but don't initialize) all plugins for the Plugin Manager dialog */
+static void load_all_plugins(void)
 {
 	gchar *path;
 
 	path = g_strconcat(app->configdir, G_DIR_SEPARATOR_S, "plugins", NULL);
-	// first load plugins in ~/.geany/plugins/, then in $prefix/lib/geany
-	load_plugins(path);
+	/* first load plugins in ~/.geany/plugins/, then in $prefix/lib/geany */
+	load_plugins_from_path(path);
 	g_free(path);
 #ifdef G_OS_WIN32
 	path = get_plugin_path();
 #else
 	path = g_strconcat(GEANY_LIBDIR, G_DIR_SEPARATOR_S "geany", NULL);
 #endif
-	load_plugins(path);
+	load_plugins_from_path(path);
 
 	g_free(path);
 }
@@ -580,7 +686,11 @@ void plugins_init()
 	geany_data_init();
 	geany_object = geany_object_new();
 
-	widget = gtk_menu_item_new_with_mnemonic(_("Plugin Manager"));
+	widget = gtk_separator_menu_item_new();
+	gtk_widget_show(widget);
+	gtk_container_add(GTK_CONTAINER(geany_data.tools_menu), widget);
+
+	widget = gtk_menu_item_new_with_mnemonic(_("_Plugin Manager"));
 	gtk_container_add(GTK_CONTAINER (geany_data.tools_menu), widget);
 	gtk_widget_show(widget);
 	g_signal_connect((gpointer) widget, "activate", G_CALLBACK(pm_show_dialog), NULL);
@@ -588,48 +698,86 @@ void plugins_init()
 	separator = gtk_separator_menu_item_new();
 	gtk_container_add(GTK_CONTAINER(geany_data.tools_menu), separator);
 
-	load_plugin_paths();
+	load_active_plugins();
 
 	plugins_update_tools_menu();
 }
 
 
-void plugins_create_active_list()
+static void update_active_plugins_pref(void)
 {
 	gint i = 0;
 	GList *list;
+	gsize count = g_list_length(active_plugin_list) + g_list_length(failed_plugins_list);
 
-	g_strfreev(app->active_plugins);
+	g_strfreev(active_plugins_pref);
 
-	if (active_plugin_list == NULL)
+	if (count == 0)
 	{
-		app->active_plugins = NULL;
+		active_plugins_pref = NULL;
 		return;
 	}
 
-	app->active_plugins = g_new0(gchar*, g_list_length(active_plugin_list) + 1);
+	active_plugins_pref = g_new0(gchar*, count + 1);
+
 	for (list = g_list_first(active_plugin_list); list != NULL; list = list->next)
 	{
-		app->active_plugins[i] = g_strdup(((Plugin*)list->data)->filename);
+		Plugin *plugin = list->data;
+
+		active_plugins_pref[i] = g_strdup(plugin->filename);
 		i++;
 	}
-	app->active_plugins[i] = NULL;
+	for (list = g_list_first(failed_plugins_list); list != NULL; list = list->next)
+	{
+		const gchar *fname = list->data;
+
+		active_plugins_pref[i] = g_strdup(fname);
+		i++;
+	}
+	active_plugins_pref[i] = NULL;
 }
 
 
-void plugins_free()
+void plugins_save_prefs(GKeyFile *config)
 {
-	if (plugin_list != NULL)
+	g_key_file_set_boolean(config, "plugins", "load_plugins", prefs.load_plugins);
+
+	update_active_plugins_pref();
+	if (active_plugins_pref != NULL)
+		g_key_file_set_string_list(config, "plugins", "active_plugins",
+			(const gchar**)active_plugins_pref, g_strv_length(active_plugins_pref));
+	else
 	{
-		g_list_foreach(plugin_list, (GFunc) plugin_free, NULL);
-		g_list_free(plugin_list);
+		/* use an empty dummy array to override maybe exisiting value */
+		const gchar *dummy[] = { "" };
+		g_key_file_set_string_list(config, "plugins", "active_plugins", dummy, 1);
+	}
+}
+
+
+void plugins_load_prefs(GKeyFile *config)
+{
+	prefs.load_plugins = utils_get_setting_boolean(config, "plugins", "load_plugins", TRUE);
+	active_plugins_pref = g_key_file_get_string_list(config, "plugins", "active_plugins", NULL, NULL);
+}
+
+
+void plugins_free(void)
+{
+	if (failed_plugins_list != NULL)
+	{
+		g_list_foreach(failed_plugins_list, (GFunc) g_free,	NULL);
+		g_list_free(failed_plugins_list);
 	}
 	if (active_plugin_list != NULL)
-		// no need to do more here, active_plugin_list holds the same pointer as plugin_list
+	{
+		g_list_foreach(active_plugin_list, (GFunc) plugin_free,	GINT_TO_POINTER(PLUGIN_FREE_ALL));
 		g_list_free(active_plugin_list);
+	}
+	g_strfreev(active_plugins_pref);
 
 	g_object_unref(geany_object);
-	geany_object = NULL; // to mark the object as invalid for any code which tries to emit signals
+	geany_object = NULL; /* to mark the object as invalid for any code which tries to emit signals */
 }
 
 
@@ -650,7 +798,7 @@ void plugins_update_document_sensitive(gboolean enabled)
 static gint
 plugin_has_menu(Plugin *a, Plugin *b)
 {
-	if (((PluginFields)a->fields).menu_item != NULL)
+	if (a->fields.menu_item != NULL)
 		return 0;
 
 	return 1;
@@ -696,7 +844,6 @@ void pm_selection_changed(GtkTreeSelection *selection, gpointer user_data)
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	Plugin *p;
-	PluginInfo *pi;
 
 	if (gtk_tree_selection_get_selected(selection, &model, &iter))
 	{
@@ -705,6 +852,7 @@ void pm_selection_changed(GtkTreeSelection *selection, gpointer user_data)
 		if (p != NULL)
 		{
 			gchar *text;
+			PluginInfo *pi;
 
 			pi = p->info();
 			text = g_strdup_printf(
@@ -724,6 +872,7 @@ void pm_selection_changed(GtkTreeSelection *selection, gpointer user_data)
 static void pm_plugin_toggled(GtkCellRendererToggle *cell, gchar *pth, gpointer data)
 {
 	gboolean old_state, state;
+	gchar *file_name;
 	GtkTreeIter iter;
 	GtkTreePath *path = gtk_tree_path_new_from_string(pth);
 	Plugin *p;
@@ -735,27 +884,31 @@ static void pm_plugin_toggled(GtkCellRendererToggle *cell, gchar *pth, gpointer
 		PLUGIN_COLUMN_CHECK, &old_state, PLUGIN_COLUMN_PLUGIN, &p, -1);
 	if (p == NULL)
 		return;
-	state = ! old_state; // toggle the state
-	gtk_list_store_set(pm_widgets.store, &iter, PLUGIN_COLUMN_CHECK, state, -1);
+	state = ! old_state; /* toggle the state */
 
-	// load/unload the plugin once it was toggled for correct behaviour of the preferences button
-	// we want to call plugin's configure() only after init() has been called
+	/* save the filename of the plugin */
+	file_name = g_strdup(p->filename);
 
-	// plugin should be loaded, so load it if it is not already
-	if (state && g_list_find(active_plugin_list, p) == NULL)
-	{
-		plugin_init(p);
-	}
-	// plugin should be unloaded, so unload it if it is loaded
-	if (! state && g_list_find(active_plugin_list, p) != NULL)
-	{
-		plugin_unload(p);
-	}
+	/* unload plugin module */
+	if (!state)
+		keybindings_write_to_file();	/* save shortcuts (only need this group, but it doesn't take long) */
+	plugin_free(p, GINT_TO_POINTER(PLUGIN_FREE_ALL));
 
-	// set again the sensitiveness of the configure button
+	/* reload plugin module and initialize it if item is checked */
+	p = plugin_new(file_name, state, TRUE);
+	if (state)
+		keybindings_load_keyfile();		/* load shortcuts */
+
+	/* update model */
+	gtk_list_store_set(pm_widgets.store, &iter,
+		PLUGIN_COLUMN_CHECK, state,
+		PLUGIN_COLUMN_PLUGIN, p, -1);
+
+	g_free(file_name);
+
+	/* set again the sensitiveness of the configure button */
 	gtk_widget_set_sensitive(pm_widgets.configure_button,
-		p->configure != NULL && g_list_find(active_plugin_list, p) != NULL);
-
+		p->configure != NULL && is_active_plugin(p));
 }
 
 
@@ -789,7 +942,7 @@ static void pm_prepare_treeview(GtkWidget *tree, GtkListStore *store)
 	gtk_tree_sortable_set_sort_column_id(
 		GTK_TREE_SORTABLE(store), PLUGIN_COLUMN_NAME, GTK_SORT_ASCENDING);
 
-	// selection handling
+	/* selection handling */
 	sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree));
 	gtk_tree_selection_set_mode(sel, GTK_SELECTION_SINGLE);
 	g_signal_connect((gpointer) sel, "changed", G_CALLBACK(pm_selection_changed), NULL);
@@ -806,10 +959,9 @@ static void pm_prepare_treeview(GtkWidget *tree, GtkListStore *store)
 	{
 		for (; list != NULL; list = list->next)
 		{
-			gboolean active = (g_list_find(active_plugin_list, list->data) != NULL) ? TRUE : FALSE;
 			gtk_list_store_append(store, &iter);
 			gtk_list_store_set(store, &iter,
-				PLUGIN_COLUMN_CHECK, active,
+				PLUGIN_COLUMN_CHECK, is_active_plugin(list->data),
 				PLUGIN_COLUMN_NAME, ((Plugin*)list->data)->info()->name,
 				PLUGIN_COLUMN_FILE, ((Plugin*)list->data)->filename,
 				PLUGIN_COLUMN_PLUGIN, list->data,
@@ -840,19 +992,34 @@ void pm_on_configure_button_clicked(GtkButton *button, gpointer user_data)
 }
 
 
+static void pm_dialog_response(GtkDialog *dialog, gint response, gpointer user_data)
+{
+	if (plugin_list != NULL)
+	{
+		/* remove all non-active plugins from the list */
+		g_list_foreach(plugin_list, (GFunc) plugin_free, GINT_TO_POINTER(PLUGIN_FREE_NON_ACTIVE));
+		g_list_free(plugin_list);
+		plugin_list = NULL;
+	}
+	gtk_widget_destroy(GTK_WIDGET(dialog));
+}
+
+
 static void pm_show_dialog(GtkMenuItem *menuitem, gpointer user_data)
 {
 	GtkWidget *vbox, *vbox2, *label_vbox, *hbox, *swin, *label, *label2;
 
+	/* before showing the dialog, we need to create the list of available plugins */
+	load_all_plugins();
+
 	pm_widgets.dialog = gtk_dialog_new_with_buttons(_("Plugins"), GTK_WINDOW(app->window),
 						GTK_DIALOG_DESTROY_WITH_PARENT,
-						GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+						GTK_STOCK_OK, GTK_RESPONSE_CANCEL, NULL);
 	vbox = ui_dialog_vbox_new(GTK_DIALOG(pm_widgets.dialog));
 	gtk_widget_set_name(pm_widgets.dialog, "GeanyDialog");
 	gtk_box_set_spacing(GTK_BOX(vbox), 6);
 
 	gtk_window_set_default_size(GTK_WINDOW(pm_widgets.dialog), 400, 350);
-	gtk_dialog_set_default_response(GTK_DIALOG(pm_widgets.dialog), GTK_RESPONSE_CANCEL);
 
 	pm_widgets.tree = gtk_tree_view_new();
 	pm_widgets.store = gtk_list_store_new(
@@ -891,8 +1058,8 @@ static void pm_show_dialog(GtkMenuItem *menuitem, gpointer user_data)
 	gtk_box_pack_start(GTK_BOX(vbox2), swin, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox2), label_vbox, FALSE, FALSE, 0);
 
-	g_signal_connect_swapped((gpointer) pm_widgets.dialog, "response",
-		G_CALLBACK(gtk_widget_destroy), pm_widgets.dialog);
+	g_signal_connect((gpointer) pm_widgets.dialog, "response",
+		G_CALLBACK(pm_dialog_response), NULL);
 
 	gtk_container_add(GTK_CONTAINER(vbox), vbox2);
 	gtk_widget_show_all(pm_widgets.dialog);
