@@ -19,7 +19,7 @@
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  *      MA 02110-1301, USA.
  *
- * $Id: plugins.h 2150 2008-01-06 18:11:57Z eht16 $
+ * $Id: plugins.h 2491 2008-04-16 15:09:52Z ntrel $
  */
 
 
@@ -28,13 +28,15 @@
 
 #ifdef HAVE_PLUGINS
 
-void plugins_init();
+void plugins_init(void);
 
-void plugins_free();
+void plugins_free(void);
 
-void plugins_create_active_list();
+void plugins_save_prefs(GKeyFile *config);
 
-void plugins_update_tools_menu();
+void plugins_load_prefs(GKeyFile *config);
+
+void plugins_update_tools_menu(void);
 
 void plugins_update_document_sensitive(gboolean enabled);
 
