@@ -1,8 +1,8 @@
 /*
  *      search.h - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2006-2007 Enrico Tröger <enrico.troeger@uvena.de>
- *      Copyright 2006-2007 Nick Treleaven <nick.treleaven@btinternet.com>
+ *      Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2006-2008 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,21 +18,21 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: search.h 1692 2007-07-11 17:44:43Z eht16 $
+ * $Id: search.h 2287 2008-02-27 13:17:29Z eht16 $
  */
 
 
 #ifndef GEANY_SEARCH_H
 #define GEANY_SEARCH_H 1
 
-// the flags given in the search dialog for "find next", also used by the search bar
+/* the flags given in the search dialog for "find next", also used by the search bar */
 typedef struct
 {
 	gchar		*text;
 	gint		flags;
 	gboolean	backwards;
-	// set to TRUE when text was set by a search bar callback to keep track of
-	// search bar background colour
+	/* set to TRUE when text was set by a search bar callback to keep track of
+	 * search bar background colour */
 	gboolean	search_bar;
 } GeanySearchData;
 
@@ -47,15 +47,15 @@ typedef struct
 extern SearchPrefs search_prefs;
 
 
-void search_init();
+void search_init(void);
 
-void search_finalize();
+void search_finalize(void);
 
-void search_show_find_dialog();
+void search_show_find_dialog(void);
 
-void search_show_replace_dialog();
+void search_show_replace_dialog(void);
 
-void search_show_find_in_files_dialog();
+void search_show_find_in_files_dialog(const gchar *dir);
 
 void search_find_usage(const gchar *search_text, gint flags, gboolean in_session);
 
