@@ -1,8 +1,8 @@
 /*
  *      socket.c - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2006-2007 Enrico Tröger <enrico.troeger@uvena.de>
- *      Copyright 2006-2007 Nick Treleaven <nick.treleaven@btinternet.com>
+ *      Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2006-2008 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: socket.c 1868 2007-09-11 15:21:11Z ntrel $
+ * $Id: socket.c 2287 2008-02-27 13:17:29Z eht16 $
  */
 
 /*
@@ -40,6 +40,14 @@
  * to mark the end of data send a single '.'. Each message should be ended with \n.
  *
  * At the moment the commands open, line and column are available.
+ *
+ * About the socket files on Unix-like systems:
+ * Geany creates a socket in /tmp (or any other directory returned by g_get_tmp_dir()) and
+ * a symlink in the current configuration to the created socket file. The symlink is named
+ * geany_socket_<hostname>_<displayname> (displayname is the name of the active X display).
+ * If the socket file cannot be created in the temporary directory, Geany creates the socket file
+ * directly in the configuration directory as a fallback.
+ *
  */
 
 
@@ -54,6 +62,7 @@
 # include <sys/socket.h>
 # include <sys/un.h>
 # include <netinet/in.h>
+# include <glib/gstdio.h>
 #else
 # include <winsock2.h>
 # include <ws2tcpip.h>
@@ -67,6 +76,7 @@
 #include "document.h"
 #include "support.h"
 #include "ui_utils.h"
+#include "utils.h"
 
 
 
@@ -81,10 +91,13 @@
 #endif
 
 
+struct socket_info_struct socket_info;
+
+
 #ifdef G_OS_WIN32
 static gint socket_fd_connect_inet	(gushort port);
 static gint socket_fd_open_inet		(gushort port);
-static void socket_init_win32();
+static void socket_init_win32		(void);
 #else
 static gint socket_fd_connect_unix	(const gchar *path);
 static gint socket_fd_open_unix		(const gchar *path);
@@ -132,7 +145,7 @@ void send_open_command(gint sock, gint argc, gchar **argv)
 	{
 		filename = get_argv_filename(argv[i]);
 
-		// if the filename is valid or if a new file should be opened is check on the other side
+		/* if the filename is valid or if a new file should be opened is check on the other side */
 		if (filename != NULL)
 		{
 			socket_fd_write_all(sock, filename, strlen(filename));
@@ -141,7 +154,7 @@ void send_open_command(gint sock, gint argc, gchar **argv)
 		else
 		{
 			g_printerr(_("Could not find file '%s'."), filename);
-			g_printerr("\n");	// keep translation from open_cl_files() in main.c.
+			g_printerr("\n");	/* keep translation from open_cl_files() in main.c. */
 		}
 		g_free(filename);
 	}
@@ -149,16 +162,39 @@ void send_open_command(gint sock, gint argc, gchar **argv)
 }
 
 
+#ifndef G_OS_WIN32
+static void remove_socket_link_full(void)
+{
+	gchar real_path[512];
+	gsize len;
+
+	real_path[0] = '\0';
+
+	/* read the contents of the symbolic link socket_info.file_name and delete it
+	 * readlink should return something like "/tmp/geany_socket.499602d2" */
+	len = readlink(socket_info.file_name, real_path, sizeof(real_path) - 1);
+	if ((gint) len > 0)
+	{
+		real_path[len] = '\0';
+		g_unlink(real_path);
+	}
+	g_unlink(socket_info.file_name);
+}
+#endif
+
+
 /* (Unix domain) socket support to replace the old FIFO code
- * (taken from Sylpheed, thanks) */
+ * (taken from Sylpheed, thanks)
+ * Returns the created socket, -1 if an error occurred or -2 if another socket exists and files
+ * were sent to it. */
 gint socket_init(gint argc, gchar **argv)
 {
 	gint sock;
 
 #ifdef G_OS_WIN32
 	HANDLE hmutex;
-	// we need a mutex name which is unique for the used configuration dir,
-	// but we can't use the whole path, so build a hash on the configdir and use it
+	/* we need a mutex name which is unique for the used configuration dir,
+	 * but we can't use the whole path, so build a hash on the configdir and use it */
 	gchar *mutex_name = g_strdup_printf("Geany%d", g_str_hash(app->configdir));
 
 	socket_init_win32();
@@ -181,26 +217,42 @@ gint socket_init(gint argc, gchar **argv)
 	if (sock < 0)
 		return -1;
 #else
+	gchar *display_name = gdk_get_display();
+	gchar *hostname = utils_get_hostname();
+	gchar *p;
+
+	if (display_name == NULL)
+		display_name = g_strdup("NODISPLAY");
+
+	/* these lines are taken from dcopc.c in kdelibs */
+	if ((p = strrchr(display_name, '.')) > strrchr(display_name, ':') && p != NULL)
+		*p = '\0';
+	while ((p = strchr(display_name, ':')) != NULL)
+		*p = '_';
 
 	if (socket_info.file_name == NULL)
-		socket_info.file_name = g_strdup_printf("%s%cgeany_socket", app->configdir, G_DIR_SEPARATOR);
+		socket_info.file_name = g_strdup_printf("%s%cgeany_socket_%s_%s",
+			app->configdir, G_DIR_SEPARATOR, hostname, display_name);
+
+	g_free(display_name);
+	g_free(hostname);
 
 	sock = socket_fd_connect_unix(socket_info.file_name);
 	if (sock < 0)
 	{
-		unlink(socket_info.file_name);
+		remove_socket_link_full(); /* deletes the socket file and the symlink */
 		return socket_fd_open_unix(socket_info.file_name);
 	}
 #endif
 
-	// remote command mode, here we have another running instance and want to use it
+	/* remote command mode, here we have another running instance and want to use it */
 	if (argc > 1)
 	{
 		send_open_command(sock, argc, argv);
 	}
 
 	socket_fd_close(sock);
-	return -1;
+	return -2;
 }
 
 
@@ -220,9 +272,9 @@ gint socket_finalize(void)
 #ifdef G_OS_WIN32
 	WSACleanup();
 #else
-	if (socket_info.file_name)
+	if (socket_info.file_name != NULL)
 	{
-		unlink(socket_info.file_name);
+		remove_socket_link_full(); /* deletes the socket file and the symlink */
 		g_free(socket_info.file_name);
 	}
 #endif
@@ -263,6 +315,7 @@ static gint socket_fd_open_unix(const gchar *path)
 	gint sock;
 	struct sockaddr_un addr;
 	gint val;
+	gchar *real_path;
 
 	sock = socket(PF_UNIX, SOCK_STREAM, 0);
 
@@ -280,9 +333,32 @@ static gint socket_fd_open_unix(const gchar *path)
 		return -1;
 	}
 
+	/* fix for #1888561:
+	 * in case the configuration directory is located on a network file system or any other
+	 * file system which doesn't support sockets, we just link the socket there and create the
+	 * real socket in the system's tmp directory assuming it supports sockets */
+	real_path = g_strdup_printf("%s%cgeany_socket.%08x",
+		g_get_tmp_dir(), G_DIR_SEPARATOR, g_random_int());
+
+	if (utils_is_file_writeable(real_path) != 0)
+	{	/* if real_path is not writable for us, fall back to ~/.geany/geany_socket_*_* */
+		/* instead of creating a symlink and print a warning */
+		g_warning("Socket %s could not be written, using %s as fallback.", real_path, path);
+		setptr(real_path, g_strdup(path));
+	}
+	/* create a symlink in e.g. ~/.geany/geany_socket_hostname__0 to /tmp/geany_socket.499602d2 */
+	else if (symlink(real_path, path) != 0)
+	{
+		perror("symlink");
+		socket_fd_close(sock);
+		return -1;
+	}
+
 	memset(&addr, 0, sizeof(addr));
 	addr.sun_family = AF_UNIX;
-	strncpy(addr.sun_path, path, sizeof(addr.sun_path) - 1);
+	strncpy(addr.sun_path, real_path, sizeof(addr.sun_path) - 1);
+
+	g_free(real_path);
 
 	if (bind(sock, (struct sockaddr *)&addr, sizeof(addr)) < 0)
 	{
@@ -384,7 +460,7 @@ static gint socket_fd_connect_inet(gushort port)
 }
 
 
-static void socket_init_win32()
+static void socket_init_win32(void)
 {
 	WSADATA wsadata;
 
@@ -408,7 +484,7 @@ gboolean socket_lock_input_cb(GIOChannel *source, GIOCondition condition, gpoint
 	fd = g_io_channel_unix_get_fd(source);
 	sock = accept(fd, (struct sockaddr *)&caddr, &caddr_len);
 
-	// first get the command
+	/* first get the command */
 	while (socket_fd_gets(sock, buf, sizeof(buf)) != -1)
 	{
 		if (strncmp(buf, "open", 4) == 0)
@@ -417,12 +493,12 @@ gboolean socket_lock_input_cb(GIOChannel *source, GIOCondition condition, gpoint
 
 			while (socket_fd_gets(sock, buf, sizeof(buf)) != -1 && *buf != '.')
 			{
-				g_strstrip(buf); // remove \n char
+				g_strstrip(buf); /* remove \n char */
 
 				if (g_file_test(buf, G_FILE_TEST_IS_REGULAR | G_FILE_TEST_IS_SYMLINK))
 					document_open_file(buf, FALSE, NULL, NULL);
 				else
-				{	// create new file if it doesn't exist
+				{	/* create new file if it doesn't exist */
 					gint idx;
 
 					idx = document_new_file(buf, NULL, NULL);
@@ -443,8 +519,8 @@ gboolean socket_lock_input_cb(GIOChannel *source, GIOCondition condition, gpoint
 		{
 			while (socket_fd_gets(sock, buf, sizeof(buf)) != -1 && *buf != '.')
 			{
-				g_strstrip(buf); // remove \n char
-				// on any error we get 0 which should be safe enough as fallback
+				g_strstrip(buf); /* remove \n char */
+				/* on any error we get 0 which should be safe enough as fallback */
 				cl_options.goto_line = atoi(buf);
 			}
 		}
@@ -452,8 +528,8 @@ gboolean socket_lock_input_cb(GIOChannel *source, GIOCondition condition, gpoint
 		{
 			while (socket_fd_gets(sock, buf, sizeof(buf)) != -1 && *buf != '.')
 			{
-				g_strstrip(buf); // remove \n char
-				// on any error we get 0 which should be safe enough as fallback
+				g_strstrip(buf); /* remove \n char */
+				/* on any error we get 0 which should be safe enough as fallback */
 				cl_options.goto_column = atoi(buf);
 			}
 		}
@@ -522,7 +598,7 @@ static gint socket_fd_check_io(gint fd, GIOCondition cond)
 	timeout.tv_usec = 0;
 
 #ifdef G_OS_UNIX
-	// checking for non-blocking mode
+	/* checking for non-blocking mode */
 
 	flags = fcntl(fd, F_GETFL, 0);
 	if (flags < 0)
