@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: symbols.c 2150 2008-01-06 18:11:57Z eht16 $
+ * $Id: symbols.c 2458 2008-04-08 15:21:54Z eht16 $
  */
 
 /*
@@ -61,7 +61,7 @@ typedef struct
 	const gchar	*tag_file;
 } TagFileInfo;
 
-enum	// Geany tag files
+enum	/* Geany tag files */
 {
 	GTF_C,
 	GTF_PASCAL,
@@ -83,16 +83,40 @@ static TagFileInfo tag_file_info[GTF_MAX] =
 static gchar *user_tags_dir;
 
 
-static void html_tags_loaded();
+static void html_tags_loaded(void);
 static void load_user_tags(filetype_id ft_id);
 
+/* get the tags_ignore list, exported by tagmanager's options.c */
+extern gchar **c_tags_ignore;
 
-// Ensure that the global tags file for the file_type_idx filetype is loaded.
+static void load_c_ignore_tags(void)
+{
+	gchar *path = g_strconcat(app->configdir, G_DIR_SEPARATOR_S "ignore.tags", NULL);
+	gchar *content;
+
+	if (g_file_get_contents(path, &content, NULL, NULL))
+	{
+		c_tags_ignore = g_strsplit_set(content, " \n\r", -1);
+		g_free(content);
+	}
+	g_free(path);
+}
+
+
+/* Ensure that the global tags file(s) for the file_type_idx filetype is loaded.
+ * This provides autocompletion, calltips, etc. */
 void symbols_global_tags_loaded(gint file_type_idx)
 {
 	TagFileInfo *tfi;
 	gint tag_type;
 
+	/* load ignore list for C/C++ parser */
+	if ((file_type_idx == GEANY_FILETYPES_C || file_type_idx == GEANY_FILETYPES_CPP) &&
+		c_tags_ignore == NULL)
+	{
+		load_c_ignore_tags();
+	}
+
 	if (cl_options.ignore_global_tags || app->tm_workspace == NULL)
 		return;
 
@@ -107,8 +131,8 @@ void symbols_global_tags_loaded(gint file_type_idx)
 	switch (file_type_idx)
 	{
 		case GEANY_FILETYPES_CPP:
-			symbols_global_tags_loaded(GEANY_FILETYPES_C);	// load C global tags
-			// no C++ tagfile yet
+			symbols_global_tags_loaded(GEANY_FILETYPES_C);	/* load C global tags */
+			/* no C++ tagfile yet */
 			return;
 		case GEANY_FILETYPES_C:		tag_type = GTF_C; break;
 		case GEANY_FILETYPES_PASCAL:tag_type = GTF_PASCAL; break;
@@ -132,8 +156,8 @@ void symbols_global_tags_loaded(gint file_type_idx)
 }
 
 
-// HTML tagfile is just a list of entities for autocompletion (e.g. '&amp;')
-static void html_tags_loaded()
+/* HTML tagfile is just a list of entities for autocompletion (e.g. '&amp;') */
+static void html_tags_loaded(void)
 {
 	TagFileInfo *tfi;
 
@@ -170,14 +194,14 @@ GString *symbols_find_tags_as_string(GPtrArray *tags_array, guint tag_types, gin
 			tag = TM_TAG(typedefs->pdata[j]);
 			if (!(tag->atts.entry.scope))
 			{
-				// tag->atts.file.lang contains (for some reason) the line of the tag if
-				// tag->atts.entry.file is not NULL
+				/* tag->atts.file.lang contains (for some reason) the line of the tag if
+				 * tag->atts.entry.file is not NULL */
 				gint tag_lang =
 					(tag->atts.entry.file) ? tag->atts.entry.file->lang : tag->atts.file.lang;
 
-				// the check for tag_lang == lang is necessary to avoid wrong type colouring of
-				// e.g. PHP classes in C++ files
-				// lang = -2 disables the check
+				/* the check for tag_lang == lang is necessary to avoid wrong type colouring of
+				 * e.g. PHP classes in C++ files
+				 * lang = -2 disables the check */
 				if (tag->name && (tag_lang == lang || lang == -2))
 				{
 					if (j != 0)
@@ -187,7 +211,8 @@ GString *symbols_find_tags_as_string(GPtrArray *tags_array, guint tag_types, gin
 			}
 		}
 	}
-	g_ptr_array_free(typedefs, TRUE);
+	if (typedefs)
+		g_ptr_array_free(typedefs, TRUE);
 	return s;
 }
 
@@ -198,9 +223,9 @@ const gchar *symbols_get_context_separator(gint ft_id)
 
 	switch (ft_id)
 	{
-		case GEANY_FILETYPES_C:	// for C++ .h headers or C structs
+		case GEANY_FILETYPES_C:	/* for C++ .h headers or C structs */
 		case GEANY_FILETYPES_CPP:
-		//~ case GEANY_FILETYPES_RUBY: // not sure what to use atm
+		/*case GEANY_FILETYPES_RUBY:*/ /* not sure what to use atm*/
 		{
 			static gchar cc[] = "::";
 
@@ -215,14 +240,13 @@ const gchar *symbols_get_context_separator(gint ft_id)
 			cosep = def;
 		}
 	}
-	return cosep;	// return ptr to static string
+	return cosep;	/* return ptr to static string */
 }
 
 
-GString *symbols_get_macro_list()
+GString *symbols_get_macro_list(void)
 {
 	guint j, i;
-	const GPtrArray *tags;
 	GPtrArray *ftags;
 	GString *words;
 
@@ -234,6 +258,8 @@ GString *symbols_get_macro_list()
 
 	for (j = 0; j < app->tm_workspace->work_objects->len; j++)
 	{
+		GPtrArray *tags;
+
 		tags = tm_tags_extract(TM_WORK_OBJECT(app->tm_workspace->work_objects->pdata[j])->tags_array,
 			tm_tag_enum_t | tm_tag_variable_t | tm_tag_macro_t | tm_tag_macro_with_arg_t);
 		if (NULL != tags)
@@ -242,12 +268,13 @@ GString *symbols_get_macro_list()
 			{
 				g_ptr_array_add(ftags, (gpointer) tags->pdata[i]);
 			}
+			g_ptr_array_free(tags, TRUE);
 		}
 	}
 	tm_tags_sort(ftags, NULL, FALSE);
 	for (j = 0; j < ftags->len; j++)
 	{
-		if (j > 0) g_string_append_c(words, ' ');
+		if (j > 0) g_string_append_c(words, '\n');
 		g_string_append(words, TM_TAG(ftags->pdata[j])->name);
 	}
 	g_ptr_array_free(ftags, TRUE);
@@ -255,6 +282,7 @@ GString *symbols_get_macro_list()
 }
 
 
+/* Note: if tags is sorted, we can use bsearch or tm_tags_find() to speed this up. */
 static TMTag *
 symbols_find_tm_tag(const GPtrArray *tags, const gchar *tag_name)
 {
@@ -270,46 +298,70 @@ symbols_find_tm_tag(const GPtrArray *tags, const gchar *tag_name)
 }
 
 
-static TMTag *find_workspace_tag(const gchar *tag_name, gint type)
+static TMTag *find_work_object_tag(const TMWorkObject *workobj,
+		const gchar *tag_name, gint type)
 {
-	guint j;
-	const GPtrArray *tags;
+	GPtrArray *tags;
 	TMTag *tmtag;
 
-	if (app->tm_workspace != NULL && app->tm_workspace->work_objects != NULL)
+	if (workobj != NULL)
 	{
-		for (j = 0; j < app->tm_workspace->work_objects->len; j++)
+		tags = tm_tags_extract(workobj->tags_array, type);
+		if (tags != NULL)
 		{
-			tags = tm_tags_extract(
-				TM_WORK_OBJECT(app->tm_workspace->work_objects->pdata[j])->tags_array,
-				type);
-			if (tags == NULL) continue;
-
 			tmtag = symbols_find_tm_tag(tags, tag_name);
+
+			g_ptr_array_free(tags, TRUE);
+
 			if (tmtag != NULL)
 				return tmtag;
 		}
 	}
-	return NULL;	// not found
+	return NULL;	/* not found */
 }
 
 
-const gchar **symbols_get_html_entities()
+static TMTag *find_workspace_tag(const gchar *tag_name, gint type)
+{
+	guint j;
+	const GPtrArray *work_objects = NULL;
+
+	if (app->tm_workspace != NULL)
+		work_objects = app->tm_workspace->work_objects;
+
+	if (work_objects != NULL)
+	{
+		for (j = 0; j < work_objects->len; j++)
+		{
+			TMWorkObject *workobj = TM_WORK_OBJECT(work_objects->pdata[j]);
+			TMTag *tmtag;
+
+			tmtag = find_work_object_tag(workobj, tag_name, type);
+			if (tmtag != NULL)
+				return tmtag;
+		}
+	}
+	return NULL;	/* not found */
+}
+
+
+const gchar **symbols_get_html_entities(void)
 {
 	if (html_entities == NULL)
-		html_tags_loaded(); // if not yet created, force creation of the array but shouldn't occur
+		html_tags_loaded(); /* if not yet created, force creation of the array but shouldn't occur */
 
 	return (const gchar **) html_entities;
 }
 
 
-void symbols_finalize()
+void symbols_finalize(void)
 {
 	g_strfreev(html_entities);
+	g_strfreev(c_tags_ignore);
 }
 
 
-// small struct to track tag name and type together
+/* small struct to track tag name and type together */
 typedef struct GeanySymbol
 {
 	gchar	*str;
@@ -343,11 +395,11 @@ static gint compare_symbol_lines(const GeanySymbol *a, const GeanySymbol *b)
 }
 
 
-static const GList *get_tag_list(gint idx, guint tag_types, gboolean sort_by_name)
+static const GList *get_tag_list(gint idx, guint tag_types, gint sort_mode)
 {
 	static GList *tag_names = NULL;
 
-	if (idx >= 0 && doc_list[idx].is_valid && doc_list[idx].tm_file &&
+	if (DOC_IDX_VALID(idx) && doc_list[idx].tm_file &&
 		doc_list[idx].tm_file->tags_array)
 	{
 		TMTag *tag;
@@ -370,8 +422,8 @@ static const GList *get_tag_list(gint idx, guint tag_types, gboolean sort_by_nam
 			tag_names = NULL;
 		}
 
-		// encodings_convert_to_utf8_from_charset() fails with charset "None", so skip conversion
-		// for None at this point completely
+		/* encodings_convert_to_utf8_from_charset() fails with charset "None", so skip conversion
+		 * for None at this point completely */
 		if (utils_str_equal(doc_list[idx].encoding, "UTF-8") ||
 			utils_str_equal(doc_list[idx].encoding, "None"))
 			doc_is_utf8 = TRUE;
@@ -385,7 +437,7 @@ static const GList *get_tag_list(gint idx, guint tag_types, gboolean sort_by_nam
 			if (tag->type & tag_types)
 			{
 				if (! doc_is_utf8) utf8_name = encodings_convert_to_utf8_from_charset(tag->name,
-															-1, doc_list[idx].encoding, TRUE);
+															(gsize)-1, doc_list[idx].encoding, TRUE);
 				else utf8_name = tag->name;
 
 				if (utf8_name == NULL)
@@ -407,7 +459,7 @@ static const GList *get_tag_list(gint idx, guint tag_types, gboolean sort_by_nam
 				if (! doc_is_utf8) g_free(utf8_name);
 			}
 		}
-		if (sort_by_name)
+		if (sort_mode == SYMBOLS_SORT_BY_NAME)
 			tag_names = g_list_sort(tag_names, (GCompareFunc) compare_symbol);
 		else
 			tag_names = g_list_sort(tag_names, (GCompareFunc) compare_symbol_lines);
@@ -419,7 +471,7 @@ static const GList *get_tag_list(gint idx, guint tag_types, gboolean sort_by_nam
 }
 
 
-// amount of types in the symbol list (currently max. 8 are used)
+/* amount of types in the symbol list (currently max. 8 are used) */
 #define MAX_SYMBOL_TYPES	(sizeof(tv_iters) / sizeof(GtkTreeIter))
 
 struct TreeviewSymbols
@@ -436,10 +488,10 @@ struct TreeviewSymbols
 } tv_iters;
 
 
-static void init_tag_iters()
+static void init_tag_iters(void)
 {
-	// init all GtkTreeIters with -1 to make them invalid to avoid crashes when switching between
-	// filetypes(e.g. config file to Python crashes Geany without this)
+	/* init all GtkTreeIters with -1 to make them invalid to avoid crashes when switching between
+	 * filetypes(e.g. config file to Python crashes Geany without this) */
 	tv_iters.tag_function.stamp = -1;
 	tv_iters.tag_class.stamp = -1;
 	tv_iters.tag_member.stamp = -1;
@@ -531,7 +583,7 @@ static void init_tag_list(gint idx)
 				&(tv_iters.tag_struct), _("Appendix"), NULL,
 				&(tv_iters.tag_other), _("Other"), NULL,
 				NULL);
-			//	&(tv_iters.tag_namespace), _("Other"), NULL, NULL);
+			/*	&(tv_iters.tag_namespace), _("Other"), NULL, NULL);	*/
 			break;
 		}
 		case GEANY_FILETYPES_HASKELL:
@@ -571,9 +623,9 @@ static void init_tag_list(gint idx)
 				&(tv_iters.tag_macro), _("Local"), NULL,
 				&(tv_iters.tag_variable), _("Our"), NULL,
 				NULL);
-				//&(tv_iters.tag_struct), _("Label"), NULL,
-				//&(tv_iters.tag_namespace), _("Begin"), NULL,
-				//&(tv_iters.tag_other), _("Other"), NULL, NULL);
+				/*&(tv_iters.tag_struct), _("Label"), NULL,*/
+				/*&(tv_iters.tag_namespace), _("Begin"), NULL,*/
+				/*&(tv_iters.tag_other), _("Other"), NULL, NULL);*/
 			break;
 		}
 		case GEANY_FILETYPES_PHP:
@@ -585,9 +637,20 @@ static void init_tag_list(gint idx)
 				&(tv_iters.tag_macro), _("Constants"), "classviewer-macro",
 				&(tv_iters.tag_variable), _("Variables"), "classviewer-var",
 				NULL);
-				//&(tv_iters.tag_struct), _("Label"),
-				//&(tv_iters.tag_namespace), _("Begin"),
-				//&(tv_iters.tag_other), _("Other"), NULL);
+				/*&(tv_iters.tag_struct), _("Label"),*/
+				/*&(tv_iters.tag_namespace), _("Begin"),*/
+				/*&(tv_iters.tag_other), _("Other"), NULL);*/
+			break;
+		}
+		case GEANY_FILETYPES_HTML:
+		{
+			tag_list_add_groups(tag_store,
+				&(tv_iters.tag_function), _("JavaScript functions"), NULL,
+				&(tv_iters.tag_member), _("Anchor"), NULL,
+				&(tv_iters.tag_namespace), _("Heading (H1)"), NULL,
+				&(tv_iters.tag_class), _("Heading (H2)"), NULL,
+				&(tv_iters.tag_variable), _("Heading (H3)"), NULL,
+				NULL);
 			break;
 		}
 		case GEANY_FILETYPES_REST:
@@ -608,10 +671,11 @@ static void init_tag_list(gint idx)
 				&(tv_iters.tag_member), _("Singletons"), "classviewer-struct",
 				&(tv_iters.tag_function), _("Methods"), "classviewer-method",
 				NULL);
-				//&(tv_iters.tag_namespace), _("Begin"),
-				//&(tv_iters.tag_other), _("Other"), NULL);
+				/*&(tv_iters.tag_namespace), _("Begin"),*/
+				/*&(tv_iters.tag_other), _("Other"), NULL);*/
 			break;
 		}
+		case GEANY_FILETYPES_TCL:
 		case GEANY_FILETYPES_PYTHON:
 		{
 			tag_list_add_groups(tag_store,
@@ -620,25 +684,25 @@ static void init_tag_list(gint idx)
 				&(tv_iters.tag_function), _("Functions"), "classviewer-method",
 				&(tv_iters.tag_variable), _("Variables"), "classviewer-var",
 				NULL);
-				//&(tv_iters.tag_macro), _("Mixin"),
-				//&(tv_iters.tag_variable), _("Variables"),
-				//&(tv_iters.tag_struct), _("Members"),
-				//&(tv_iters.tag_namespace), _("Begin"),
-				//&(tv_iters.tag_other), _("Other"), NULL);
+				/*&(tv_iters.tag_macro), _("Mixin"),*/
+				/*&(tv_iters.tag_variable), _("Variables"),*/
+				/*&(tv_iters.tag_struct), _("Members"),*/
+				/*&(tv_iters.tag_namespace), _("Begin"),*/
+				/*&(tv_iters.tag_other), _("Other"), NULL);*/
 			break;
 		}
 		case GEANY_FILETYPES_VHDL:
 		{
 			tag_list_add_groups(tag_store,
 				&(tv_iters.tag_function), _("Functions"), "classviewer-method",
-				//&(tv_iters.tag_class), _("Constants"),
-				//&(tv_iters.tag_member), _("Members"),
-				//&(tv_iters.tag_macro), _("Macros"),
+				/*&(tv_iters.tag_class), _("Constants"),*/
+				/*&(tv_iters.tag_member), _("Members"),*/
+				/*&(tv_iters.tag_macro), _("Macros"),*/
 				&(tv_iters.tag_variable), _("Variables"), "classviewer-var",
 				NULL);
-				//&(tv_iters.tag_namespace), _("Namespaces"),
-				//&(tv_iters.tag_struct), _("Signals"),
-				//&(tv_iters.tag_other), _("Other"), NULL);
+				/*&(tv_iters.tag_namespace), _("Namespaces"),*/
+				/*&(tv_iters.tag_struct), _("Signals"),*/
+				/*&(tv_iters.tag_other), _("Other"), NULL);*/
 			break;
 		}
 		case GEANY_FILETYPES_JAVA:
@@ -649,8 +713,8 @@ static void init_tag_list(gint idx)
 				&(tv_iters.tag_class), _("Classes"), "classviewer-class",
 				&(tv_iters.tag_function), _("Methods"), "classviewer-method",
 				&(tv_iters.tag_member), _("Members"), "classviewer-member",
-			//	&(tv_iters.tag_macro), _("Macros"),
-			//	&(tv_iters.tag_variable), _("Variables"),
+				/*&(tv_iters.tag_macro), _("Macros"),*/
+				/*&(tv_iters.tag_variable), _("Variables"),*/
 				&(tv_iters.tag_other), _("Other"), "classviewer-other",
 				NULL);
 			break;
@@ -679,6 +743,36 @@ static void init_tag_list(gint idx)
 				NULL);
 			break;
 		}
+		case GEANY_FILETYPES_FORTRAN:
+		{
+			tag_list_add_groups(tag_store,
+				&(tv_iters.tag_namespace), _("Module"), NULL,
+				&(tv_iters.tag_struct), _("Interfaces"), "classviewer-struct",
+				&(tv_iters.tag_function), _("Functions"), "classviewer-method",
+				&(tv_iters.tag_member), _("Subroutines"), "classviewer-method",
+				&(tv_iters.tag_variable), _("Variables"), "classviewer-var",
+				&(tv_iters.tag_type), _("Types"), "classviewer-namespace",
+				&(tv_iters.tag_macro), _("Blocks"), "classviewer-member",
+				&(tv_iters.tag_other), _("Other"), "classviewer-other",
+				NULL);
+			break;
+		}
+		case GEANY_FILETYPES_ASM:
+		{
+			tag_list_add_groups(tag_store,
+				&(tv_iters.tag_namespace), _("Labels"), "classviewer-namespace",
+				&(tv_iters.tag_function), _("Macros"), "classviewer-method",
+				&(tv_iters.tag_macro), _("Defines"), "classviewer-macro",
+				&(tv_iters.tag_struct), _("Types"), "classviewer-struct",
+				NULL);
+			break;
+		}
+		case GEANY_FILETYPES_MAKE:
+			tag_list_add_groups(tag_store,
+				&tv_iters.tag_function, _("Targets"), "classviewer-method",
+				&tv_iters.tag_macro, _("Macros"), "classviewer-macro",
+				NULL);
+			break;
 		case GEANY_FILETYPES_D:
 		default:
 		{
@@ -718,15 +812,15 @@ static void hide_empty_rows(GtkTreeModel *model, GtkTreeStore *store)
 	guint i = 0;
 
 	if (! gtk_tree_model_get_iter_first(model, &iter))
-		return; // stop when first iter is invalid, i.e. no elements
+		return; /* stop when first iter is invalid, i.e. no elements */
 
-	do // first collect the iters we need to delete empty rows
+	do /* first collect the iters we need to delete empty rows */
 	{
 		if (! gtk_tree_model_iter_has_child(model, &iter))
 			iters[i++] = gtk_tree_iter_copy(&iter);
 	} while (gtk_tree_model_iter_next(model, &iter));
 
-	// now actually delete the collected iters
+	/* now actually delete the collected iters */
 	for (i = 0; i < MAX_SYMBOL_TYPES; i++)
 	{
 		if (iters[i] == NULL)
@@ -737,25 +831,33 @@ static void hide_empty_rows(GtkTreeModel *model, GtkTreeStore *store)
 }
 
 
-gboolean symbols_recreate_tag_list(gint idx, gboolean sort_by_name)
+gboolean symbols_recreate_tag_list(gint idx, gint sort_mode)
 {
 	GList *tmp;
 	const GList *tags;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
+	static gint prev_sort_mode = SYMBOLS_SORT_BY_NAME;
 	filetype_id ft_id = FILETYPE_ID(doc_list[idx].file_type);
 
 	g_return_val_if_fail(DOC_IDX_VALID(idx), FALSE);
 
-	tags = get_tag_list(idx, tm_tag_max_t, sort_by_name);
+	if (sort_mode == SYMBOLS_SORT_USE_PREVIOUS)
+		sort_mode = prev_sort_mode;
+	else
+		prev_sort_mode = sort_mode;
+
+	tags = get_tag_list(idx, tm_tag_max_t, sort_mode);
 	if (doc_list[idx].tm_file == NULL || tags == NULL)
 		return FALSE;
 
 	gtk_tree_store_clear(doc_list[idx].tag_store);
-	// unref the store to speed up the filling(from TreeView Tutorial)
+	/* unref the store to speed up the filling(from TreeView Tutorial) */
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(doc_list[idx].tag_tree));
-	g_object_ref(model); // Make sure the model stays with us after the tree view unrefs it
-	gtk_tree_view_set_model(GTK_TREE_VIEW(doc_list[idx].tag_tree), NULL); // Detach model from view
+	/* Make sure the model stays with us after the tree view unrefs it */
+	g_object_ref(model);
+	/* Detach model from view */
+	gtk_tree_view_set_model(GTK_TREE_VIEW(doc_list[idx].tag_tree), NULL);
 
 	init_tag_list(idx);
 	for (tmp = (GList*)tags; tmp; tmp = g_list_next(tmp))
@@ -800,7 +902,7 @@ gboolean symbols_recreate_tag_list(gint idx, gboolean sort_by_name)
 			case tm_tag_typedef_t:
 			case tm_tag_enum_t:
 			{
-				// TODO: separate C-like types here also
+				/** TODO separate C-like types here also */
 				if (ft_id == GEANY_FILETYPES_HAXE)
 				{
 					if (tv_iters.tag_type.stamp == -1) break;
@@ -851,7 +953,8 @@ gboolean symbols_recreate_tag_list(gint idx, gboolean sort_by_name)
 		}
 	}
 	hide_empty_rows(model, doc_list[idx].tag_store);
-	gtk_tree_view_set_model(GTK_TREE_VIEW(doc_list[idx].tag_tree), model); // Re-attach model to view
+	/* Re-attach model to view */
+	gtk_tree_view_set_model(GTK_TREE_VIEW(doc_list[idx].tag_tree), model);
 	g_object_unref(model);
 	gtk_tree_view_expand_all(GTK_TREE_VIEW(doc_list[idx].tag_tree));
 	return TRUE;
@@ -869,8 +972,8 @@ static filetype *detect_global_tags_filetype(const gchar *utf8_filename)
 	tags_ext = strstr(shortname, ".tags");
 	if (tags_ext)
 	{
-		*tags_ext = '\0';	// remove .tags extension
-		ft = filetypes_detect_from_filename(shortname);
+		*tags_ext = '\0';	/* remove .tags extension */
+		ft = filetypes_detect_from_extension(shortname);
 	}
 	g_free(shortname);
 
@@ -912,7 +1015,7 @@ int symbols_generate_global_tags(int argc, char **argv, gboolean want_preprocess
 		if (want_preprocess && (ft->id == GEANY_FILETYPES_C || ft->id == GEANY_FILETYPES_CPP))
 			command = g_strdup_printf("%s %s", pre_process, NVL(getenv("CFLAGS"), ""));
 		else
-			command = NULL;	// don't preprocess
+			command = NULL;	/* don't preprocess */
 
 		geany_debug("Generating %s tags file.", ft->name);
 		tm_get_workspace();
@@ -939,7 +1042,7 @@ int symbols_generate_global_tags(int argc, char **argv, gboolean want_preprocess
 }
 
 
-void symbols_show_load_tags_dialog()
+void symbols_show_load_tags_dialog(void)
 {
 	GtkWidget *dialog;
 	GtkFileFilter *filter;
@@ -1000,7 +1103,7 @@ static GHashTable *get_tagfile_hash(const GSList *file_list)
 
 		if (FILETYPE_ID(ft) < GEANY_FILETYPES_ALL)
 		{
-			fnames = g_hash_table_lookup(hash, ft);	// may be NULL
+			fnames = g_hash_table_lookup(hash, ft);	/* may be NULL */
 			fnames = g_list_append(fnames, fname);
 			g_hash_table_insert(hash, ft, fnames);
 		}
@@ -1011,7 +1114,7 @@ static GHashTable *get_tagfile_hash(const GSList *file_list)
 }
 
 
-static GHashTable *init_user_tags()
+static GHashTable *init_user_tags(void)
 {
 	GSList *file_list;
 	GHashTable *lang_hash;
@@ -1020,10 +1123,10 @@ static GHashTable *init_user_tags()
 	file_list = utils_get_file_list(user_tags_dir, NULL, NULL);
 	lang_hash = get_tagfile_hash(file_list);
 
-	// don't need to delete list contents because they are now used for hash contents
+	/* don't need to delete list contents because they are now used for hash contents */
 	g_slist_free(file_list);
 
-	// create the tags dir for next time if it doesn't exist
+	/* create the tags dir for next time if it doesn't exist */
 	if (! g_file_test(user_tags_dir, G_FILE_TEST_IS_DIR))
 	{
 		utils_mkdir(user_tags_dir, FALSE);
@@ -1044,7 +1147,7 @@ static void load_user_tags(filetype_id ft_id)
 
 	if (tags_loaded[ft_id])
 		return;
-	tags_loaded[ft_id] = TRUE;	// prevent reloading
+	tags_loaded[ft_id] = TRUE;	/* prevent reloading */
 
 	if (lang_hash == NULL)
 		lang_hash = init_user_tags();
@@ -1071,26 +1174,34 @@ gboolean symbols_goto_tag(const gchar *name, gboolean definition)
 {
 	const gint forward_types = tm_tag_prototype_t | tm_tag_externvar_t;
 	gint type;
-	TMTag *tmtag;
+	TMTag *tmtag = NULL;
+	gint old_idx = document_get_cur_idx();
 
-	// goto tag definition: all except prototypes / forward declarations / externs
+	/* goto tag definition: all except prototypes / forward declarations / externs */
 	type = (definition) ? tm_tag_max_t - forward_types : forward_types;
 
-	tmtag = find_workspace_tag(name, type);
+	/* first look in the current document */
+	if (doc_list[old_idx].tm_file)
+		tmtag = find_work_object_tag(doc_list[old_idx].tm_file, name, type);
+
+	/* if not found, look in the workspace */
+	if (tmtag == NULL)
+		tmtag = find_workspace_tag(name, type);
+
 	if (tmtag != NULL)
 	{
 		gint new_idx = document_find_by_filename(
 			tmtag->atts.entry.file->work_object.file_name, TRUE);
-		// not found in opened document, should open
+		/* not found in opened document, should open */
 		if (new_idx == -1)
 		{
 			new_idx = document_open_file(tmtag->atts.entry.file->work_object.file_name, FALSE, NULL, NULL);
 		}
 
-		if (navqueue_goto_line(new_idx, tmtag->atts.entry.line))
+		if (navqueue_goto_line(old_idx, new_idx, tmtag->atts.entry.line))
 			return TRUE;
 	}
-	// if we are here, there was no match and we are beeping ;-)
+	/* if we are here, there was no match and we are beeping ;-) */
 	utils_beep();
 	if (type == forward_types)
 		ui_set_statusbar(FALSE, _("Forward declaration \"%s\" not found."), name);
