@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: tools.c 2150 2008-01-06 18:11:57Z eht16 $
+ * $Id: tools.c 2348 2008-03-14 18:55:30Z eht16 $
  */
 
 /*
@@ -49,6 +49,7 @@
 #include "keybindings.h"
 #include "templates.h"
 #include "win32.h"
+#include "dialogs.h"
 
 
 /* custom commands code*/
@@ -58,6 +59,9 @@ struct cc_dialog
 	GtkWidget *box;
 };
 
+static gboolean cc_error_occurred = FALSE;
+static gboolean cc_reading_finished = FALSE;
+static GString *cc_buffer;
 
 static void cc_add_command(struct cc_dialog *cc, gint idx)
 {
@@ -91,18 +95,18 @@ static gboolean cc_iofunc(GIOChannel *ioc, GIOCondition cond, gpointer data)
 {
 	if (cond & (G_IO_IN | G_IO_PRI))
 	{
-		gint idx = GPOINTER_TO_INT(data);
 		gchar *msg = NULL;
-		GString *str = g_string_sized_new(256);
 		GIOStatus rv;
 		GError *err = NULL;
 
+		cc_buffer = g_string_sized_new(256);
+
 		do
 		{
 			rv = g_io_channel_read_line(ioc, &msg, NULL, NULL, &err);
 			if (msg != NULL)
 			{
-				g_string_append(str, msg);
+				g_string_append(cc_buffer, msg);
 				g_free(msg);
 			}
 			if (err != NULL)
@@ -113,15 +117,10 @@ static gboolean cc_iofunc(GIOChannel *ioc, GIOCondition cond, gpointer data)
 			}
 		} while (rv == G_IO_STATUS_NORMAL || rv == G_IO_STATUS_AGAIN);
 
-		if (rv == G_IO_STATUS_EOF)
-		{	// Command completed successfully
-			sci_replace_sel(doc_list[idx].sci, str->str);
-		}
-		else
-		{	// Something went wrong?
+		if (rv != G_IO_STATUS_EOF)
+		{	/* Something went wrong? */
 			g_warning("%s: %s\n", __func__, "Incomplete command output");
 		}
-		g_string_free(str, TRUE);
 	}
 	return FALSE;
 }
@@ -132,19 +131,98 @@ static gboolean cc_iofunc_err(GIOChannel *ioc, GIOCondition cond, gpointer data)
 	if (cond & (G_IO_IN | G_IO_PRI))
 	{
 		gchar *msg = NULL;
+		GString *str = g_string_sized_new(256);
+		GIOStatus rv;
 
-		while (g_io_channel_read_line(ioc, &msg, NULL, NULL, NULL) && msg != NULL)
+		do
 		{
-			g_warning("%s: %s", (const gchar*) data, g_strstrip(msg));
-			g_free(msg);
+			rv = g_io_channel_read_line(ioc, &msg, NULL, NULL, NULL);
+			if (msg != NULL)
+			{
+				g_string_append(str, msg);
+				g_free(msg);
+			}
+		} while (rv == G_IO_STATUS_NORMAL || rv == G_IO_STATUS_AGAIN);
+
+		if (NZV(str->str))
+		{
+			g_warning("%s: %s\n", (const gchar *) data, str->str);
+			ui_set_statusbar(TRUE,
+				_("The executed custom command returned an error. "
+				"Your selection was not changed. Error message: %s"),
+				str->str);
+			cc_error_occurred = TRUE;
+
 		}
+		g_string_free(str, TRUE);
+	}
+	cc_reading_finished = TRUE;
+	return FALSE;
+}
+
+
+static gboolean cc_replace_sel_cb(gpointer user_data)
+{
+	gint idx = GPOINTER_TO_INT(user_data);
+
+	if (! cc_reading_finished)
+	{	/* keep this function in the main loop until cc_iofunc_err() has finished */
 		return TRUE;
 	}
 
+	if (! cc_error_occurred && cc_buffer != NULL)
+	{	/* Command completed successfully */
+		sci_replace_sel(doc_list[idx].sci, cc_buffer->str);
+		g_string_free(cc_buffer, TRUE);
+		cc_buffer = NULL;
+	}
+
+	cc_error_occurred = FALSE;
+	cc_reading_finished = FALSE;
+
 	return FALSE;
 }
 
 
+/* check whether the executed command failed and if so do nothing.
+ * If it returned with a sucessful exit code, replace the selection. */
+static void cc_exit_cb(GPid child_pid, gint status, gpointer user_data)
+{
+	/* if there was already an error, skip further checks */
+	if (! cc_error_occurred)
+	{
+#ifdef G_OS_UNIX
+		if (WIFEXITED(status))
+		{
+			if (WEXITSTATUS(status) != EXIT_SUCCESS)
+				cc_error_occurred = TRUE;
+		}
+		else if (WIFSIGNALED(status))
+		{	/* the terminating signal: WTERMSIG (status)); */
+			cc_error_occurred = TRUE;
+		}
+		else
+		{	/* any other failure occured */
+			cc_error_occurred = TRUE;
+		}
+#else
+		cc_error_occurred = ! win32_get_exit_status(child_pid);
+#endif
+
+		if (cc_error_occurred)
+		{	/* here we are sure cc_error_occurred was set due to an unsuccessful exit code
+			 * and so we add an error message */
+			/* TODO maybe include the exit code in the error message */
+			ui_set_statusbar(TRUE,
+				_("The executed custom command exited with an unsuccessful exit code."));
+		}
+	}
+
+	g_idle_add(cc_replace_sel_cb, user_data);
+	g_spawn_close_pid(child_pid);
+}
+
+
 /* Executes command (which should include all necessary command line args) and passes the current
  * selection through the standard input of command. The whole output of command replaces the
  * current selection. */
@@ -165,25 +243,30 @@ void tools_execute_custom_command(gint idx, const gchar *command)
 	argv = g_strsplit(command, " ", -1);
 	ui_set_statusbar(TRUE, _("Passing data and executing custom command: %s"), command);
 
-	if (g_spawn_async_with_pipes(NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
+	cc_error_occurred = FALSE;
+
+	if (g_spawn_async_with_pipes(NULL, argv, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
 						NULL, NULL, &pid, &stdin_fd, &stdout_fd, &stderr_fd, &error))
 	{
 		gchar *sel;
 		gint len, remaining, wrote;
 
-		// use GIOChannel to monitor stdout
+		if (pid > 0)
+			g_child_watch_add(pid, (GChildWatchFunc) cc_exit_cb, GINT_TO_POINTER(idx));
+
+		/* use GIOChannel to monitor stdout */
 		utils_set_up_io_channel(stdout_fd, G_IO_IN|G_IO_PRI|G_IO_ERR|G_IO_HUP|G_IO_NVAL,
-				FALSE, cc_iofunc, GINT_TO_POINTER(idx));
-		// copy program's stderr to Geany's stdout to help error tracking
+				FALSE, cc_iofunc, NULL);
+		/* copy program's stderr to Geany's stdout to help error tracking */
 		utils_set_up_io_channel(stderr_fd, G_IO_IN|G_IO_PRI|G_IO_ERR|G_IO_HUP|G_IO_NVAL,
 				FALSE, cc_iofunc_err, (gpointer)command);
 
-		// get selection
+		/* get selection */
 		len = sci_get_selected_text_length(doc_list[idx].sci);
 		sel = g_malloc0(len + 1);
 		sci_get_selected_text(doc_list[idx].sci, sel);
 
-		// write data to the command
+		/* write data to the command */
 		remaining = len - 1;
 		do
 		{
@@ -202,6 +285,7 @@ void tools_execute_custom_command(gint idx, const gchar *command)
 	else
 	{
 		geany_debug("g_spawn_async_with_pipes() failed: %s", error->message);
+		ui_set_statusbar(TRUE, _("Custom command failed: %s"), error->message);
 		g_error_free(error);
 	}
 
@@ -209,7 +293,7 @@ void tools_execute_custom_command(gint idx, const gchar *command)
 }
 
 
-static void cc_show_dialog_custom_commands()
+static void cc_show_dialog_custom_commands(void)
 {
 	GtkWidget *dialog, *label, *vbox, *button;
 	guint i;
@@ -240,7 +324,7 @@ static void cc_show_dialog_custom_commands()
 		for (i = 0; i < g_strv_length(ui_prefs.custom_commands); i++)
 		{
 			if (ui_prefs.custom_commands[i][0] == '\0')
-				continue; // skip empty fields
+				continue; /* skip empty fields */
 
 			cc_add_command(&cc, i);
 		}
@@ -255,7 +339,7 @@ static void cc_show_dialog_custom_commands()
 
 	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
 	{
-		// get all hboxes which contain a label and an entry element
+		/* get all hboxes which contain a label and an entry element */
 		GList *children = gtk_container_get_children(GTK_CONTAINER(cc.box));
 		GList *tmp;
 		GSList *result_list = NULL;
@@ -266,15 +350,15 @@ static void cc_show_dialog_custom_commands()
 
 		while (children != NULL)
 		{
-			// get the contents of each hbox
+			/* get the contents of each hbox */
 			tmp = gtk_container_get_children(GTK_CONTAINER(children->data));
 
-			// first element of the list is the label, so skip it and get the entry element
+			/* first element of the list is the label, so skip it and get the entry element */
 			tmp = tmp->next;
 
 			text = gtk_entry_get_text(GTK_ENTRY(tmp->data));
 
-			// if the content of the entry is non-empty, add it to the result array
+			/* if the content of the entry is non-empty, add it to the result array */
 			if (text[0] != '\0')
 			{
 				result_list = g_slist_append(result_list, g_strdup(text));
@@ -282,7 +366,7 @@ static void cc_show_dialog_custom_commands()
 			}
 			children = children->next;
 		}
-		// create a new null-terminated array but only if there any commands defined
+		/* create a new null-terminated array but only if there any commands defined */
 		if (len > 0)
 		{
 			result = g_new(gchar*, len + 1);
@@ -293,12 +377,12 @@ static void cc_show_dialog_custom_commands()
 				result_list = result_list->next;
 				j++;
 			}
-			result[len] = NULL; // null-terminate the array
+			result[len] = NULL; /* null-terminate the array */
 		}
-		// set the new array
+		/* set the new array */
 		g_strfreev(ui_prefs.custom_commands);
 		ui_prefs.custom_commands = result;
-		// rebuild the menu items
+		/* rebuild the menu items */
 		tools_create_insert_custom_command_menu_items();
 
 		g_slist_free(result_list);
@@ -326,7 +410,7 @@ static void cc_on_custom_command_menu_activate(GtkMenuItem *menuitem, gpointer u
 	while (children != NULL)
 	{
 		if (i == (len - 2))
-			break; // stop before the last two elements (the seperator and the set entry)
+			break; /* stop before the last two elements (the seperator and the set entry) */
 
 		gtk_widget_set_sensitive(GTK_WIDGET(children->data), enable);
 		children = children->next;
@@ -351,8 +435,8 @@ static void cc_on_custom_command_activate(GtkMenuItem *menuitem, gpointer user_d
 		return;
 	}
 
-	// send it through the command and when the command returned the output the current selection
-	// will be replaced
+	/* send it through the command and when the command returned the output the current selection
+	 * will be replaced */
 	tools_execute_custom_command(idx, ui_prefs.custom_commands[command_idx]);
 }
 
@@ -361,18 +445,22 @@ static void cc_insert_custom_command_items(GtkMenu *me, GtkMenu *mp, gchar *labe
 {
 	GtkWidget *item;
 	gint key_idx = -1;
+	KeyBinding *kb = NULL;
 
 	switch (idx)
 	{
-		case 0: key_idx = GEANY_KEYS_EDIT_SENDTOCMD1; break;
-		case 1: key_idx = GEANY_KEYS_EDIT_SENDTOCMD2; break;
-		case 2: key_idx = GEANY_KEYS_EDIT_SENDTOCMD3; break;
+		case 0: key_idx = GEANY_KEYS_FORMAT_SENDTOCMD1; break;
+		case 1: key_idx = GEANY_KEYS_FORMAT_SENDTOCMD2; break;
+		case 2: key_idx = GEANY_KEYS_FORMAT_SENDTOCMD3; break;
 	}
 
+	if (key_idx != -1)
+		kb = keybindings_lookup_item(GEANY_KEY_GROUP_FORMAT, key_idx);
+
 	item = gtk_menu_item_new_with_label(label);
 	if (key_idx != -1)
 		gtk_widget_add_accelerator(item, "activate", gtk_accel_group_new(),
-			keys[key_idx]->key, keys[key_idx]->mods, GTK_ACCEL_VISIBLE);
+			kb->key, kb->mods, GTK_ACCEL_VISIBLE);
 	gtk_container_add(GTK_CONTAINER(me), item);
 	gtk_widget_show(item);
 	g_signal_connect((gpointer) item, "activate", G_CALLBACK(cc_on_custom_command_activate),
@@ -381,7 +469,7 @@ static void cc_insert_custom_command_items(GtkMenu *me, GtkMenu *mp, gchar *labe
 	item = gtk_menu_item_new_with_label(label);
 	if (key_idx != -1)
 		gtk_widget_add_accelerator(item, "activate", gtk_accel_group_new(),
-			keys[key_idx]->key, keys[key_idx]->mods, GTK_ACCEL_VISIBLE);
+			kb->key, kb->mods, GTK_ACCEL_VISIBLE);
 	gtk_container_add(GTK_CONTAINER(mp), item);
 	gtk_widget_show(item);
 	g_signal_connect((gpointer) item, "activate", G_CALLBACK(cc_on_custom_command_activate),
@@ -389,7 +477,7 @@ static void cc_insert_custom_command_items(GtkMenu *me, GtkMenu *mp, gchar *labe
 }
 
 
-void tools_create_insert_custom_command_menu_items()
+void tools_create_insert_custom_command_menu_items(void)
 {
 	GtkMenu *menu_edit = GTK_MENU(lookup_widget(app->window, "send_selection_to2_menu"));
 	GtkMenu *menu_popup = GTK_MENU(lookup_widget(app->popup_menu, "send_selection_to1_menu"));
@@ -398,7 +486,7 @@ void tools_create_insert_custom_command_menu_items()
 	GList *mp_children;
 	static gboolean signal_set = FALSE;
 
-	// first clean the menus to be able to rebuild them
+	/* first clean the menus to be able to rebuild them */
 	me_children = gtk_container_get_children(GTK_CONTAINER(menu_edit));
 	mp_children = gtk_container_get_children(GTK_CONTAINER(menu_popup));
 	while (me_children != NULL)
@@ -428,7 +516,7 @@ void tools_create_insert_custom_command_menu_items()
 		gint idx = 0;
 		for (i = 0; i < g_strv_length(ui_prefs.custom_commands); i++)
 		{
-			if (ui_prefs.custom_commands[i][0] != '\0') // skip empty fields
+			if (ui_prefs.custom_commands[i][0] != '\0') /* skip empty fields */
 			{
 				cc_insert_custom_command_items(menu_edit, menu_popup, ui_prefs.custom_commands[i], idx);
 				idx++;
@@ -436,7 +524,7 @@ void tools_create_insert_custom_command_menu_items()
 		}
 	}
 
-	// separator and Set menu item
+	/* separator and Set menu item */
 	item = gtk_separator_menu_item_new();
 	gtk_container_add(GTK_CONTAINER(menu_edit), item);
 	gtk_widget_show(item);
@@ -460,15 +548,13 @@ void tools_create_insert_custom_command_menu_items()
 /* (stolen from bluefish, thanks)
  * Returns number of characters, lines and words in the supplied gchar*.
  * Handles UTF-8 correctly. Input must be properly encoded UTF-8.
- * Words are defined as any characters grouped, separated with spaces.
- */
-static void
-word_count(gchar *text, guint *chars, guint *lines, guint *words)
+ * Words are defined as any characters grouped, separated with spaces. */
+static void word_count(gchar *text, guint *chars, guint *lines, guint *words)
 {
 	guint in_word = 0;
 	gunichar utext;
 
-	if (!text) return; // politely refuse to operate on NULL
+	if (!text) return; /* politely refuse to operate on NULL */
 
 	*chars = *words = *lines = 0;
 	while (*text != '\0')
@@ -492,24 +578,25 @@ word_count(gchar *text, guint *chars, guint *lines, guint *words)
 				}
 				break;
 			default:
-				utext = g_utf8_get_char_validated(text, 2); // This might be an utf-8 char
-				if (g_unichar_isspace(utext)) // Unicode encoded space?
+				utext = g_utf8_get_char_validated(text, 2); /* This might be an utf-8 char */
+				if (g_unichar_isspace(utext)) /* Unicode encoded space? */
 					goto mb_word_separator;
-				if (g_unichar_isgraph(utext)) // Is this something printable?
+				if (g_unichar_isgraph(utext)) /* Is this something printable? */
 					in_word = 1;
 				break;
 		}
-		text = g_utf8_next_char(text); // Even if the current char is 2 bytes, this will iterate correctly.
+		/* Even if the current char is 2 bytes, this will iterate correctly. */
+		text = g_utf8_next_char(text);
 	}
 
-	// Capture last word, if there's no whitespace at the end of the file.
+	/* Capture last word, if there's no whitespace at the end of the file. */
 	if (in_word) (*words)++;
-	// We start counting line numbers from 1
+	/* We start counting line numbers from 1 */
 	if (*chars > 0) (*lines)++;
 }
 
 
-void tools_word_count()
+void tools_word_count(void)
 {
 	GtkWidget *dialog, *label, *vbox, *table;
 	gint idx;
@@ -662,13 +749,13 @@ void tools_color_chooser(gchar *color)
 		g_signal_connect(ui_widgets.open_colorsel, "delete_event",
 						G_CALLBACK(gtk_widget_hide_on_delete), NULL);
 	}
-	// if color is non-NULL set it in the dialog as preselected color
+	/* if color is non-NULL set it in the dialog as preselected color */
 	if (color != NULL && (color[0] == '0' || color[0] == '#'))
 	{
 		GdkColor gc;
 
 		if (color[0] == '0' && color[1] == 'x')
-		{	// we have a string of the format "0x00ff00" and we need it to "#00ff00"
+		{	/* we have a string of the format "0x00ff00" and we need it to "#00ff00" */
 			color[1] = '#';
 			color++;
 		}
@@ -679,7 +766,7 @@ void tools_color_chooser(gchar *color)
 							GTK_COLOR_SELECTION_DIALOG(ui_widgets.open_colorsel)->colorsel), &gc);
 	}
 
-	// We make sure the dialog is visible.
+	/* We make sure the dialog is visible. */
 	gtk_window_present(GTK_WINDOW(ui_widgets.open_colorsel));
 #endif
 }
