@@ -18,19 +18,19 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: tools.h 2150 2008-01-06 18:11:57Z eht16 $
+ * $Id: tools.h 2267 2008-02-20 11:24:23Z eht16 $
  */
 
 
 #ifndef GEANY_TOOLS_H
 #define GEANY_TOOLS_H 1
 
-void tools_create_insert_custom_command_menu_items();
+void tools_create_insert_custom_command_menu_items(void);
 
 void tools_execute_custom_command(gint idx, const gchar *command);
 
 
-void tools_word_count();
+void tools_word_count(void);
 
 void tools_color_chooser(gchar *color);
 
