@@ -1,8 +1,8 @@
 /*
  *      treeviews.c - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2005-2007 Enrico Tröger <enrico.troeger@uvena.de>
- *      Copyright 2006-2007 Nick Treleaven <nick.treleaven@btinternet.com>
+ *      Copyright 2005-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2006-2008 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: treeviews.c 1936 2007-10-09 12:26:44Z eht16 $
+ * $Id: treeviews.c 2386 2008-03-21 18:44:12Z eht16 $
  */
 
 /*
@@ -39,6 +39,7 @@
 #include "symbols.h"
 #include "navqueue.h"
 
+#include <gdk/gdkkeysyms.h>
 
 SidebarTreeviews tv;
 
@@ -61,18 +62,31 @@ enum
 	SYMBOL_ACTION_HIDE_ALL
 };
 
+typedef struct
+{
+	GtkWidget *documents_fullpath;
+	GtkWidget *documents_show_symbols;
+	GtkWidget *documents_show_documents;
+	GtkWidget *symbols_show_symbols;
+	GtkWidget *symbols_show_documents;
+} menu_items;
+static menu_items mi;
 
 static GtkListStore	*store_openfiles;
-static GtkWidget *tag_window;	// scrolled window that holds the symbol list GtkTreeView
-
+static GtkWidget *tag_window;	/* scrolled window that holds the symbol list GtkTreeView */
 
 /* callback prototypes */
 static void on_taglist_tree_popup_clicked(GtkMenuItem *menuitem, gpointer user_data);
 static void on_openfiles_tree_selection_changed(GtkTreeSelection *selection, gpointer data);
-static void on_openfiles_tree_popup_clicked(GtkMenuItem *menuitem, gpointer user_data);
+static void on_openfiles_document_action(GtkMenuItem *menuitem, gpointer user_data);
+static void on_openfiles_hide_item_clicked(GtkMenuItem *menuitem, gpointer user_data);
 static gboolean on_taglist_tree_selection_changed(GtkTreeSelection *selection);
 static gboolean on_treeviews_button_press_event(GtkWidget *widget, GdkEventButton *event,
 																			gpointer user_data);
+static gboolean on_treeviews_key_press_event(GtkWidget *widget, GdkEventKey *event,
+																			gpointer user_data);
+static void on_list_document_activate(GtkCheckMenuItem *item, gpointer user_data);
+static void on_list_symbol_activate(GtkCheckMenuItem *item, gpointer user_data);
 
 
 /* the prepare_* functions are document-related, but I think they fit better here than in document.c */
@@ -106,13 +120,21 @@ static void prepare_taglist(GtkWidget *tree, GtkTreeStore *store)
 	gtk_tree_view_set_model(GTK_TREE_VIEW(tree), GTK_TREE_MODEL(store));
 	g_signal_connect(G_OBJECT(tree), "button-press-event",
 					G_CALLBACK(on_treeviews_button_press_event), GINT_TO_POINTER(TREEVIEW_SYMBOL));
+	g_signal_connect(G_OBJECT(tree), "key-press-event",
+					G_CALLBACK(on_treeviews_key_press_event), GINT_TO_POINTER(TREEVIEW_SYMBOL));
 
 	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(tree), FALSE);
 
-	// selection handling
+#if GTK_CHECK_VERSION(2, 12, 0)
+	gtk_tree_view_set_show_expanders(GTK_TREE_VIEW(tree), prefs.show_symbol_list_expanders);
+	if (! prefs.show_symbol_list_expanders)
+		gtk_tree_view_set_level_indentation(GTK_TREE_VIEW(tree), 10);
+#endif
+
+	/* selection handling */
 	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree));
 	gtk_tree_selection_set_mode(select, GTK_SELECTION_SINGLE);
-	// callback for changed selection not necessary, will be handled by button-press-event
+	/* callback for changed selection not necessary, will be handled by button-press-event */
 }
 
 
@@ -128,7 +150,7 @@ on_default_tag_tree_button_press_event(GtkWidget *widget, GdkEventButton *event,
 }
 
 
-// update = rescan the tags for document[idx].filename
+/* update = rescan the tags for document[idx].filename */
 void treeviews_update_tag_list(gint idx, gboolean update)
 {
 	if (gtk_bin_get_child(GTK_BIN(tag_window)))
@@ -139,7 +161,7 @@ void treeviews_update_tag_list(gint idx, gboolean update)
 		GtkScrolledWindow *scrolled_window = GTK_SCROLLED_WINDOW(tag_window);
 		GtkWidget *label;
 
-		// default_tag_tree is a GtkViewPort with a GtkLabel inside it
+		/* default_tag_tree is a GtkViewPort with a GtkLabel inside it */
 		tv.default_tag_tree = gtk_viewport_new(
 			gtk_scrolled_window_get_hadjustment(scrolled_window),
 			gtk_scrolled_window_get_vadjustment(scrolled_window));
@@ -149,10 +171,10 @@ void treeviews_update_tag_list(gint idx, gboolean update)
 		gtk_widget_show_all(tv.default_tag_tree);
 		g_signal_connect(G_OBJECT(tv.default_tag_tree), "button-press-event",
 			G_CALLBACK(on_default_tag_tree_button_press_event), NULL);
-		g_object_ref((gpointer)tv.default_tag_tree);	// to hold it after removing
+		g_object_ref((gpointer)tv.default_tag_tree);	/* to hold it after removing */
 	}
 
-	// show default empty tag tree if there are no tags
+	/* show default empty tag tree if there are no tags */
 	if (idx == -1 || doc_list[idx].file_type == NULL ||
 		! filetype_has_tags(doc_list[idx].file_type))
 	{
@@ -161,7 +183,7 @@ void treeviews_update_tag_list(gint idx, gboolean update)
 	}
 
 	if (update)
-	{	// updating the tag list in the left tag window
+	{	/* updating the tag list in the left tag window */
 		if (doc_list[idx].tag_tree == NULL)
 		{
 			doc_list[idx].tag_store = gtk_tree_store_new(
@@ -169,10 +191,10 @@ void treeviews_update_tag_list(gint idx, gboolean update)
 			doc_list[idx].tag_tree = gtk_tree_view_new();
 			prepare_taglist(doc_list[idx].tag_tree, doc_list[idx].tag_store);
 			gtk_widget_show(doc_list[idx].tag_tree);
-			g_object_ref((gpointer)doc_list[idx].tag_tree);	// to hold it after removing
+			g_object_ref((gpointer)doc_list[idx].tag_tree);	/* to hold it after removing */
 		}
 
-		doc_list[idx].has_tags = symbols_recreate_tag_list(idx, TRUE); // sort by name by default
+		doc_list[idx].has_tags = symbols_recreate_tag_list(idx, SYMBOLS_SORT_USE_PREVIOUS);
 	}
 
 	if (doc_list[idx].has_tags)
@@ -215,7 +237,7 @@ gboolean on_treeviews_tooltip_queried(GtkWidget *widget, gint x, gint y, gboolea
 
 
 /* does some preparing things to the open files list widget */
-static void prepare_openfiles()
+static void prepare_openfiles(void)
 {
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
@@ -225,8 +247,8 @@ static void prepare_openfiles()
 
 	tv.tree_openfiles = lookup_widget(app->window, "treeview6");
 
-	// store the short filename to show, and the index as reference,
-	// the colour (black/red/green) and the full name for the tooltip
+	/* store the short filename to show, and the index as reference,
+	 * the colour (black/red/green) and the full name for the tooltip */
 #if GTK_CHECK_VERSION(2, 12, 0)
 	store_openfiles = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_INT, GDK_TYPE_COLOR, G_TYPE_STRING);
 #else
@@ -234,21 +256,21 @@ static void prepare_openfiles()
 #endif
 	gtk_tree_view_set_model(GTK_TREE_VIEW(tv.tree_openfiles), GTK_TREE_MODEL(store_openfiles));
 
-	// set policy settings for the scolledwindow around the treeview again, because glade
-	// doesn't keep the settings
+	/* set policy settings for the scolledwindow around the treeview again, because glade
+	 * doesn't keep the settings */
 	gtk_scrolled_window_set_policy(
 			GTK_SCROLLED_WINDOW(lookup_widget(app->window, "scrolledwindow7")),
 			GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
 	renderer = gtk_cell_renderer_text_new();
-	column = gtk_tree_view_column_new_with_attributes(_("Open files"), renderer,
+	column = gtk_tree_view_column_new_with_attributes(_("Documents"), renderer,
 															"text", 0, "foreground-gdk", 2, NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(tv.tree_openfiles), column);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(tv.tree_openfiles), FALSE);
 
 	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(tv.tree_openfiles), FALSE);
 
-	// sort opened filenames in the store_openfiles treeview
+	/* sort opened filenames in the store_openfiles treeview */
 	sortable = GTK_TREE_SORTABLE(GTK_TREE_MODEL(store_openfiles));
 	gtk_tree_sortable_set_sort_column_id(sortable, 0, GTK_SORT_ASCENDING);
 
@@ -257,7 +279,7 @@ static void prepare_openfiles()
 	pango_font_description_free(pfd);
 
 #if GTK_CHECK_VERSION(2, 12, 0)
-	// GTK 2.12 tooltips
+	/* GTK 2.12 tooltips */
 	gtk_widget_set_has_tooltip(tv.tree_openfiles, TRUE);
 	g_signal_connect(G_OBJECT(tv.tree_openfiles), "query-tooltip",
 						G_CALLBACK(on_treeviews_tooltip_queried), NULL);
@@ -266,7 +288,7 @@ static void prepare_openfiles()
 	g_signal_connect(G_OBJECT(tv.tree_openfiles), "button-press-event",
 						G_CALLBACK(on_treeviews_button_press_event), GINT_TO_POINTER(TREEVIEW_OPENFILES));
 
-	// selection handling
+	/* selection handling */
 	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(tv.tree_openfiles));
 	gtk_tree_selection_set_mode(select, GTK_SELECTION_SINGLE);
 	g_signal_connect(G_OBJECT(select), "changed", G_CALLBACK(on_openfiles_tree_selection_changed), NULL);
@@ -289,18 +311,21 @@ void treeviews_openfiles_update(gint idx)
 	gchar *basename;
 	GdkColor *color = document_get_status(idx);
 
-	basename = g_path_get_basename(DOC_FILENAME(idx));
+	if (prefs.sidebar_openfiles_fullpath)
+		basename = DOC_FILENAME(idx);
+	else
+		basename = g_path_get_basename(DOC_FILENAME(idx));
 	gtk_list_store_set(store_openfiles, &doc_list[idx].iter,
 #if GTK_CHECK_VERSION(2, 12, 0)
 		0, basename, 1, idx, 2, color, 3, DOC_FILENAME(idx), -1);
 #else
 		0, basename, 1, idx, 2, color, -1);
 #endif
-	g_free(basename);
+	if (! prefs.sidebar_openfiles_fullpath)
+		g_free(basename);
 }
 
 
-#if 0
 void treeviews_openfiles_update_all()
 {
 	guint i;
@@ -315,7 +340,6 @@ void treeviews_openfiles_update_all()
 		treeviews_openfiles_add(idx);
 	}
 }
-#endif
 
 
 void treeviews_remove_document(gint idx)
@@ -329,7 +353,7 @@ void treeviews_remove_document(gint idx)
 		gtk_widget_destroy(doc_list[idx].tag_tree);
 		if (GTK_IS_TREE_VIEW(doc_list[idx].tag_tree))
 		{
-			// Because it was ref'd in treeviews_update_tag_list, it needs unref'ing
+			/* Because it was ref'd in treeviews_update_tag_list, it needs unref'ing */
 			g_object_unref((gpointer)doc_list[idx].tag_tree);
 		}
 		doc_list[idx].tag_tree = NULL;
@@ -337,20 +361,20 @@ void treeviews_remove_document(gint idx)
 }
 
 
-static void create_taglist_popup_menu()
+static void create_taglist_popup_menu(void)
 {
 	GtkWidget *item;
 
 	tv.popup_taglist = gtk_menu_new();
 
-	item = gtk_menu_item_new_with_label(_("Sort by name"));
+	item = gtk_menu_item_new_with_mnemonic(_("Sort by _Name"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(tv.popup_taglist), item);
 	g_signal_connect((gpointer) item, "activate",
 				G_CALLBACK(on_taglist_tree_popup_clicked),
 				GINT_TO_POINTER(SYMBOL_ACTION_SORT_BY_NAME));
 
-	item = gtk_menu_item_new_with_label(_("Sort by appearance"));
+	item = gtk_menu_item_new_with_mnemonic(_("Sort by _Appearance"));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(tv.popup_taglist), item);
 	g_signal_connect((gpointer) item, "activate",
@@ -361,15 +385,19 @@ static void create_taglist_popup_menu()
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(tv.popup_taglist), item);
 
-	item = gtk_image_menu_item_new_with_label(_("Hide"));
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
-		gtk_image_new_from_stock("gtk-close", GTK_ICON_SIZE_MENU));
-	gtk_widget_show(item);
-	gtk_container_add(GTK_CONTAINER(tv.popup_taglist), item);
-	g_signal_connect((gpointer) item, "activate",
-				G_CALLBACK(on_taglist_tree_popup_clicked), GINT_TO_POINTER(SYMBOL_ACTION_HIDE));
+	mi.symbols_show_symbols = gtk_check_menu_item_new_with_mnemonic(_("Show S_ymbol List"));
+	gtk_widget_show(mi.symbols_show_symbols);
+	gtk_container_add(GTK_CONTAINER(tv.popup_taglist), mi.symbols_show_symbols);
+	g_signal_connect((gpointer) mi.symbols_show_symbols, "activate",
+			G_CALLBACK(on_list_symbol_activate), NULL);
 
-	item = gtk_image_menu_item_new_with_label(_("Hide sidebar"));
+	mi.symbols_show_documents = gtk_check_menu_item_new_with_mnemonic(_("Show _Document List"));
+	gtk_widget_show(mi.symbols_show_documents);
+	gtk_container_add(GTK_CONTAINER(tv.popup_taglist), mi.symbols_show_documents);
+	g_signal_connect((gpointer) mi.symbols_show_documents, "activate",
+			G_CALLBACK(on_list_document_activate), NULL);
+
+	item = gtk_image_menu_item_new_with_mnemonic(_("H_ide Sidebar"));
 	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
 		gtk_image_new_from_stock("gtk-close", GTK_ICON_SIZE_MENU));
 	gtk_widget_show(item);
@@ -379,7 +407,28 @@ static void create_taglist_popup_menu()
 }
 
 
-static void create_openfiles_popup_menu()
+static void on_openfiles_fullpath_activate(GtkCheckMenuItem *item, gpointer user_data)
+{
+	prefs.sidebar_openfiles_fullpath = gtk_check_menu_item_get_active(item);
+	treeviews_openfiles_update_all();
+}
+
+
+static void on_list_document_activate(GtkCheckMenuItem *item, gpointer user_data)
+{
+	prefs.sidebar_openfiles_visible = gtk_check_menu_item_get_active(item);
+	ui_sidebar_show_hide();
+}
+
+
+static void on_list_symbol_activate(GtkCheckMenuItem *item, gpointer user_data)
+{
+	prefs.sidebar_symbol_visible = gtk_check_menu_item_get_active(item);
+	ui_sidebar_show_hide();
+}
+
+
+static void create_openfiles_popup_menu(void)
 {
 	GtkWidget *item;
 
@@ -389,7 +438,7 @@ static void create_openfiles_popup_menu()
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(tv.popup_openfiles), item);
 	g_signal_connect((gpointer) item, "activate",
-				G_CALLBACK(on_openfiles_tree_popup_clicked), GINT_TO_POINTER(OPENFILES_ACTION_REMOVE));
+			G_CALLBACK(on_openfiles_document_action), GINT_TO_POINTER(OPENFILES_ACTION_REMOVE));
 
 	item = gtk_separator_menu_item_new();
 	gtk_widget_show(item);
@@ -399,35 +448,49 @@ static void create_openfiles_popup_menu()
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(tv.popup_openfiles), item);
 	g_signal_connect((gpointer) item, "activate",
-				G_CALLBACK(on_openfiles_tree_popup_clicked), GINT_TO_POINTER(OPENFILES_ACTION_SAVE));
+			G_CALLBACK(on_openfiles_document_action), GINT_TO_POINTER(OPENFILES_ACTION_SAVE));
 
-	item = gtk_image_menu_item_new_with_label(_("Reload"));
+	item = gtk_image_menu_item_new_with_mnemonic(_("_Reload"));
 	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
 		gtk_image_new_from_stock("gtk-revert-to-saved", GTK_ICON_SIZE_MENU));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(tv.popup_openfiles), item);
 	g_signal_connect((gpointer) item, "activate",
-				G_CALLBACK(on_openfiles_tree_popup_clicked), GINT_TO_POINTER(OPENFILES_ACTION_RELOAD));
+			G_CALLBACK(on_openfiles_document_action), GINT_TO_POINTER(OPENFILES_ACTION_RELOAD));
 
 	item = gtk_separator_menu_item_new();
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(tv.popup_openfiles), item);
 
-	item = gtk_image_menu_item_new_with_label(_("Hide"));
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
-		gtk_image_new_from_stock("gtk-close", GTK_ICON_SIZE_MENU));
-	gtk_widget_show(item);
-	gtk_container_add(GTK_CONTAINER(tv.popup_openfiles), item);
-	g_signal_connect((gpointer) item, "activate", G_CALLBACK(on_openfiles_tree_popup_clicked),
-												GINT_TO_POINTER(OPENFILES_ACTION_HIDE));
+	mi.documents_fullpath = gtk_check_menu_item_new_with_mnemonic(_("Show _Full Path Name"));
+	gtk_widget_show(mi.documents_fullpath);
+	gtk_container_add(GTK_CONTAINER(tv.popup_openfiles), mi.documents_fullpath);
+	g_signal_connect((gpointer) mi.documents_fullpath, "activate",
+			G_CALLBACK(on_openfiles_fullpath_activate), NULL);
 
-	item = gtk_image_menu_item_new_with_label(_("Hide sidebar"));
+	item = gtk_separator_menu_item_new();
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(tv.popup_openfiles), item);
+
+	mi.documents_show_symbols = gtk_check_menu_item_new_with_mnemonic(_("Show S_ymbol List"));
+	gtk_widget_show(mi.documents_show_symbols);
+	gtk_container_add(GTK_CONTAINER(tv.popup_openfiles), mi.documents_show_symbols);
+	g_signal_connect((gpointer) mi.documents_show_symbols, "activate",
+			G_CALLBACK(on_list_symbol_activate), NULL);
+
+	mi.documents_show_documents = gtk_check_menu_item_new_with_mnemonic(_("Show _Document List"));
+	gtk_widget_show(mi.documents_show_documents);
+	gtk_container_add(GTK_CONTAINER(tv.popup_openfiles), mi.documents_show_documents);
+	g_signal_connect((gpointer) mi.documents_show_documents, "activate",
+			G_CALLBACK(on_list_document_activate), NULL);
+
+	item = gtk_image_menu_item_new_with_mnemonic(_("H_ide Sidebar"));
 	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
 		gtk_image_new_from_stock("gtk-close", GTK_ICON_SIZE_MENU));
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(tv.popup_openfiles), item);
-	g_signal_connect((gpointer) item, "activate", G_CALLBACK(on_openfiles_tree_popup_clicked),
-													GINT_TO_POINTER(OPENFILES_ACTION_HIDE_ALL));
+	g_signal_connect((gpointer) item, "activate",
+		G_CALLBACK(on_openfiles_hide_item_clicked), NULL);
 }
 
 
@@ -459,7 +522,7 @@ void treeviews_select_openfiles_item(gint idx)
 
 /* callbacks */
 
-static void on_openfiles_tree_popup_clicked(GtkMenuItem *menuitem, gpointer user_data)
+static void on_openfiles_document_action(GtkMenuItem *menuitem, gpointer user_data)
 {
 	GtkTreeIter iter;
 	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tv.tree_openfiles));
@@ -488,29 +551,24 @@ static void on_openfiles_tree_popup_clicked(GtkMenuItem *menuitem, gpointer user
 					on_toolbutton23_clicked(NULL, NULL);
 					break;
 				}
-				case OPENFILES_ACTION_HIDE:
-				{
-					prefs.sidebar_openfiles_visible = FALSE;
-					ui_treeviews_show_hide(FALSE);
-					break;
-				}
-				case OPENFILES_ACTION_HIDE_ALL:
-				{
-					ui_prefs.sidebar_visible = FALSE;
-					ui_treeviews_show_hide(TRUE);
-					break;
-				}
 			}
 		}
 	}
 }
 
 
+static void on_openfiles_hide_item_clicked(GtkMenuItem *menuitem, gpointer user_data)
+{
+	ui_prefs.sidebar_visible = FALSE;
+	ui_sidebar_show_hide();
+}
+
+
 static gboolean change_focus(gpointer data)
 {
-	gint idx = (gint) data;
+	gint idx = GPOINTER_TO_INT(data);
 
-	// idx might not be valid e.g. if user closed a tab whilst Geany is opening files
+	/* idx might not be valid e.g. if user closed a tab whilst Geany is opening files */
 	if (DOC_IDX_VALID(idx))
 	{
 		GtkWidget *focusw = gtk_window_get_focus(GTK_WINDOW(app->window));
@@ -529,14 +587,14 @@ static void on_openfiles_tree_selection_changed(GtkTreeSelection *selection, gpo
 	GtkTreeModel *model;
 	gint idx = 0;
 
-	// use switch_notebook_page to ignore changing the notebook page because it is already done
+	/* use switch_notebook_page to ignore changing the notebook page because it is already done */
 	if (gtk_tree_selection_get_selected(selection, &model, &iter) && ! app->ignore_callback)
 	{
 		gtk_tree_model_get(model, &iter, 1, &idx, -1);
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(app->notebook),
 					gtk_notebook_page_num(GTK_NOTEBOOK(app->notebook),
 					(GtkWidget*) doc_list[idx].sci));
-		g_idle_add((GSourceFunc) change_focus, (gpointer) idx);
+		g_idle_add((GSourceFunc) change_focus, GINT_TO_POINTER(idx));
 	}
 }
 
@@ -549,26 +607,26 @@ static void on_taglist_tree_popup_clicked(GtkMenuItem *menuitem, gpointer user_d
 		{
 			gint idx = document_get_cur_idx();
 			if (DOC_IDX_VALID(idx))
-				doc_list[idx].has_tags = symbols_recreate_tag_list(idx, TRUE);
+				doc_list[idx].has_tags = symbols_recreate_tag_list(idx, SYMBOLS_SORT_BY_NAME);
 			break;
 		}
 		case SYMBOL_ACTION_SORT_BY_APPEARANCE:
 		{
 			gint idx = document_get_cur_idx();
 			if (DOC_IDX_VALID(idx))
-				doc_list[idx].has_tags = symbols_recreate_tag_list(idx, FALSE);
+				doc_list[idx].has_tags = symbols_recreate_tag_list(idx, SYMBOLS_SORT_BY_APPEARANCE);
 			break;
 		}
 		case SYMBOL_ACTION_HIDE:
 		{
 			prefs.sidebar_symbol_visible = FALSE;
-			ui_treeviews_show_hide(FALSE);
+			ui_sidebar_show_hide();
 			break;
 		}
 		case SYMBOL_ACTION_HIDE_ALL:
 		{
 			ui_prefs.sidebar_visible = FALSE;
-			ui_treeviews_show_hide(TRUE);
+			ui_sidebar_show_hide();
 			break;
 		}
 	}
@@ -588,34 +646,85 @@ static gboolean on_taglist_tree_selection_changed(GtkTreeSelection *selection)
 		{
 			gint idx = document_get_cur_idx();
 
-			navqueue_goto_line(idx, line);
+			navqueue_goto_line(idx, idx, line);
 		}
 	}
 	return FALSE;
 }
 
 
-static gboolean on_treeviews_button_press_event(GtkWidget *widget, GdkEventButton *event,
-																			gpointer user_data)
+static gboolean on_treeviews_key_press_event(GtkWidget *widget, GdkEventKey *event,
+											 gpointer user_data)
 {
-	if (event->button == 1 && GPOINTER_TO_INT(user_data) == TREEVIEW_SYMBOL)
-	{ // allow reclicking of taglist treeview item
+	if (event->keyval == GDK_Return ||
+		event->keyval == GDK_ISO_Enter ||
+		event->keyval == GDK_KP_Enter ||
+		event->keyval == GDK_space)
+	{
 		GtkTreeSelection *select = gtk_tree_view_get_selection(GTK_TREE_VIEW(widget));
-		// delay the query of selection state because this callback is executed before GTK
-		// changes the selection (g_signal_connect_after would be better but it doesn't work)
+		/* delay the query of selection state because this callback is executed before GTK
+		 * changes the selection (g_signal_connect_after would be better but it doesn't work) */
 		g_idle_add((GSourceFunc) on_taglist_tree_selection_changed, select);
 	}
+	return FALSE;
+}
 
-	if (event->button == 3)
-	{	// popupmenu to hide or clear the active treeview
+
+static gboolean on_treeviews_button_press_event(GtkWidget *widget, GdkEventButton *event,
+												gpointer user_data)
+{
+	if (event->type == GDK_2BUTTON_PRESS && GPOINTER_TO_INT(user_data) == TREEVIEW_SYMBOL)
+	{	/* double click on parent node(section) expands/collapses it */
+		GtkTreeModel *model;
+		GtkTreeSelection *selection;
+		GtkTreeIter iter;
+
+		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(widget));
+		if (gtk_tree_selection_get_selected(selection, &model, &iter))
+		{
+			if (gtk_tree_model_iter_has_child(model, &iter))
+			{
+				GtkTreePath *path = gtk_tree_model_get_path(model, &iter);
+
+				if (gtk_tree_view_row_expanded(GTK_TREE_VIEW(widget), path))
+					gtk_tree_view_collapse_row(GTK_TREE_VIEW(widget), path);
+				else
+					gtk_tree_view_expand_row(GTK_TREE_VIEW(widget), path, FALSE);
+
+				gtk_tree_path_free(path);
+				return TRUE;
+			}
+		}
+	}
+	else if (event->button == 1 && GPOINTER_TO_INT(user_data) == TREEVIEW_SYMBOL)
+	{	/* allow reclicking of taglist treeview item */
+		GtkTreeSelection *select = gtk_tree_view_get_selection(GTK_TREE_VIEW(widget));
+		/* delay the query of selection state because this callback is executed before GTK
+		 * changes the selection (g_signal_connect_after would be better but it doesn't work) */
+		g_idle_add((GSourceFunc) on_taglist_tree_selection_changed, select);
+	}
+	else if (event->button == 3)
+	{	/* popupmenu to hide or clear the active treeview */
 		if (GPOINTER_TO_INT(user_data) == TREEVIEW_OPENFILES)
+		{
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi.documents_show_documents),
+				prefs.sidebar_openfiles_visible);
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi.documents_show_symbols),
+				prefs.sidebar_symbol_visible);
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi.documents_fullpath),
+				prefs.sidebar_openfiles_fullpath);
 			gtk_menu_popup(GTK_MENU(tv.popup_openfiles), NULL, NULL, NULL, NULL,
 																event->button, event->time);
+		}
 		else if (GPOINTER_TO_INT(user_data) == TREEVIEW_SYMBOL)
 		{
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi.symbols_show_documents),
+				prefs.sidebar_openfiles_visible);
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mi.symbols_show_symbols),
+				prefs.sidebar_symbol_visible);
 			gtk_menu_popup(GTK_MENU(tv.popup_taglist), NULL, NULL, NULL, NULL,
 																event->button, event->time);
-			return TRUE;	// prevent selection changed signal for symbol tags
+			return TRUE;	/* prevent selection changed signal for symbol tags */
 		}
 	}
 	return FALSE;
