@@ -1,8 +1,8 @@
 /*
  *      ui_utils.c - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2006-2007 Enrico Tröger <enrico.troeger@uvena.de>
- *      Copyright 2006-2007 Nick Treleaven <nick.treleaven@btinternet.com>
+ *      Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2006-2008 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: ui_utils.c 1878 2007-09-12 16:25:19Z ntrel $
+ * $Id: ui_utils.c 2472 2008-04-11 15:39:44Z eht16 $
  */
 
 /*
@@ -52,14 +52,15 @@ UIWidgets		ui_widgets;
 
 static struct
 {
-	GtkWidget *document_buttons[38];	// widgets only sensitive when there is at least one document
+	/* widgets only sensitive when there is at least one document */
+	GtkWidget *document_buttons[45];
 }
 widgets;
 
 
 static gchar *menu_item_get_text(GtkMenuItem *menu_item);
 
-static void update_recent_menu();
+static void update_recent_menu(void);
 static void recent_file_loaded(const gchar *utf8_filename);
 static void
 recent_file_activate_cb                (GtkMenuItem     *menuitem,
@@ -74,6 +75,9 @@ static void set_statusbar(const gchar *text, gboolean allow_override)
 	GTimeVal timeval;
 	const gint GEANY_STATUS_TIMEOUT = 1;
 
+	if (! prefs.statusbar_visible)
+		return; /* just do nothing if statusbar is not visible */
+
 	g_get_current_time(&timeval);
 
 	if (! allow_override)
@@ -91,76 +95,102 @@ static void set_statusbar(const gchar *text, gboolean allow_override)
 }
 
 
-/* Display text on the statusbar or log it to the Status window if
- * prefs.suppress_status_messages is set */
-void ui_set_statusbar(const gchar *format, ...)
+/* Display text on the statusbar.
+ * log is whether the message should be recorded in the Status window. */
+void ui_set_statusbar(gboolean log, const gchar *format, ...)
 {
 	gchar string[512];
 	va_list args;
 
-	if (! prefs.statusbar_visible)
-		return; // just do nothing if statusbar is not visible
-
 	va_start(args, format);
 	g_vsnprintf(string, 512, format, args);
 	va_end(args);
 
-	if (prefs.suppress_status_messages)
-		msgwin_status_add("%s", string);
-	else
+	if (! prefs.suppress_status_messages)
 		set_statusbar(string, FALSE);
+
+	if (log || prefs.suppress_status_messages)
+		msgwin_status_add("%s", string);
 }
 
 
 /* updates the status bar document statistics */
 void ui_update_statusbar(gint idx, gint pos)
 {
-	gchar *text;
-	const gchar *cur_tag;
-	guint line, col;
-
 	if (! prefs.statusbar_visible)
-		return; // just do nothing if statusbar is not visible
+		return; /* just do nothing if statusbar is not visible */
 
 	if (idx == -1) idx = document_get_cur_idx();
 
 	if (DOC_IDX_VALID(idx))
 	{
-		utils_get_current_function(idx, &cur_tag);
+		static GString *stats_str = NULL;
+		const gchar sp[] = "      ";
+		guint line, col;
+		const gchar *cur_tag;
+		gchar *filetype_name;
+
+		/* workaround to make the name of filetype GEANY_FILETYPES_ALL translatable */
+		if (doc_list[idx].file_type == NULL || doc_list[idx].file_type->id == GEANY_FILETYPES_ALL)
+			filetype_name = _("None");
+		else
+			filetype_name = doc_list[idx].file_type->name;
+
+		if (stats_str == NULL)
+			stats_str = g_string_sized_new(120);
 
 		if (pos == -1) pos = sci_get_current_position(doc_list[idx].sci);
 		line = sci_get_line_from_position(doc_list[idx].sci, pos);
 
-		// Add temporary fix for sci infinite loop in Document::GetColumn(int)
-		// when current pos is beyond document end (can occur when removing
-		// blocks of selected lines especially esp. brace sections near end of file).
+		/* Add temporary fix for sci infinite loop in Document::GetColumn(int)
+		 * when current pos is beyond document end (can occur when removing
+		 * blocks of selected lines especially esp. brace sections near end of file). */
 		if (pos <= sci_get_length(doc_list[idx].sci))
 			col = sci_get_col_from_position(doc_list[idx].sci, pos);
 		else
 			col = 0;
 
-		/* Status bar statistics: col = column, sel = selection, RO = read-only,
-		 * OVR = overwrite/overtype, INS = insert, MOD = modified */
-		text = g_strdup_printf(_("line: %d\t col: %d\t sel: %d\t %s      %s      "
-			"mode: %s      encoding: %s %s      filetype: %s      scope: %s"),
+		/* Status bar statistics: col = column, sel = selection. */
+		g_string_printf(stats_str, _("line: %d\t col: %d\t sel: %d\t "),
 			(line + 1), col,
-			sci_get_selected_text_length(doc_list[idx].sci) - 1,
+			sci_get_selected_text_length(doc_list[idx].sci) - 1);
+
+		g_string_append(stats_str,
+			/* RO = read-only */
 			(doc_list[idx].readonly) ? _("RO ") :
-				(sci_get_overtype(doc_list[idx].sci) ? _("OVR") : _("INS")),
-			(doc_list[idx].changed) ? _("MOD") : "   ",
-			document_get_eol_mode(idx),
+				/* OVR = overwrite/overtype, INS = insert */
+				(sci_get_overtype(doc_list[idx].sci) ? _("OVR") : _("INS")));
+		g_string_append(stats_str, sp);
+		g_string_append(stats_str,
+			(doc_list[idx].use_tabs) ? _("TAB") : _("SP "));	/* SP = space */
+		g_string_append(stats_str, sp);
+		g_string_append_printf(stats_str, _("mode: %s"),
+			document_get_eol_mode(idx));
+		g_string_append(stats_str, sp);
+		g_string_append_printf(stats_str, _("encoding: %s %s"),
 			(doc_list[idx].encoding) ? doc_list[idx].encoding : _("unknown"),
 			(encodings_is_unicode_charset(doc_list[idx].encoding)) ?
-				((doc_list[idx].has_bom) ? _("(with BOM)") : "") : "",
-			(doc_list[idx].file_type) ? doc_list[idx].file_type->name :
-				filetypes[GEANY_FILETYPES_ALL]->name,
+				/* BOM = byte order mark */
+				((doc_list[idx].has_bom) ? _("(with BOM)") : "") : "");
+		g_string_append(stats_str, sp);
+		g_string_append_printf(stats_str, _("filetype: %s"), filetype_name);
+		g_string_append(stats_str, sp);
+		if (doc_list[idx].changed)
+		{
+			g_string_append(stats_str, _("MOD"));	/* MOD = modified */
+			g_string_append(stats_str, sp);
+		}
+
+		utils_get_current_function(idx, &cur_tag);
+		g_string_append_printf(stats_str, _("scope: %s"),
 			cur_tag);
-		set_statusbar(text, TRUE);	// can be overridden by status messages
-		g_free(text);
+
+		/* can be overridden by status messages */
+		set_statusbar(stats_str->str, TRUE);
 	}
-	else
+	else	/* no documents */
 	{
-		set_statusbar("", TRUE);	// can be overridden by status messages
+		set_statusbar("", TRUE);	/* can be overridden by status messages */
 	}
 }
 
@@ -215,7 +245,7 @@ void ui_set_editor_font(const gchar *font_name)
 	PangoFontDescription *font_desc;
 
 	g_return_if_fail(font_name != NULL);
-	// do nothing if font has not changed
+	/* do nothing if font has not changed */
 	if (prefs.editor_font != NULL)
 		if (strcmp(font_name, prefs.editor_font) == 0) return;
 
@@ -237,12 +267,12 @@ void ui_set_editor_font(const gchar *font_name)
 	}
 	pango_font_description_free(font_desc);
 
-	msgwin_status_add(_("Font updated (%s)."), prefs.editor_font);
+	ui_set_statusbar(TRUE, _("Font updated (%s)."), prefs.editor_font);
 	g_free(fname);
 }
 
 
-void ui_set_fullscreen()
+void ui_set_fullscreen(void)
 {
 	if (ui_prefs.fullscreen)
 	{
@@ -271,7 +301,7 @@ void ui_update_popup_reundo_items(gint idx)
 		enable_redo = document_can_redo(idx);
 	}
 
-	// index 0 is the popup menu, 1 is the menubar, 2 is the toolbar
+	/* index 0 is the popup menu, 1 is the menubar, 2 is the toolbar */
 	gtk_widget_set_sensitive(ui_widgets.undo_items[0], enable_undo);
 	gtk_widget_set_sensitive(ui_widgets.undo_items[1], enable_undo);
 	gtk_widget_set_sensitive(ui_widgets.undo_items[2], enable_undo);
@@ -341,10 +371,11 @@ void ui_update_insert_include_item(gint idx, gint item)
 }
 
 
-void ui_update_fold_items()
+void ui_update_fold_items(void)
 {
-	gtk_widget_set_sensitive(lookup_widget(app->window, "menu_fold_all1"), editor_prefs.folding);
-	gtk_widget_set_sensitive(lookup_widget(app->window, "menu_unfold_all1"), editor_prefs.folding);
+	ui_widget_show_hide(lookup_widget(app->window, "menu_fold_all1"), editor_prefs.folding);
+	ui_widget_show_hide(lookup_widget(app->window, "menu_unfold_all1"), editor_prefs.folding);
+	ui_widget_show_hide(lookup_widget(app->window, "separator22"), editor_prefs.folding);
 }
 
 
@@ -382,7 +413,7 @@ static void insert_include_items(GtkMenu *me, GtkMenu *mp, gchar **includes, gch
 }
 
 
-void ui_create_insert_menu_items()
+void ui_create_insert_menu_items(void)
 {
 	GtkMenu *menu_edit = GTK_MENU(lookup_widget(app->window, "insert_include2_menu"));
 	GtkMenu *menu_popup = GTK_MENU(lookup_widget(app->popup_menu, "insert_include1_menu"));
@@ -437,19 +468,19 @@ static void insert_date_items(GtkMenu *me, GtkMenu *mp, gchar *label)
 {
 	GtkWidget *item;
 
-	item = gtk_menu_item_new_with_label(label);
+	item = gtk_menu_item_new_with_mnemonic(label);
 	gtk_container_add(GTK_CONTAINER(me), item);
 	gtk_widget_show(item);
 	g_signal_connect((gpointer) item, "activate", G_CALLBACK(on_menu_insert_date_activate), label);
 
-	item = gtk_menu_item_new_with_label(label);
+	item = gtk_menu_item_new_with_mnemonic(label);
 	gtk_container_add(GTK_CONTAINER(mp), item);
 	gtk_widget_show(item);
 	g_signal_connect((gpointer) item, "activate", G_CALLBACK(on_insert_date_activate), label);
 }
 
 
-void ui_create_insert_date_menu_items()
+void ui_create_insert_date_menu_items(void)
 {
 	GtkMenu *menu_edit = GTK_MENU(lookup_widget(app->window, "insert_date1_menu"));
 	GtkMenu *menu_popup = GTK_MENU(lookup_widget(app->popup_menu, "insert_date2_menu"));
@@ -478,8 +509,8 @@ void ui_create_insert_date_menu_items()
 	gtk_container_add(GTK_CONTAINER(menu_popup), item);
 	gtk_widget_show(item);
 
-	str = _("Use Custom Date Format");
-	item = gtk_menu_item_new_with_label(str);
+	str = _("_Use Custom Date Format");
+	item = gtk_menu_item_new_with_mnemonic(str);
 	gtk_container_add(GTK_CONTAINER(menu_edit), item);
 	gtk_widget_show(item);
 	g_signal_connect((gpointer) item, "activate", G_CALLBACK(on_menu_insert_date_activate),
@@ -487,7 +518,7 @@ void ui_create_insert_date_menu_items()
 	g_object_set_data_full(G_OBJECT(app->window), "insert_date_custom1", gtk_widget_ref(item),
 													(GDestroyNotify)gtk_widget_unref);
 
-	item = gtk_menu_item_new_with_label(str);
+	item = gtk_menu_item_new_with_mnemonic(str);
 	gtk_container_add(GTK_CONTAINER(menu_popup), item);
 	gtk_widget_show(item);
 	g_signal_connect((gpointer) item, "activate", G_CALLBACK(on_insert_date_activate),
@@ -495,7 +526,7 @@ void ui_create_insert_date_menu_items()
 	g_object_set_data_full(G_OBJECT(app->popup_menu), "insert_date_custom2", gtk_widget_ref(item),
 													(GDestroyNotify)gtk_widget_unref);
 
-	insert_date_items(menu_edit, menu_popup, _("Set Custom Date Format"));
+	insert_date_items(menu_edit, menu_popup, _("_Set Custom Date Format"));
 }
 
 
@@ -507,21 +538,24 @@ void ui_save_buttons_toggle(gboolean enable)
 	gtk_widget_set_sensitive(ui_widgets.save_buttons[0], enable);
 	gtk_widget_set_sensitive(ui_widgets.save_buttons[1], enable);
 
-	// save all menu item and tool button
-	for (i = 0; i < (guint) gtk_notebook_get_n_pages(GTK_NOTEBOOK(app->notebook)); i++)
+	/* save all menu item and tool button */
+	for (i = 0; i < doc_array->len; i++)
 	{
-		// count the amount of files where changes were made and if there are some,
-		// we need the save all button / item
-		if (! dirty_tabs && doc_list[i].is_valid && doc_list[i].changed)
+		/* check whether there are files where changes were made and if there are some,
+		 * we need the save all button / item */
+		if (doc_list[i].is_valid && doc_list[i].changed)
+		{
 			dirty_tabs = TRUE;
+			break;
+		}
 	}
 
-	gtk_widget_set_sensitive(ui_widgets.save_buttons[2], (dirty_tabs > 0) ? TRUE : FALSE);
-	gtk_widget_set_sensitive(ui_widgets.save_buttons[3], (dirty_tabs > 0) ? TRUE : FALSE);
+	gtk_widget_set_sensitive(ui_widgets.save_buttons[2], dirty_tabs);
+	gtk_widget_set_sensitive(ui_widgets.save_buttons[3], dirty_tabs);
 }
 
 
-static void init_document_widgets()
+static void init_document_widgets(void)
 {
 	/* Cache the document-sensitive widgets so we don't have to keep looking them up
 	 * when using ui_document_buttons_update(). */
@@ -535,38 +569,45 @@ static void init_document_widgets()
 	widgets.document_buttons[7] = lookup_widget(app->window, "menu_close_all1");
 	widgets.document_buttons[8] = lookup_widget(app->window, "menu_save_all1");
 	widgets.document_buttons[9] = lookup_widget(app->window, "toolbutton22");
-	widgets.document_buttons[10] = lookup_widget(app->window, "toolbutton13"); // compile_button
+	widgets.document_buttons[10] = lookup_widget(app->window, "toolbutton13"); /* compile_button */
 	widgets.document_buttons[11] = lookup_widget(app->window, "menu_save_as1");
 	widgets.document_buttons[12] = lookup_widget(app->window, "toolbutton23");
 	widgets.document_buttons[13] = lookup_widget(app->window, "menu_count_words1");
 	widgets.document_buttons[14] = lookup_widget(app->window, "menu_build1");
 	widgets.document_buttons[15] = lookup_widget(app->window, "add_comments1");
-	widgets.document_buttons[16] = lookup_widget(app->window, "search1");
-	widgets.document_buttons[17] = lookup_widget(app->window, "menu_paste1");
-	widgets.document_buttons[18] = lookup_widget(app->window, "menu_undo2");
-	widgets.document_buttons[19] = lookup_widget(app->window, "preferences2");
-	widgets.document_buttons[20] = lookup_widget(app->window, "menu_reload1");
-	widgets.document_buttons[21] = lookup_widget(app->window, "menu_document1");
-	widgets.document_buttons[22] = lookup_widget(app->window, "menu_markers_margin1");
-	widgets.document_buttons[23] = lookup_widget(app->window, "menu_linenumber_margin1");
-	widgets.document_buttons[24] = lookup_widget(app->window, "menu_choose_color1");
-	widgets.document_buttons[25] = lookup_widget(app->window, "menu_zoom_in1");
-	widgets.document_buttons[26] = lookup_widget(app->window, "menu_zoom_out1");
-	widgets.document_buttons[27] = lookup_widget(app->window, "normal_size1");
-	widgets.document_buttons[28] = lookup_widget(app->window, "toolbutton24");
-	widgets.document_buttons[29] = lookup_widget(app->window, "toolbutton25");
-	widgets.document_buttons[30] = lookup_widget(app->window, "entry_goto_line");
-	widgets.document_buttons[31] = lookup_widget(app->window, "treeview6");
-	widgets.document_buttons[32] = lookup_widget(app->window, "print1");
-	widgets.document_buttons[33] = lookup_widget(app->window, "menu_reload_as1");
-	widgets.document_buttons[34] = lookup_widget(app->window, "menu_select_all1");
-	widgets.document_buttons[35] = lookup_widget(app->window, "insert_date1");
-	widgets.document_buttons[36] = lookup_widget(app->window, "menu_format1");
-	widgets.document_buttons[37] = lookup_widget(app->window, "menu_open_selected_file1");
+	widgets.document_buttons[16] = lookup_widget(app->window, "menu_paste1");
+	widgets.document_buttons[17] = lookup_widget(app->window, "menu_undo2");
+	widgets.document_buttons[18] = lookup_widget(app->window, "preferences2");
+	widgets.document_buttons[19] = lookup_widget(app->window, "menu_reload1");
+	widgets.document_buttons[20] = lookup_widget(app->window, "menu_document1");
+	widgets.document_buttons[21] = lookup_widget(app->window, "menu_markers_margin1");
+	widgets.document_buttons[22] = lookup_widget(app->window, "menu_linenumber_margin1");
+	widgets.document_buttons[23] = lookup_widget(app->window, "menu_choose_color1");
+	widgets.document_buttons[24] = lookup_widget(app->window, "menu_zoom_in1");
+	widgets.document_buttons[25] = lookup_widget(app->window, "menu_zoom_out1");
+	widgets.document_buttons[26] = lookup_widget(app->window, "normal_size1");
+	widgets.document_buttons[27] = lookup_widget(app->window, "toolbutton24");
+	widgets.document_buttons[28] = lookup_widget(app->window, "toolbutton25");
+	widgets.document_buttons[29] = lookup_widget(app->window, "entry_goto_line");
+	widgets.document_buttons[30] = lookup_widget(app->window, "treeview6");
+	widgets.document_buttons[31] = lookup_widget(app->window, "print1");
+	widgets.document_buttons[32] = lookup_widget(app->window, "menu_reload_as1");
+	widgets.document_buttons[33] = lookup_widget(app->window, "menu_select_all1");
+	widgets.document_buttons[34] = lookup_widget(app->window, "insert_date1");
+	widgets.document_buttons[35] = lookup_widget(app->window, "menu_format1");
+	widgets.document_buttons[36] = lookup_widget(app->window, "menu_open_selected_file1");
+	widgets.document_buttons[37] = lookup_widget(app->window, "page_setup1");
+	widgets.document_buttons[38] = lookup_widget(app->window, "find1");
+	widgets.document_buttons[39] = lookup_widget(app->window, "find_next1");
+	widgets.document_buttons[40] = lookup_widget(app->window, "find_previous1");
+	widgets.document_buttons[41] = lookup_widget(app->window, "replace1");
+	widgets.document_buttons[42] = lookup_widget(app->window, "find_nextsel1");
+	widgets.document_buttons[43] = lookup_widget(app->window, "find_prevsel1");
+	widgets.document_buttons[44] = lookup_widget(app->window, "go_to_line1");
 }
 
 
-void ui_document_buttons_update()
+void ui_document_buttons_update(void)
 {
 	guint i;
 	gboolean enable = gtk_notebook_get_n_pages(GTK_NOTEBOOK(app->notebook)) ? TRUE : FALSE;
@@ -593,15 +634,14 @@ void ui_widget_show_hide(GtkWidget *widget, gboolean show)
 }
 
 
-void ui_treeviews_show_hide(G_GNUC_UNUSED gboolean force)
+void ui_sidebar_show_hide(void)
 {
 	GtkWidget *widget;
 
-/*	geany_debug("\nSidebar: %s\nSymbol: %s\nFiles: %s", ui_btoa(ui_prefs.sidebar_visible),
-					ui_btoa(prefs.sidebar_symbol_visible), ui_btoa(prefs.sidebar_openfiles_visible));
-*/
-
-	if (! prefs.sidebar_openfiles_visible && ! prefs.sidebar_symbol_visible)
+	/* check that there are no other notebook pages before hiding the sidebar completely
+	 * other pages could be e.g. the file browser plugin */
+	if (! prefs.sidebar_openfiles_visible && ! prefs.sidebar_symbol_visible &&
+		gtk_notebook_get_n_pages(GTK_NOTEBOOK(app->treeview_notebook)) <= 2)
 	{
 		ui_prefs.sidebar_visible = FALSE;
 	}
@@ -626,7 +666,7 @@ void ui_treeviews_show_hide(G_GNUC_UNUSED gboolean force)
 void ui_document_show_hide(gint idx)
 {
 	gchar *widget_name;
-	GtkWidget *check_indent;
+	GtkWidget *item;
 
 	if (idx == -1)
 		idx = document_get_cur_idx();
@@ -636,20 +676,27 @@ void ui_document_show_hide(gint idx)
 
 	app->ignore_callback = TRUE;
 
-	check_indent = lookup_widget(app->window, "menu_use_auto_indentation1");
-
 	gtk_check_menu_item_set_active(
 			GTK_CHECK_MENU_ITEM(lookup_widget(app->window, "menu_line_breaking1")),
 			doc_list[idx].line_wrapping);
-	gtk_check_menu_item_set_active(
-			GTK_CHECK_MENU_ITEM(check_indent),
-			doc_list[idx].auto_indent);
+
+	item = lookup_widget(app->window, "menu_use_auto_indentation1");
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item),
+		doc_list[idx].auto_indent);
+	gtk_widget_set_sensitive(item, editor_prefs.indent_mode != INDENT_NONE);
+
+	item = lookup_widget(app->window,
+		doc_list[idx].use_tabs ? "tabs1" : "spaces1");
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), TRUE);
+
 	gtk_check_menu_item_set_active(
 			GTK_CHECK_MENU_ITEM(lookup_widget(app->window, "set_file_readonly1")),
 			doc_list[idx].readonly);
-	gtk_check_menu_item_set_active(
-			GTK_CHECK_MENU_ITEM(lookup_widget(app->window, "menu_write_unicode_bom1")),
-			doc_list[idx].has_bom);
+
+	item = lookup_widget(app->window, "menu_write_unicode_bom1");
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item),
+		doc_list[idx].has_bom);
+	gtk_widget_set_sensitive(item, encodings_is_unicode_charset(doc_list[idx].encoding));
 
 	switch (sci_get_eol_mode(doc_list[idx].sci))
 	{
@@ -657,13 +704,8 @@ void ui_document_show_hide(gint idx)
 		case SC_EOL_LF: widget_name = "lf"; break;
 		default: widget_name = "crlf"; break;
 	}
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(lookup_widget(app->window, widget_name)),
-																					TRUE);
-
-	gtk_widget_set_sensitive(check_indent, editor_prefs.indent_mode != INDENT_NONE);
-
-	gtk_widget_set_sensitive(lookup_widget(app->window, "menu_write_unicode_bom1"),
-			encodings_is_unicode_charset(doc_list[idx].encoding));
+	gtk_check_menu_item_set_active(
+		GTK_CHECK_MENU_ITEM(lookup_widget(app->window, widget_name)), TRUE);
 
 	encodings_select_radio_item(doc_list[idx].encoding);
 	filetypes_select_radio_item(doc_list[idx].file_type);
@@ -678,11 +720,11 @@ void ui_update_toolbar_icons(GtkIconSize size)
 	GtkWidget *widget = NULL;
 	GtkWidget *oldwidget = NULL;
 
-	// destroy old widget
+	/* destroy old widget */
 	widget = lookup_widget(app->window, "toolbutton22");
 	oldwidget = gtk_tool_button_get_icon_widget(GTK_TOOL_BUTTON(widget));
 	if (oldwidget && GTK_IS_WIDGET(oldwidget)) gtk_widget_destroy(oldwidget);
-	// create new widget
+	/* create new widget */
 	button_image = ui_new_image_from_inline(GEANY_IMAGE_SAVE_ALL, FALSE);
 	gtk_widget_show(button_image);
 	gtk_tool_button_set_icon_widget(GTK_TOOL_BUTTON(widget), button_image);
@@ -691,22 +733,22 @@ void ui_update_toolbar_icons(GtkIconSize size)
 }
 
 
-void ui_update_toolbar_items()
+void ui_update_toolbar_items(void)
 {
-	// show toolbar
+	/* show toolbar */
 	GtkWidget *widget = lookup_widget(app->window, "menu_show_toolbar1");
 	if (prefs.toolbar_visible && ! gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget)))
-	{
-		prefs.toolbar_visible = ! prefs.toolbar_visible;	// will be changed by the toggled callback
+	{	/* will be changed by the toggled callback */
+		prefs.toolbar_visible = ! prefs.toolbar_visible;
 		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widget), TRUE);
 	}
 	else if (! prefs.toolbar_visible && gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget)))
-	{
-		prefs.toolbar_visible = ! prefs.toolbar_visible;	// will be changed by the toggled callback
+	{	/* will be changed by the toggled callback */
+		prefs.toolbar_visible = ! prefs.toolbar_visible;
 		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widget), FALSE);
 	}
 
-	// fileops
+	/* fileops */
 	ui_widget_show_hide(lookup_widget(app->window, "menutoolbutton1"), prefs.toolbar_show_fileops);
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton9"), prefs.toolbar_show_fileops);
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton10"), prefs.toolbar_show_fileops);
@@ -715,40 +757,44 @@ void ui_update_toolbar_items()
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton15"), prefs.toolbar_show_fileops);
 	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem7"), prefs.toolbar_show_fileops);
 	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem2"), prefs.toolbar_show_fileops);
-	// search
+	/* search */
 	ui_widget_show_hide(lookup_widget(app->window, "entry1"), prefs.toolbar_show_search);
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton18"), prefs.toolbar_show_search);
 	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem5"), prefs.toolbar_show_search);
-	// goto line
+	/* goto line */
 	ui_widget_show_hide(lookup_widget(app->window, "entry_goto_line"), prefs.toolbar_show_goto);
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton25"), prefs.toolbar_show_goto);
 	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem8"), prefs.toolbar_show_goto);
-	// compile
+	/* compile */
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton13"), prefs.toolbar_show_compile);
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton26"), prefs.toolbar_show_compile);
 	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem6"), prefs.toolbar_show_compile);
-	// colour
+	/* colour */
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton24"), prefs.toolbar_show_colour);
 	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem3"), prefs.toolbar_show_colour);
-	// zoom
+	/* zoom */
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton20"), prefs.toolbar_show_zoom);
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton21"), prefs.toolbar_show_zoom);
 	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem4"), prefs.toolbar_show_zoom);
-	// undo
+	/* indent */
+	ui_widget_show_hide(lookup_widget(app->window, "toolbutton_indent_dec"), prefs.toolbar_show_indent);
+	ui_widget_show_hide(lookup_widget(app->window, "toolbutton_indent_inc"), prefs.toolbar_show_indent);
+	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem11"), prefs.toolbar_show_indent);
+	/* undo */
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton_undo"), prefs.toolbar_show_undo);
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton_redo"), prefs.toolbar_show_undo);
 	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem9"), prefs.toolbar_show_undo);
-	// navigation
+	/* navigation */
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton_back"), prefs.toolbar_show_navigation);
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton_forward"), prefs.toolbar_show_navigation);
 	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem10"), prefs.toolbar_show_navigation);
-	// quit
+	/* quit */
 	ui_widget_show_hide(lookup_widget(app->window, "toolbutton19"), prefs.toolbar_show_quit);
 	ui_widget_show_hide(lookup_widget(app->window, "separatortoolitem8"), prefs.toolbar_show_quit);
 }
 
 
-// Note: remember to unref the pixbuf once an image or window has added a reference.
+/* Note: remember to unref the pixbuf once an image or window has added a reference. */
 GdkPixbuf *ui_new_pixbuf_from_inline(gint img, gboolean small_img)
 {
 	switch(img)
@@ -784,7 +830,7 @@ GdkPixbuf *ui_new_pixbuf_from_inline(gint img, gboolean small_img)
 		default: return NULL;
 	}
 
-	//return gtk_image_new_from_pixbuf(pixbuf);
+	/*return gtk_image_new_from_pixbuf(pixbuf);*/
 }
 
 
@@ -795,12 +841,12 @@ GtkWidget *ui_new_image_from_inline(gint img, gboolean small_img)
 
 	pb = ui_new_pixbuf_from_inline(img, small_img);
 	wid = gtk_image_new_from_pixbuf(pb);
-	g_object_unref(pb);	// the image doesn't adopt our reference, so remove our ref.
+	g_object_unref(pb);	/* the image doesn't adopt our reference, so remove our ref. */
 	return wid;
 }
 
 
-void ui_create_recent_menu()
+void ui_create_recent_menu(void)
 {
 	GtkWidget *tmp;
 	guint i;
@@ -815,13 +861,13 @@ void ui_create_recent_menu()
 	for (i = 0; i < MIN(prefs.mru_length, g_queue_get_length(ui_prefs.recent_queue)); i++)
 	{
 		filename = g_queue_peek_nth(ui_prefs.recent_queue, i);
-		// create menu item for the recent files menu in the menu bar
+		/* create menu item for the recent files menu in the menu bar */
 		tmp = gtk_menu_item_new_with_label(filename);
 		gtk_widget_show(tmp);
 		gtk_menu_shell_append(GTK_MENU_SHELL(ui_widgets.recent_files_menubar), tmp);
 		g_signal_connect((gpointer) tmp, "activate",
 					G_CALLBACK(recent_file_activate_cb), NULL);
-		// create menu item for the recent files menu in the toolbar bar
+		/* create menu item for the recent files menu in the toolbar bar */
 		tmp = gtk_menu_item_new_with_label(filename);
 		gtk_widget_show(tmp);
 		gtk_menu_shell_append(GTK_MENU_SHELL(ui_widgets.recent_files_toolbar), tmp);
@@ -850,6 +896,15 @@ void ui_add_recent_file(const gchar *utf8_filename)
 {
 	if (g_queue_find_custom(ui_prefs.recent_queue, utf8_filename, (GCompareFunc) strcmp) == NULL)
 	{
+#if GTK_CHECK_VERSION(2, 10, 0)
+		GtkRecentManager *manager = gtk_recent_manager_get_default();
+		gchar *uri = g_filename_to_uri(utf8_filename, NULL, NULL);
+		if (uri != NULL)
+		{
+			gtk_recent_manager_add_item(manager, uri);
+			g_free(uri);
+		}
+#endif
 		g_queue_push_head(ui_prefs.recent_queue, g_strdup(utf8_filename));
 		if (g_queue_get_length(ui_prefs.recent_queue) > prefs.mru_length)
 		{
@@ -857,11 +912,11 @@ void ui_add_recent_file(const gchar *utf8_filename)
 		}
 		update_recent_menu();
 	}
-	else recent_file_loaded(utf8_filename);	// filename already in recent list
+	else recent_file_loaded(utf8_filename);	/* filename already in recent list */
 }
 
 
-// Returns: newly allocated string with the UTF-8 menu text.
+/* Returns: newly allocated string with the UTF-8 menu text. */
 static gchar *menu_item_get_text(GtkMenuItem *menu_item)
 {
 	const gchar *text = NULL;
@@ -873,7 +928,7 @@ static gchar *menu_item_get_text(GtkMenuItem *menu_item)
 		if (GTK_IS_LABEL(child))
 			text = gtk_label_get_text(GTK_LABEL(child));
 	}
-	// GTK owns text so it's much safer to return a copy of it in case the memory is reallocated
+	/* GTK owns text so it's much safer to return a copy of it in case the memory is reallocated */
 	return g_strdup(text);
 }
 
@@ -899,7 +954,7 @@ static void recent_file_loaded(const gchar *utf8_filename)
 	void *data;
 	GtkWidget *tmp;
 
-	// first reorder the queue
+	/* first reorder the queue */
 	item = g_queue_find_custom(ui_prefs.recent_queue, utf8_filename, (GCompareFunc) strcmp);
 	g_return_if_fail(item != NULL);
 
@@ -907,7 +962,7 @@ static void recent_file_loaded(const gchar *utf8_filename)
 	g_queue_remove(ui_prefs.recent_queue, data);
 	g_queue_push_head(ui_prefs.recent_queue, data);
 
-	// remove the old menuitem for the filename
+	/* remove the old menuitem for the filename */
 	children = gtk_container_get_children(GTK_CONTAINER(ui_widgets.recent_files_menubar));
 	item = g_list_find_custom(children, utf8_filename, (GCompareFunc) find_recent_file_item);
 	if (item != NULL) gtk_widget_destroy(GTK_WIDGET(item->data));
@@ -916,13 +971,14 @@ static void recent_file_loaded(const gchar *utf8_filename)
 	item = g_list_find_custom(children, utf8_filename, (GCompareFunc) find_recent_file_item);
 	if (item != NULL) gtk_widget_destroy(GTK_WIDGET(item->data));
 
-	// now prepend a new menuitem for the filename, first for the recent files menu in the menu bar
+	/* now prepend a new menuitem for the filename,
+	 * first for the recent files menu in the menu bar */
 	tmp = gtk_menu_item_new_with_label(utf8_filename);
 	gtk_widget_show(tmp);
 	gtk_menu_shell_prepend(GTK_MENU_SHELL(ui_widgets.recent_files_menubar), tmp);
 	g_signal_connect((gpointer) tmp, "activate",
 				G_CALLBACK(recent_file_activate_cb), NULL);
-	// then for the recent files menu in the tool bar
+	/* then for the recent files menu in the tool bar */
 	tmp = gtk_menu_item_new_with_label(utf8_filename);
 	gtk_widget_show(tmp);
 	gtk_menu_shell_prepend(GTK_MENU_SHELL(ui_widgets.recent_files_toolbar), tmp);
@@ -931,7 +987,7 @@ static void recent_file_loaded(const gchar *utf8_filename)
 }
 
 
-static void update_recent_menu()
+static void update_recent_menu(void)
 {
 	GtkWidget *tmp;
 	static GtkMenuToolButton *menu = NULL;
@@ -946,7 +1002,7 @@ static void update_recent_menu()
 		gtk_menu_tool_button_set_menu(menu, ui_widgets.recent_files_toolbar);
 	}
 
-	// clean the MRU list before adding an item (menubar)
+	/* clean the MRU list before adding an item (menubar) */
 	children = gtk_container_get_children(GTK_CONTAINER(ui_widgets.recent_files_menubar));
 	if (g_list_length(children) > prefs.mru_length - 1)
 	{
@@ -958,7 +1014,7 @@ static void update_recent_menu()
 		}
 	}
 
-	// clean the MRU list before adding an item (toolbar)
+	/* clean the MRU list before adding an item (toolbar) */
 	children = gtk_container_get_children(GTK_CONTAINER(ui_widgets.recent_files_toolbar));
 	if (g_list_length(children) > prefs.mru_length - 1)
 	{
@@ -971,13 +1027,13 @@ static void update_recent_menu()
 	}
 
 	filename = g_queue_peek_head(ui_prefs.recent_queue);
-	// create item for the menu bar menu
+	/* create item for the menu bar menu */
 	tmp = gtk_menu_item_new_with_label(filename);
 	gtk_widget_show(tmp);
 	gtk_menu_shell_prepend(GTK_MENU_SHELL(ui_widgets.recent_files_menubar), tmp);
 	g_signal_connect((gpointer) tmp, "activate",
 				G_CALLBACK(recent_file_activate_cb), NULL);
-	// create item for the tool bar menu
+	/* create item for the tool bar menu */
 	tmp = gtk_menu_item_new_with_label(filename);
 	gtk_widget_show(tmp);
 	gtk_menu_shell_prepend(GTK_MENU_SHELL(ui_widgets.recent_files_toolbar), tmp);
@@ -986,7 +1042,7 @@ static void update_recent_menu()
 }
 
 
-void ui_show_markers_margin()
+void ui_show_markers_margin(void)
 {
 	gint i, idx, max = gtk_notebook_get_n_pages(GTK_NOTEBOOK(app->notebook));
 
@@ -998,7 +1054,7 @@ void ui_show_markers_margin()
 }
 
 
-void ui_show_linenumber_margin()
+void ui_show_linenumber_margin(void)
 {
 	gint i, idx, max = gtk_notebook_get_n_pages(GTK_NOTEBOOK(app->notebook));
 
@@ -1043,7 +1099,7 @@ const gint BUTTON_BOX_BORDER = 5;
  * Returns: the vbox. */
 GtkWidget *ui_dialog_vbox_new(GtkDialog *dialog)
 {
-	GtkWidget *vbox = gtk_vbox_new(FALSE, 12);	// need child vbox to set a separate border.
+	GtkWidget *vbox = gtk_vbox_new(FALSE, 12);	/* need child vbox to set a separate border. */
 
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), BUTTON_BOX_BORDER);
 	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), vbox);
@@ -1119,11 +1175,11 @@ void ui_combo_box_add_to_history(GtkComboBox *combo, const gchar *text)
 		equal = utils_str_equal(combo_text, text);
 		g_free(combo_text);
 	}
-	if (equal) return;	// don't prepend duplicate
+	if (equal) return;	/* don't prepend duplicate */
 
 	gtk_combo_box_prepend_text(combo, text);
 
-	// limit history
+	/* limit history */
 	path = gtk_tree_path_new_from_indices(history_len, -1);
 	if (gtk_tree_model_get_iter(model, &iter, path))
 	{
@@ -1139,7 +1195,7 @@ void ui_update_tab_status(gint idx)
 {
 	GdkColor *color = document_get_status(idx);
 
-	// NULL color will reset to default
+	/* NULL color will reset to default */
 	gtk_widget_modify_fg(doc_list[idx].tab_label, GTK_STATE_NORMAL, color);
 	gtk_widget_modify_fg(doc_list[idx].tab_label, GTK_STATE_ACTIVE, color);
 	gtk_widget_modify_fg(doc_list[idx].tabmenu_label, GTK_STATE_NORMAL, color);
@@ -1159,25 +1215,25 @@ gboolean ui_tree_view_find_next(GtkTreeView *treeview, TVMatchCallback cb)
 	treesel = gtk_tree_view_get_selection(treeview);
 	if (gtk_tree_selection_get_selected(treesel, &model, &iter))
 	{
-		// get the next selected item
+		/* get the next selected item */
 		if (! gtk_tree_model_iter_next(model, &iter))
-			return FALSE;	// no more items
+			return FALSE;	/* no more items */
 	}
-	else	// no selection
+	else	/* no selection */
 	{
 		if (! gtk_tree_model_get_iter_first(model, &iter))
-			return TRUE;	// no items
+			return TRUE;	/* no items */
 	}
 	while (TRUE)
 	{
 		gtk_tree_selection_select_iter(treesel, &iter);
 		if (cb())
-			break;	// found next message
+			break;	/* found next message */
 
 		if (! gtk_tree_model_iter_next(model, &iter))
-			return FALSE;	// no more items
+			return FALSE;	/* no more items */
 	}
-	// scroll item in view
+	/* scroll item in view */
 	if (ui_prefs.msgwindow_visible)
 	{
 		GtkTreePath *path = gtk_tree_model_get_path(
@@ -1211,9 +1267,9 @@ GtkWidget *ui_path_box_new(const gchar *title, GtkFileChooserAction action, GtkE
 	hbox = gtk_hbox_new(FALSE, 6);
 	path_entry = GTK_WIDGET(entry);
 
-	// prevent path_entry being vertically stretched to the height of dirbtn
+	/* prevent path_entry being vertically stretched to the height of dirbtn */
 	vbox = gtk_vbox_new(FALSE, 0);
-	if (gtk_widget_get_parent(path_entry))	// entry->parent may be a GtkComboBoxEntry
+	if (gtk_widget_get_parent(path_entry))	/* entry->parent may be a GtkComboBoxEntry */
 	{
 		GtkWidget *parent = gtk_widget_get_parent(path_entry);
 
@@ -1299,7 +1355,7 @@ static void ui_path_box_open_clicked(GtkButton *button, gpointer user_data)
 	const gchar *title = g_object_get_data(G_OBJECT(path_box), "title");
 	gchar *utf8_path;
 
-	// TODO: extend for other actions
+	/* TODO: extend for other actions */
 	g_return_if_fail(action == GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 
 	if (title == NULL)
@@ -1307,7 +1363,7 @@ static void ui_path_box_open_clicked(GtkButton *button, gpointer user_data)
 			_("Select Folder") : _("Select File");
 
 #ifdef G_OS_WIN32
-	utf8_path = win32_show_project_folder_dialog(title,
+	utf8_path = win32_show_project_folder_dialog(ui_widgets.prefs_dialog, title,
 						gtk_entry_get_text(GTK_ENTRY(entry)));
 #else
 	utf8_path = run_file_chooser(title, action, gtk_entry_get_text(GTK_ENTRY(entry)));
@@ -1323,7 +1379,7 @@ static void ui_path_box_open_clicked(GtkButton *button, gpointer user_data)
 
 void ui_statusbar_showhide(gboolean state)
 {
-	// handle statusbar visibility
+	/* handle statusbar visibility */
 	if (state)
 	{
 		gtk_widget_show(app->statusbar);
@@ -1355,7 +1411,7 @@ void ui_table_add_row(GtkTable *table, gint row, ...)
 }
 
 
-void ui_init()
+void ui_init(void)
 {
 	init_document_widgets();
 }
