@@ -1,8 +1,8 @@
 /*
  *      vte.h - this file is part of Geany, a fast and lightweight IDE
  *
- *      Copyright 2005-2007 Enrico Tröger <enrico.troeger@uvena.de>
- *      Copyright 2006-2007 Nick Treleaven <nick.treleaven@btinternet.com>
+ *      Copyright 2005-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *      Copyright 2006-2008 Nick Treleaven <<nick(dot)treleaven(at)btinternet(dot)com>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: vte.h 1927 2007-10-02 16:20:44Z ntrel $
+ * $Id: vte.h 2287 2008-02-27 13:17:29Z eht16 $
  */
 
 
@@ -28,8 +28,9 @@
 #ifdef HAVE_VTE
 
 /* include stdlib.h AND unistd.h, because on GNU/Linux pid_t seems to be
- * in stdlib.h, on FreeBSD in unistd.h */
+ * in stdlib.h, on FreeBSD in unistd.h, sys/types.h is needed for C89 */
 #include <stdlib.h>
+#include <sys/types.h>
 #include <unistd.h>
 
 
@@ -54,6 +55,7 @@ typedef struct
 	gboolean ignore_menu_bar_accel;
 	gboolean follow_path;
 	gboolean run_in_vte;
+	gboolean skip_run_script;
 	gboolean enable_bash_keys;
 	gint scrollback_lines;
 	gchar *emulation;
@@ -62,7 +64,7 @@ typedef struct
 	GdkColor *colour_fore;
 	GdkColor *colour_back;
 } VteConfig;
-VteConfig *vc;
+extern VteConfig *vc;
 
 
 void vte_init(void);
@@ -71,13 +73,13 @@ void vte_close(void);
 
 void vte_apply_user_settings(void);
 
-void vte_send_cmd(const gchar *cmd);
+gboolean vte_send_cmd(const gchar *cmd);
 
 const gchar* vte_get_working_directory(void);
 
 void vte_cwd(const gchar *filename, gboolean force);
 
-void vte_append_preferences_tab();
+void vte_append_preferences_tab(void);
 
 /*
 void vte_drag_data_received(GtkWidget *widget, GdkDragContext  *drag_context, gint x, gint y,
@@ -117,8 +119,6 @@ struct VteFunctions
 	void (*vte_terminal_set_word_chars) (VteTerminal *terminal, const char *spec);
 	void (*vte_terminal_set_mouse_autohide) (VteTerminal *terminal, gboolean setting);
 	void (*vte_terminal_reset) (VteTerminal *terminal, gboolean full, gboolean clear_history);
-	void (*vte_terminal_set_encoding) (VteTerminal *terminal, const char *codeset);
-	void (*vte_terminal_set_cursor_blinks) (VteTerminal *terminal, gboolean blink);
 	GtkType (*vte_terminal_get_type) (void);
 	void (*vte_terminal_set_scroll_on_output) (VteTerminal *terminal, gboolean scroll);
 	void (*vte_terminal_set_scroll_on_keystroke) (VteTerminal *terminal, gboolean scroll);
