@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: win32.h 2150 2008-01-06 18:11:57Z eht16 $
+ *  $Id: win32.h 2416 2008-03-26 18:53:59Z eht16 $
  */
 
 
@@ -33,23 +33,16 @@ void win32_show_font_dialog(void);
 
 void win32_show_color_dialog(const gchar *colour);
 
-/* Creates a native Windows message box of the given type and returns always TRUE
- * or FALSE representing th pressed Yes or No button.
- * If type is not GTK_MESSAGE_QUESTION, it returns always TRUE. */
 gboolean win32_message_dialog(GtkWidget *parent, GtkMessageType type, const gchar *msg);
 
-/* Special dialog to ask for an action when closing an unsaved file */
 gint win32_message_dialog_unsaved(const gchar *msg);
 
-/* Just a simple wrapper function to open a browser window */
 void win32_open_browser(const gchar *uri);
 
 gchar *win32_show_project_open_dialog(GtkWidget *parent, const gchar *title,
 								      const gchar *initial_dir, gboolean allow_new_file,
 								      gboolean project_file_filter);
 
-/* Shows a folder selection dialog.
- * The selected folder name is returned. */
 gchar *win32_show_project_folder_dialog(GtkWidget *parent, const gchar *title,
 										const gchar *initial_dir);
 
@@ -59,4 +52,13 @@ void win32_init_debug_code();
 
 gchar *win32_get_appdata_folder();
 
+gchar *win32_get_hostname();
+
+gboolean win32_get_exit_status(GPid child_pid);
+
+gboolean win32_spawn(const gchar *dir, gchar **argv, gchar **env, GSpawnFlags flags,
+					 gchar **std_out, gchar **std_err, gint *exit_status, GError **error);
+
+gchar *win32_get_shortcut_target(const gchar *file_name);
+
 #endif
