@@ -96,7 +96,8 @@ typedef enum
 	tm_tag_attr_impl_t = 4096, /*!< Implementation (e.g. virtual) */
 	tm_tag_attr_lang_t = 8192, /*!< Language (File tag only) */
 	tm_tag_attr_inactive_t = 16384, /*!< Inactive file (File tag only) */
-	tm_tag_attr_max_t = 32767 /*!< Maximum value */
+	tm_tag_attr_pointer_t = 32768, /*!< Pointer type */
+	tm_tag_attr_max_t = 65535 /*!< Maximum value */
 } TMTagAttrType;
 
 /*! Tag access type for C++/Java member functions and variables */
@@ -130,6 +131,7 @@ typedef struct _TMTag
 			TMSourceFile *file; /*!< File in which the tag occurs */
 			gulong line; /*!< Line number of the tag */
 			gboolean local; /*!< Is the tag of local scope */
+			guint pointerOrder;
 			char *arglist; /*!< Argument list (functions/prototypes/macros) */
 			char *scope; /*!< Scope of tag */
 			char *inheritance; /*!< Parent classes */
@@ -174,11 +176,15 @@ gboolean tm_tag_init(TMTag *tag, TMSourceFile *file, const tagEntryInfo *tag_ent
  \param tag The TMTag structure to populate
  \param file The TMSourceFile struct (assigned to the file member)
  \param fp FILE pointer from where the tag line is read
- \param mode langType - if set to greater than 0, the alternative parser is used and mode represents
-             the langType to use for the tags
  \return TRUE on success, FALSE on FAILURE
 */
-gboolean tm_tag_init_from_file(TMTag *tag, TMSourceFile *file, FILE *fp, gint mode);
+gboolean tm_tag_init_from_file(TMTag *tag, TMSourceFile *file, FILE *fp);
+
+/*!
+ Same as tm_tag_init_from_file(), but using an alternative parser for PHP and
+ LaTeX global tags files.
+*/
+gboolean tm_tag_init_from_file_alt(TMTag *tag, TMSourceFile *file, FILE *fp);
 
 /*!
  Creates a new tag structure from a tagEntryInfo pointer and a TMSOurceFile pointer
@@ -190,7 +196,8 @@ gboolean tm_tag_init_from_file(TMTag *tag, TMSourceFile *file, FILE *fp, gint mo
 TMTag *tm_tag_new(TMSourceFile *file, const tagEntryInfo *tag_entry);
 
 /*!
- Same as tm_tag_new() except that the tag attributes are read from file
+ Same as tm_tag_new() except that the tag attributes are read from file.
+ \param mode langType to use for the tag.
 */
 TMTag *tm_tag_new_from_file(TMSourceFile *file, FILE *fp, gint mode);
 
@@ -291,12 +298,14 @@ TMTag **tm_tags_find(const GPtrArray *sorted_tags_array, const char *name,
 */
 void tm_tags_array_free(GPtrArray *tags_array, gboolean free_all);
 
+#if 0
 /*!
  Destroys a TMTag structure, i.e. frees all elements except the tag itself.
  \param tag The TMTag structure to destroy
  \sa tm_tag_free()
 */
 void tm_tag_destroy(TMTag *tag);
+#endif
 
 /*!
  Destroys all data in the tag and frees the tag structure as well.
